/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_atfLjTEz);
  numBytes += sLine_init(&sLine_a4GrECuc);
  numBytes += sLine_init(&sLine_jKOKVm6p);
  numBytes += sLine_init(&sLine_eRNMLLt2);
  numBytes += sLine_init(&sLine_YOL6lrdL);
  numBytes += sBiquad_init(&sBiquad_s_LKzSUg84);
  numBytes += sLine_init(&sLine_c4LPsshB);
  numBytes += sLine_init(&sLine_r432XzYz);
  numBytes += sLine_init(&sLine_gFlaEb8o);
  numBytes += sLine_init(&sLine_KlgFMa8U);
  numBytes += sLine_init(&sLine_8yAC7FUa);
  numBytes += sBiquad_init(&sBiquad_s_aAVGSfZG);
  numBytes += sLine_init(&sLine_e5eLVyJ4);
  numBytes += sLine_init(&sLine_TWgIeY2e);
  numBytes += sLine_init(&sLine_PC5R0gti);
  numBytes += sLine_init(&sLine_PpTPfLtO);
  numBytes += sLine_init(&sLine_RLqZiWme);
  numBytes += sLine_init(&sLine_fuXSSIIO);
  numBytes += sBiquad_init(&sBiquad_s_8LSbZFKS);
  numBytes += sLine_init(&sLine_E3JC5uHA);
  numBytes += sLine_init(&sLine_cevx1G6j);
  numBytes += sLine_init(&sLine_xEuczQB8);
  numBytes += sLine_init(&sLine_DgBIOjQQ);
  numBytes += sLine_init(&sLine_feNBolwe);
  numBytes += sLine_init(&sLine_zRyDQqXG);
  numBytes += sBiquad_init(&sBiquad_s_e7iMYI4j);
  numBytes += sLine_init(&sLine_cfUKzoDG);
  numBytes += sLine_init(&sLine_LHGAyNVU);
  numBytes += sLine_init(&sLine_WpFSzaGO);
  numBytes += sLine_init(&sLine_ZTooHvlT);
  numBytes += sLine_init(&sLine_oDPEuAAS);
  numBytes += sBiquad_init(&sBiquad_s_A0P7mKTQ);
  numBytes += sLine_init(&sLine_0egeMdVB);
  numBytes += sLine_init(&sLine_DciNfvqI);
  numBytes += sLine_init(&sLine_8xTFfLgD);
  numBytes += sLine_init(&sLine_KBCJXlmZ);
  numBytes += sLine_init(&sLine_83H0DuGT);
  numBytes += sLine_init(&sLine_IFkDMTWz);
  numBytes += sBiquad_init(&sBiquad_s_IzC0NTML);
  numBytes += sLine_init(&sLine_2IEhbMdG);
  numBytes += sLine_init(&sLine_HHZWbOB0);
  numBytes += sLine_init(&sLine_NSnnysyI);
  numBytes += sLine_init(&sLine_Kq8SVdah);
  numBytes += sLine_init(&sLine_oEJdvk0D);
  numBytes += sLine_init(&sLine_DCFer1Zt);
  numBytes += sLine_init(&sLine_Xqz4jj3O);
  numBytes += sLine_init(&sLine_eg9ml84Z);
  numBytes += sLine_init(&sLine_tqTWgHyN);
  numBytes += sLine_init(&sLine_jpaPodTZ);
  numBytes += sLine_init(&sLine_Lx5rEpPq);
  numBytes += sLine_init(&sLine_PeZ68nL0);
  numBytes += sLine_init(&sLine_HYAwkrQi);
  numBytes += sLine_init(&sLine_p0gq1VcF);
  numBytes += sLine_init(&sLine_kpWWgThS);
  numBytes += sEnv_init(&sEnv_qAkugdHd, 512, 256);
  numBytes += sEnv_init(&sEnv_MreXH6Qx, 512, 256);
  numBytes += sLine_init(&sLine_8lY7pmEO);
  numBytes += sLine_init(&sLine_i4hPeZLV);
  numBytes += sLine_init(&sLine_oLC9ICoz);
  numBytes += sLine_init(&sLine_mgNQz2wB);
  numBytes += sLine_init(&sLine_KGoc2gO8);
  numBytes += sLine_init(&sLine_5smm3uys);
  numBytes += sLine_init(&sLine_PF2SkrMm);
  numBytes += sLine_init(&sLine_PT2VAXku);
  numBytes += sLine_init(&sLine_TelBcEjD);
  numBytes += sLine_init(&sLine_XH0IeQDf);
  numBytes += sLine_init(&sLine_fN9h9Lx5);
  numBytes += sLine_init(&sLine_FULWliam);
  numBytes += sLine_init(&sLine_Yi1vWqsP);
  numBytes += sLine_init(&sLine_wP6x3Sra);
  numBytes += sLine_init(&sLine_JWvkgLMc);
  numBytes += sLine_init(&sLine_a1nJuZC0);
  numBytes += sLine_init(&sLine_XcxZUoBe);
  numBytes += sLine_init(&sLine_q8T1drzt);
  numBytes += sEnv_init(&sEnv_hmUkP2Ur, 512, 256);
  numBytes += sEnv_init(&sEnv_ebKDkGXi, 512, 256);
  numBytes += sLine_init(&sLine_BRne8ebW);
  numBytes += sLine_init(&sLine_1QPlyaGk);
  numBytes += sLine_init(&sLine_eby9Jmzw);
  numBytes += sLine_init(&sLine_VFyCHDbY);
  numBytes += sLine_init(&sLine_e8vwUzJi);
  numBytes += sLine_init(&sLine_0nzR12Ez);
  numBytes += sLine_init(&sLine_OsuoYFFi);
  numBytes += sLine_init(&sLine_qmr728aw);
  numBytes += sLine_init(&sLine_c83sF4gI);
  numBytes += sLine_init(&sLine_LF6U4hlY);
  numBytes += sLine_init(&sLine_vVVzVcNV);
  numBytes += sLine_init(&sLine_7bHIEkfL);
  numBytes += sLine_init(&sLine_JIawtIJ9);
  numBytes += sLine_init(&sLine_zdtXr6HK);
  numBytes += sLine_init(&sLine_VJuCMeM8);
  numBytes += sLine_init(&sLine_SfHBkP6r);
  numBytes += sLine_init(&sLine_77Pfx9Ru);
  numBytes += sLine_init(&sLine_tP959rhQ);
  numBytes += sLine_init(&sLine_YmM7x51x);
  numBytes += sLine_init(&sLine_rNnLTlBK);
  numBytes += sEnv_init(&sEnv_OTMCXNQM, 512, 256);
  numBytes += sEnv_init(&sEnv_BmPKLLVZ, 512, 256);
  numBytes += sLine_init(&sLine_91hWqGia);
  numBytes += sLine_init(&sLine_Vo1zPwuv);
  numBytes += sLine_init(&sLine_ceK2FSHa);
  numBytes += sLine_init(&sLine_XP4paGqh);
  numBytes += sLine_init(&sLine_JcnM9Km4);
  numBytes += sLine_init(&sLine_Tugqri45);
  numBytes += sLine_init(&sLine_tlpJBsnC);
  numBytes += sLine_init(&sLine_pq7UBq75);
  numBytes += sLine_init(&sLine_FEpFA6WZ);
  numBytes += sLine_init(&sLine_bzMf1MDG);
  numBytes += sLine_init(&sLine_9fYolomI);
  numBytes += sLine_init(&sLine_8wb7aPu1);
  numBytes += sLine_init(&sLine_VHFVZeRu);
  numBytes += sLine_init(&sLine_UPkACdnJ);
  numBytes += sLine_init(&sLine_N88PzxSv);
  numBytes += sLine_init(&sLine_5Yku40Ce);
  numBytes += sLine_init(&sLine_5ck0hCrS);
  numBytes += sLine_init(&sLine_ZfbI4SCK);
  numBytes += sEnv_init(&sEnv_VyAHaKV5, 512, 256);
  numBytes += sEnv_init(&sEnv_IlczPjBn, 512, 256);
  numBytes += sLine_init(&sLine_Dfg8kW3j);
  numBytes += sLine_init(&sLine_6uOITxb2);
  numBytes += sLine_init(&sLine_a2Y5bGtR);
  numBytes += sLine_init(&sLine_wztfoUeP);
  numBytes += sLine_init(&sLine_5nEf8cMR);
  numBytes += sLine_init(&sLine_sY6shsGG);
  numBytes += sLine_init(&sLine_9STs1V8F);
  numBytes += sLine_init(&sLine_OxMjE4AT);
  numBytes += sLine_init(&sLine_gnABSb97);
  numBytes += sLine_init(&sLine_JMrvh5x0);
  numBytes += sLine_init(&sLine_lymIGaZU);
  numBytes += sLine_init(&sLine_YCzjWQe8);
  numBytes += sLine_init(&sLine_dIIC5NL5);
  numBytes += sLine_init(&sLine_CoyfKN3L);
  numBytes += sLine_init(&sLine_JGCIyOYf);
  numBytes += sLine_init(&sLine_1ErwqQFI);
  numBytes += sLine_init(&sLine_WEYd1UeP);
  numBytes += sLine_init(&sLine_k3S9LJfx);
  numBytes += sLine_init(&sLine_UiivM1vs);
  numBytes += sLine_init(&sLine_V2TbqXw9);
  numBytes += sEnv_init(&sEnv_ZgvJogK3, 512, 256);
  numBytes += sEnv_init(&sEnv_x9aluynh, 512, 256);
  numBytes += sLine_init(&sLine_XhEBrAiT);
  numBytes += sLine_init(&sLine_naTeCaBY);
  numBytes += sLine_init(&sLine_wjjjwS6k);
  numBytes += sLine_init(&sLine_ymyz2ncu);
  numBytes += sLine_init(&sLine_y02VtuS7);
  numBytes += sLine_init(&sLine_EsPFTjiL);
  numBytes += sLine_init(&sLine_ZzRHyPad);
  numBytes += sLine_init(&sLine_srH0axTJ);
  numBytes += sLine_init(&sLine_mOhfvYxf);
  numBytes += sLine_init(&sLine_GctIOAtp);
  numBytes += sLine_init(&sLine_2HmE1XFJ);
  numBytes += sLine_init(&sLine_qBCJVUTU);
  numBytes += sLine_init(&sLine_NGS8bXAz);
  numBytes += sLine_init(&sLine_ThHvsdGe);
  numBytes += sLine_init(&sLine_YvFXrgU1);
  numBytes += sLine_init(&sLine_4UP39uiP);
  numBytes += sLine_init(&sLine_v3KJpkRQ);
  numBytes += sLine_init(&sLine_2WNjZhoi);
  numBytes += sEnv_init(&sEnv_UX5G5BFA, 512, 256);
  numBytes += sEnv_init(&sEnv_vfABTrp5, 512, 256);
  numBytes += sLine_init(&sLine_g7jh23Fh);
  numBytes += sLine_init(&sLine_tSXOFPwQ);
  numBytes += sLine_init(&sLine_jslyrezl);
  numBytes += sLine_init(&sLine_0eJNTmFY);
  numBytes += sLine_init(&sLine_Rb0bmp99);
  numBytes += sLine_init(&sLine_bRwshUzZ);
  numBytes += cVar_init_f(&cVar_NBL0wTD0, 0.0f);
  numBytes += cVar_init_f(&cVar_yaq8gVuR, 0.0f);
  numBytes += cVar_init_f(&cVar_SFIUM7DZ, 0.0f);
  numBytes += cVar_init_f(&cVar_EMR5tyYR, 0.0f);
  numBytes += cVar_init_f(&cVar_hAxngoLw, 0.0f);
  numBytes += cVar_init_f(&cVar_Jojdf8Gp, 1.0f);
  numBytes += cVar_init_f(&cVar_HSvxFpEE, 0.0f);
  numBytes += cVar_init_f(&cVar_C967YwGe, 0.0f);
  numBytes += cVar_init_f(&cVar_6QiQU5O5, 0.0f);
  numBytes += cVar_init_f(&cVar_iHJKKhFt, 0.0f);
  numBytes += cSlice_init(&cSlice_oNM3437J, 1, -1);
  numBytes += cVar_init_f(&cVar_fj835w0X, 1337.0f);
  numBytes += cVar_init_f(&cVar_wCKo499u, 0.0f);
  numBytes += cIf_init(&cIf_l26NqGOl, false);
  numBytes += cIf_init(&cIf_EJfHG435, false);
  numBytes += cBinop_init(&cBinop_ZPyo5Dx4, 0.0f); // __pow
  numBytes += cIf_init(&cIf_iIeKPAiw, false);
  numBytes += cBinop_init(&cBinop_ByL76171, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ZfnIiQ6n, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_5LFywbLo, 0.0f);
  numBytes += cIf_init(&cIf_QRUan1hi, false);
  numBytes += cIf_init(&cIf_wY40lhK5, false);
  numBytes += cBinop_init(&cBinop_BfqFDPzM, 0.0f); // __pow
  numBytes += cIf_init(&cIf_2nj73TpD, false);
  numBytes += cBinop_init(&cBinop_WUctPY74, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_FtUxUKIN, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_MlY43meW, 0.0f);
  numBytes += cIf_init(&cIf_rvOZzLfn, false);
  numBytes += cIf_init(&cIf_18PlZHS0, false);
  numBytes += cBinop_init(&cBinop_CnTOcscx, 0.0f); // __pow
  numBytes += cIf_init(&cIf_WDgqMylz, false);
  numBytes += cBinop_init(&cBinop_5adtbHJa, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_QGJ9H8Cc, -15.0f); // __eq
  numBytes += cIf_init(&cIf_XsntgRBT, false);
  numBytes += cSlice_init(&cSlice_F6tHLAEz, 1, -1);
  numBytes += cVar_init_f(&cVar_murOTVKr, 0.0f);
  numBytes += cSlice_init(&cSlice_kTfClmoQ, 1, -1);
  numBytes += cVar_init_f(&cVar_tU1aajCw, 0.0f);
  numBytes += cSlice_init(&cSlice_VqgNG41o, 1, -1);
  numBytes += cVar_init_f(&cVar_yjss5ajb, 0.0f);
  numBytes += cSlice_init(&cSlice_L8v6221Z, 1, -1);
  numBytes += cVar_init_f(&cVar_0wC3iGqP, 0.313f);
  numBytes += cBinop_init(&cBinop_UIDWGvdv, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_O5TGZ5PH, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_x8Ywc3pz, 0.0f);
  numBytes += cVar_init_f(&cVar_AgOd8T4s, 1337.0f);
  numBytes += cVar_init_f(&cVar_c2FbZyZl, 0.3f);
  numBytes += cBinop_init(&cBinop_eSvC03Pv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Q6h5cpJJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sMtiYd0c, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9Y375VJ0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3VcMn9KU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PXRWTWqI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_niAXjvP4, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_29W2Z15L, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_S7VYzoDB, 0.0f);
  numBytes += cVar_init_f(&cVar_QIuzuwBT, 1337.0f);
  numBytes += cVar_init_f(&cVar_i6W77F8P, 0.313f);
  numBytes += cBinop_init(&cBinop_AtFveDkN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2R1zEnPr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KFtlgVCE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_i9ZNauvi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZncBMDmH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dhPqTmUD, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_R7BJbCkg, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_GAID0QyQ, 0.0f);
  numBytes += cVar_init_f(&cVar_hOlf1kCr, 1037.0f);
  numBytes += cVar_init_f(&cVar_1RtUnE0S, 0.4f);
  numBytes += cBinop_init(&cBinop_6RWCRu5g, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6WhWmpJo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TQiTSlIR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4fvhtONJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jNEOxO68, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dwx4LLoH, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_Xfkh3J4c, 1, -1);
  numBytes += cVar_init_f(&cVar_NoSts5OO, 1337.0f);
  numBytes += cVar_init_f(&cVar_cuS5V7H8, 0.0f);
  numBytes += cIf_init(&cIf_ONWeGQf2, false);
  numBytes += cIf_init(&cIf_91Ix5aXQ, false);
  numBytes += cBinop_init(&cBinop_7ZDN2lxo, 0.0f); // __pow
  numBytes += cIf_init(&cIf_uW5ix3sX, false);
  numBytes += cBinop_init(&cBinop_BuYSLz7Q, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_nABltCWE, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_PgW2djf6, 0.0f);
  numBytes += cIf_init(&cIf_zCg71IjA, false);
  numBytes += cIf_init(&cIf_AAxw2NOV, false);
  numBytes += cBinop_init(&cBinop_vxBlW3ou, 0.0f); // __pow
  numBytes += cIf_init(&cIf_HY45b0cn, false);
  numBytes += cBinop_init(&cBinop_LbIMdZuF, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_J8ncw1F1, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_7ePGEta4, 0.0f);
  numBytes += cIf_init(&cIf_QdaBy2Qv, false);
  numBytes += cIf_init(&cIf_PvaBXsym, false);
  numBytes += cBinop_init(&cBinop_CtELIvHL, 0.0f); // __pow
  numBytes += cIf_init(&cIf_FmzlexD3, false);
  numBytes += cBinop_init(&cBinop_i651B9Xq, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_DivsllR5, -15.0f); // __eq
  numBytes += cIf_init(&cIf_WWXniq7G, false);
  numBytes += cSlice_init(&cSlice_FGkMw4G5, 1, -1);
  numBytes += cVar_init_f(&cVar_AZSe2VpB, 0.0f);
  numBytes += cSlice_init(&cSlice_Uv8iP8oY, 1, -1);
  numBytes += cVar_init_f(&cVar_MHRsDKlH, 0.0f);
  numBytes += cSlice_init(&cSlice_pBjPJHbA, 1, -1);
  numBytes += cVar_init_f(&cVar_0m135q8a, 0.0f);
  numBytes += cSlice_init(&cSlice_TUrA4rTY, 1, -1);
  numBytes += cVar_init_f(&cVar_aqaWlUV9, 0.313f);
  numBytes += cBinop_init(&cBinop_tZcTVBxH, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Pu3quGnv, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_vaIPy35O, 0.0f);
  numBytes += cVar_init_f(&cVar_04JfFAnb, 1337.0f);
  numBytes += cVar_init_f(&cVar_IuCCBceG, 0.3f);
  numBytes += cBinop_init(&cBinop_tvx84nsb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JOI57xWE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xe9CZqnr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_epjmiVDk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xI6emhWg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_95TpRB5T, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BDVwtSCv, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_OPnOWbl6, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_QTwqiETl, 0.0f);
  numBytes += cVar_init_f(&cVar_Y7aj91xp, 1337.0f);
  numBytes += cVar_init_f(&cVar_W6fX8dnx, 0.313f);
  numBytes += cBinop_init(&cBinop_yo1cZhJ2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0CtEuqpu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kgNnrQkZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cjBtwNj7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TlkrWMKS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RTAwFlfH, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_CWPjXq08, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_i9Ew9SZM, 0.0f);
  numBytes += cVar_init_f(&cVar_XfVVHT9U, 1037.0f);
  numBytes += cVar_init_f(&cVar_0ztUDKBA, 0.4f);
  numBytes += cBinop_init(&cBinop_mF2fK7s1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_duMTztaa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fbQmaXwT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZFKTXeE8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vyYCmmGz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_a1vAgsmL, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_zFOTq4TX, 5705.6f);
  numBytes += cVar_init_f(&cVar_UYaBWsKw, 313.3f);
  numBytes += cBinop_init(&cBinop_c9NgCUcn, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_YlGU5BH9, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_q4nSipg1, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_ycvBFdyq, 1, -1);
  numBytes += cVar_init_f(&cVar_kozznx6t, 0.5f);
  numBytes += cVar_init_f(&cVar_n5gUdYcL, 0.0f);
  numBytes += cVar_init_f(&cVar_INk5qCLj, 0.0f);
  numBytes += cIf_init(&cIf_7qEfQx3x, false);
  numBytes += cIf_init(&cIf_JviPrU1N, false);
  numBytes += cDelay_init(this, &cDelay_fX4T5Rjt, 10.0f);
  numBytes += cIf_init(&cIf_yFUMl2E7, false);
  numBytes += cIf_init(&cIf_qW3iWPFd, false);
  numBytes += cDelay_init(this, &cDelay_qsRzY1uZ, 10.0f);
  numBytes += cIf_init(&cIf_LCNcakKB, false);
  numBytes += cIf_init(&cIf_09pMgT2o, false);
  numBytes += cDelay_init(this, &cDelay_GsmvEsl1, 10.0f);
  numBytes += cIf_init(&cIf_jjnSHhUG, false);
  numBytes += cIf_init(&cIf_7ikTowvd, false);
  numBytes += cDelay_init(this, &cDelay_XWgaeqKN, 10.0f);
  numBytes += cIf_init(&cIf_4zCniBvb, false);
  numBytes += cIf_init(&cIf_4FOXnvTt, false);
  numBytes += cDelay_init(this, &cDelay_7eJLedvE, 10.0f);
  numBytes += cIf_init(&cIf_d1mcje4v, false);
  numBytes += cIf_init(&cIf_i1Slbckd, false);
  numBytes += cDelay_init(this, &cDelay_oTAwINpm, 10.0f);
  numBytes += cIf_init(&cIf_bE1BKGm7, false);
  numBytes += cIf_init(&cIf_37yxr9R3, false);
  numBytes += cDelay_init(this, &cDelay_URKW4bH5, 10.0f);
  numBytes += cIf_init(&cIf_YPAp5kfb, false);
  numBytes += cIf_init(&cIf_DER6xM4T, false);
  numBytes += cDelay_init(this, &cDelay_mPDwK6qa, 10.0f);
  numBytes += cIf_init(&cIf_QsJADSUR, false);
  numBytes += cIf_init(&cIf_e0yf6qdK, false);
  numBytes += cDelay_init(this, &cDelay_9A0y5OM9, 10.0f);
  numBytes += cIf_init(&cIf_BU0K9uPG, false);
  numBytes += cIf_init(&cIf_71aky8xr, false);
  numBytes += cDelay_init(this, &cDelay_cszGMehW, 10.0f);
  numBytes += cIf_init(&cIf_nvvVMjOL, false);
  numBytes += cIf_init(&cIf_GmRSVEKU, false);
  numBytes += cDelay_init(this, &cDelay_5qxtXYEh, 10.0f);
  numBytes += cIf_init(&cIf_hTDLCVTZ, false);
  numBytes += cIf_init(&cIf_D9fVLEH2, false);
  numBytes += cDelay_init(this, &cDelay_ZoLsSey8, 10.0f);
  numBytes += sVarf_init(&sVarf_QOxMw2DH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zp0Sshk7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6Ngjea96, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mJRlDsQr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oKsqFyNv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ftfvpA2w, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CZTJafai, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_h6NDt5Gs, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_FgTZUTEx, 0.0f);
  numBytes += cSlice_init(&cSlice_9ho5q8Os, 1, -1);
  numBytes += cVar_init_f(&cVar_ldE3Q1Zn, 1.0f);
  numBytes += cSlice_init(&cSlice_ThpYd2p9, 1, -1);
  numBytes += cVar_init_f(&cVar_g3AOIQIP, 0.0f);
  numBytes += cSlice_init(&cSlice_Ygn9EupI, 1, -1);
  numBytes += cVar_init_f(&cVar_dnoq2Mxp, 512.0f);
  numBytes += cSlice_init(&cSlice_j7YgrDlm, 1, -1);
  numBytes += cVar_init_f(&cVar_2O6aAxGM, 1.0f);
  numBytes += cSlice_init(&cSlice_xzn1TyT4, 1, -1);
  numBytes += cVar_init_f(&cVar_dK3cdWzB, 1.0f);
  numBytes += cDelay_init(this, &cDelay_JsohWWzs, 20.0f);
  numBytes += cVar_init_f(&cVar_0wywwvxr, 0.0f);
  numBytes += cIf_init(&cIf_fKoyWmvr, false);
  numBytes += cIf_init(&cIf_6icOhj9u, false);
  numBytes += cBinop_init(&cBinop_uOi9ZIMs, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_lo2G1fsS, 1, -1);
  numBytes += cVar_init_f(&cVar_FV04Yu3Q, 0.0f);
  numBytes += sVarf_init(&sVarf_TKZPwyTZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8alScMX6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WEUe3i0P, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_THcvjY4g, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZGaiGZnV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XJWKEgMp, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_x6CHYP3q, 0.0f);
  numBytes += cVar_init_f(&cVar_N4PXmiJ4, 0.0f);
  numBytes += cIf_init(&cIf_lbQ0FUc8, false);
  numBytes += cIf_init(&cIf_UhQM3MMz, false);
  numBytes += cDelay_init(this, &cDelay_23854Z6I, 10.0f);
  numBytes += cIf_init(&cIf_Lq9XtWdV, false);
  numBytes += cIf_init(&cIf_OPWS1TaZ, false);
  numBytes += cDelay_init(this, &cDelay_um5nrtk2, 10.0f);
  numBytes += cIf_init(&cIf_h3Pi8nmP, false);
  numBytes += cIf_init(&cIf_6NaHuRRU, false);
  numBytes += cDelay_init(this, &cDelay_G8PJHFoF, 10.0f);
  numBytes += cIf_init(&cIf_gmNl9GBg, false);
  numBytes += cIf_init(&cIf_3Ysq66gQ, false);
  numBytes += cDelay_init(this, &cDelay_YFvEkRlx, 10.0f);
  numBytes += cIf_init(&cIf_C4mP7cj3, false);
  numBytes += cIf_init(&cIf_OAcSMEhg, false);
  numBytes += cDelay_init(this, &cDelay_9Pzf5TSK, 10.0f);
  numBytes += cIf_init(&cIf_aWWDveOz, false);
  numBytes += cIf_init(&cIf_U8mJiZAf, false);
  numBytes += cDelay_init(this, &cDelay_6av11oF2, 10.0f);
  numBytes += cIf_init(&cIf_7OPl6aOJ, false);
  numBytes += cIf_init(&cIf_U5Lfx6Cz, false);
  numBytes += cDelay_init(this, &cDelay_JRxPvkCz, 10.0f);
  numBytes += cIf_init(&cIf_KvdBKvjg, false);
  numBytes += cIf_init(&cIf_2eSpv0TO, false);
  numBytes += cDelay_init(this, &cDelay_k9Ix5TtP, 10.0f);
  numBytes += cIf_init(&cIf_9tOl4wMV, false);
  numBytes += cIf_init(&cIf_JS8jNpJS, false);
  numBytes += cDelay_init(this, &cDelay_Co9qbbRm, 10.0f);
  numBytes += cIf_init(&cIf_wtvv98xt, false);
  numBytes += cIf_init(&cIf_kEvCFjUH, false);
  numBytes += cDelay_init(this, &cDelay_ZG3a0Exm, 10.0f);
  numBytes += cIf_init(&cIf_NiJryKaN, false);
  numBytes += cIf_init(&cIf_1F9BGED5, false);
  numBytes += cDelay_init(this, &cDelay_py0gL3Rx, 10.0f);
  numBytes += cIf_init(&cIf_n5pt10K4, false);
  numBytes += cIf_init(&cIf_KhE6shqq, false);
  numBytes += cDelay_init(this, &cDelay_f1RPImUs, 10.0f);
  numBytes += sVarf_init(&sVarf_LQ8Ziq5l, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jNrtpQbZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MkG8oYAp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_J0FI0lv4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PmuehAje, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_beiufeOd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FYHaCopZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wFlz5Oud, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_xSoLrUUI, 0.0f);
  numBytes += cSlice_init(&cSlice_NhpWiwTB, 1, -1);
  numBytes += cVar_init_f(&cVar_fIaf4rbz, 1.0f);
  numBytes += cSlice_init(&cSlice_B4fW84TQ, 1, -1);
  numBytes += cVar_init_f(&cVar_UXaRNwA2, 0.0f);
  numBytes += cSlice_init(&cSlice_npu5di1v, 1, -1);
  numBytes += cVar_init_f(&cVar_CumDOwN3, 512.0f);
  numBytes += cSlice_init(&cSlice_5FQDAHGo, 1, -1);
  numBytes += cVar_init_f(&cVar_W9eu0r0R, 1.0f);
  numBytes += cSlice_init(&cSlice_UchwlgD6, 1, -1);
  numBytes += cVar_init_f(&cVar_7UMeH7XZ, 1.0f);
  numBytes += cDelay_init(this, &cDelay_mAvvNq1F, 20.0f);
  numBytes += cVar_init_f(&cVar_pTtnjxvY, 0.0f);
  numBytes += cIf_init(&cIf_3pKBn5Tg, false);
  numBytes += cIf_init(&cIf_EXyBVVsY, false);
  numBytes += cBinop_init(&cBinop_JquAuloa, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_juFA9c5d, 1, -1);
  numBytes += cVar_init_f(&cVar_JHS3EFcl, 0.0f);
  numBytes += sVarf_init(&sVarf_ct6lJV2l, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HdiSuhqx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6o79A8v8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pFy6rpPl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZvmC07bo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_b9Kr1Sry, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NIz4yD1b, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cAtEq0jY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6oQefbA8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B30IxKBV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_fslb5WnB, 0.0f);
  numBytes += cVar_init_f(&cVar_FvuSbhK2, 0.0f);
  numBytes += cVar_init_f(&cVar_ono9UQZ9, 0.0f);
  numBytes += cVar_init_f(&cVar_q8LN79Z0, 0.0f);
  numBytes += cVar_init_f(&cVar_PJTtsY4L, 0.0f);
  numBytes += cVar_init_f(&cVar_ee91MX7t, 1.0f);
  numBytes += cSlice_init(&cSlice_RzkyzxxI, 1, -1);
  numBytes += cVar_init_f(&cVar_YS1EdWcW, 0.5f);
  numBytes += cVar_init_f(&cVar_uypG5CEL, 0.0f);
  numBytes += cVar_init_f(&cVar_D2FYpSAf, 0.0f);
  numBytes += cIf_init(&cIf_g1fQQDc5, false);
  numBytes += cIf_init(&cIf_FeWE6chi, false);
  numBytes += cDelay_init(this, &cDelay_vUGNhu3q, 10.0f);
  numBytes += cIf_init(&cIf_bpo8iXtN, false);
  numBytes += cIf_init(&cIf_IpNgLBAT, false);
  numBytes += cDelay_init(this, &cDelay_UsWYwufa, 10.0f);
  numBytes += cIf_init(&cIf_TuDZ45Ab, false);
  numBytes += cIf_init(&cIf_sronBJ6N, false);
  numBytes += cDelay_init(this, &cDelay_tSqUAew2, 10.0f);
  numBytes += cIf_init(&cIf_eiF9JguD, false);
  numBytes += cIf_init(&cIf_DCnJ5z4W, false);
  numBytes += cDelay_init(this, &cDelay_pv0750ge, 10.0f);
  numBytes += cIf_init(&cIf_ywMRzEwa, false);
  numBytes += cIf_init(&cIf_H0wMU26S, false);
  numBytes += cDelay_init(this, &cDelay_GElfUAxj, 10.0f);
  numBytes += cIf_init(&cIf_fHZHyWtc, false);
  numBytes += cIf_init(&cIf_K2HBqsKx, false);
  numBytes += cDelay_init(this, &cDelay_wxH040F8, 10.0f);
  numBytes += cIf_init(&cIf_iOG2FP6z, false);
  numBytes += cIf_init(&cIf_ORCIqbdW, false);
  numBytes += cDelay_init(this, &cDelay_dTrtZIys, 10.0f);
  numBytes += cIf_init(&cIf_aDU7IhkA, false);
  numBytes += cIf_init(&cIf_SL72uSSr, false);
  numBytes += cDelay_init(this, &cDelay_FEQ2gfo5, 10.0f);
  numBytes += cIf_init(&cIf_snDeV78M, false);
  numBytes += cIf_init(&cIf_nVerfcqj, false);
  numBytes += cDelay_init(this, &cDelay_xGpJA8EH, 10.0f);
  numBytes += cIf_init(&cIf_fL5pm1ge, false);
  numBytes += cIf_init(&cIf_qzQRtgzk, false);
  numBytes += cDelay_init(this, &cDelay_YOEBMcav, 10.0f);
  numBytes += cIf_init(&cIf_oRozDaOe, false);
  numBytes += cIf_init(&cIf_McDXRIzr, false);
  numBytes += cDelay_init(this, &cDelay_Dg2Ct1t3, 10.0f);
  numBytes += cIf_init(&cIf_IejBBXwh, false);
  numBytes += cIf_init(&cIf_MbBRdao9, false);
  numBytes += cDelay_init(this, &cDelay_4anWcnNC, 10.0f);
  numBytes += sVarf_init(&sVarf_ktK4dJqs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2RRfujIr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dN55Ij6u, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TijLIO7E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_m6DwWNx1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jq7dNR6A, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_n6IBV3fJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BGH8sn9Q, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_J3z5lKsg, 0.0f);
  numBytes += cSlice_init(&cSlice_eTZUplu6, 1, -1);
  numBytes += cVar_init_f(&cVar_x8BfBaJ6, 1.0f);
  numBytes += cSlice_init(&cSlice_yH15wPIN, 1, -1);
  numBytes += cVar_init_f(&cVar_GkziVjRb, 0.0f);
  numBytes += cSlice_init(&cSlice_4sUWPmLx, 1, -1);
  numBytes += cVar_init_f(&cVar_ijS8UDbr, 512.0f);
  numBytes += cSlice_init(&cSlice_Q0lRxPCb, 1, -1);
  numBytes += cVar_init_f(&cVar_7mEj1rIS, 1.0f);
  numBytes += cSlice_init(&cSlice_LlsJ9rGj, 1, -1);
  numBytes += cVar_init_f(&cVar_3sVZtc4K, 1.0f);
  numBytes += cDelay_init(this, &cDelay_VLMJn5EY, 20.0f);
  numBytes += cVar_init_f(&cVar_KamBT18P, 0.0f);
  numBytes += cIf_init(&cIf_k9yn7jQm, false);
  numBytes += cIf_init(&cIf_bflHIF06, false);
  numBytes += cBinop_init(&cBinop_2hbUVlBb, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_WRdCbCsV, 1, -1);
  numBytes += cVar_init_f(&cVar_RwGvkjNn, 0.0f);
  numBytes += sVarf_init(&sVarf_Bd8dCUAU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vSyor7si, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gqSO1ymZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_k6VwNPf7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ni5PWnYb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KLklZKBN, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_5Nk9jrUI, 0.0f);
  numBytes += cVar_init_f(&cVar_MKjShBxb, 0.0f);
  numBytes += cIf_init(&cIf_TmI4K3Uc, false);
  numBytes += cIf_init(&cIf_dpXoP2aX, false);
  numBytes += cDelay_init(this, &cDelay_RqTnMp5b, 10.0f);
  numBytes += cIf_init(&cIf_KPEe5KOW, false);
  numBytes += cIf_init(&cIf_NzCGSavo, false);
  numBytes += cDelay_init(this, &cDelay_DmTxzFHp, 10.0f);
  numBytes += cIf_init(&cIf_V0Ia5HXS, false);
  numBytes += cIf_init(&cIf_zHzSdsAp, false);
  numBytes += cDelay_init(this, &cDelay_EXI6IskP, 10.0f);
  numBytes += cIf_init(&cIf_OSRWVfE8, false);
  numBytes += cIf_init(&cIf_UjWRS20f, false);
  numBytes += cDelay_init(this, &cDelay_jFNdmUdh, 10.0f);
  numBytes += cIf_init(&cIf_NZ6mL67N, false);
  numBytes += cIf_init(&cIf_rAVDq1PI, false);
  numBytes += cDelay_init(this, &cDelay_yJdHCVcu, 10.0f);
  numBytes += cIf_init(&cIf_ha05uvjY, false);
  numBytes += cIf_init(&cIf_7TFJvTTC, false);
  numBytes += cDelay_init(this, &cDelay_D2AZIQNH, 10.0f);
  numBytes += cIf_init(&cIf_f4Y4AQuZ, false);
  numBytes += cIf_init(&cIf_qpyqc6zz, false);
  numBytes += cDelay_init(this, &cDelay_jMPUveha, 10.0f);
  numBytes += cIf_init(&cIf_lJEzHOjD, false);
  numBytes += cIf_init(&cIf_3FdK0SNK, false);
  numBytes += cDelay_init(this, &cDelay_BM03WGIa, 10.0f);
  numBytes += cIf_init(&cIf_DG5enoWU, false);
  numBytes += cIf_init(&cIf_wcXUmFKA, false);
  numBytes += cDelay_init(this, &cDelay_Lj9yirod, 10.0f);
  numBytes += cIf_init(&cIf_3xEqSNV3, false);
  numBytes += cIf_init(&cIf_3L3gDdZW, false);
  numBytes += cDelay_init(this, &cDelay_AeEgh5vy, 10.0f);
  numBytes += cIf_init(&cIf_7RFhrdPD, false);
  numBytes += cIf_init(&cIf_RSCH1she, false);
  numBytes += cDelay_init(this, &cDelay_08cVnv08, 10.0f);
  numBytes += cIf_init(&cIf_FiegSPOd, false);
  numBytes += cIf_init(&cIf_9qazXYrN, false);
  numBytes += cDelay_init(this, &cDelay_7xMT262C, 10.0f);
  numBytes += sVarf_init(&sVarf_Sip5SJu9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9rrUQOGG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0xyd393O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VxKShsKh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8zz7gqxM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DqnJVRxj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iyBcm202, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hVVumXoX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_oHQtMKo2, 0.0f);
  numBytes += cSlice_init(&cSlice_QFxvyadF, 1, -1);
  numBytes += cVar_init_f(&cVar_l1GQG2EK, 1.0f);
  numBytes += cSlice_init(&cSlice_e6yipyFl, 1, -1);
  numBytes += cVar_init_f(&cVar_37BbmJBR, 0.0f);
  numBytes += cSlice_init(&cSlice_RSwP40Yi, 1, -1);
  numBytes += cVar_init_f(&cVar_zxIoi3pJ, 512.0f);
  numBytes += cSlice_init(&cSlice_MaUUZhd8, 1, -1);
  numBytes += cVar_init_f(&cVar_CahfVcAn, 1.0f);
  numBytes += cSlice_init(&cSlice_OOlQvIOW, 1, -1);
  numBytes += cVar_init_f(&cVar_kM2knrj3, 1.0f);
  numBytes += cDelay_init(this, &cDelay_Rrnv6qF4, 20.0f);
  numBytes += cVar_init_f(&cVar_7aTI19N8, 0.0f);
  numBytes += cIf_init(&cIf_kWPDSYBi, false);
  numBytes += cIf_init(&cIf_bXdhQcyf, false);
  numBytes += cBinop_init(&cBinop_cQfCDKSM, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_x9sn94TN, 1, -1);
  numBytes += cVar_init_f(&cVar_b6mUH3ND, 0.0f);
  numBytes += sVarf_init(&sVarf_QZ2t5mx4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SCG99p5G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_w6F8JmJW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_V0uC7lEJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QmrWO2YG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6ZgUSgrf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_u61Y1BzS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eKq59oJn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9Yk3YfYo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_23DBlulU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_aqiXY9V6, 0.0f);
  numBytes += cVar_init_f(&cVar_U6yKXRyK, 0.0f);
  numBytes += cVar_init_f(&cVar_dnNhFBrh, 0.0f);
  numBytes += cVar_init_f(&cVar_R84QtEyx, 0.0f);
  numBytes += cVar_init_f(&cVar_8mB5yb96, 0.0f);
  numBytes += cVar_init_f(&cVar_ieRz6eEG, 1.0f);
  numBytes += cSlice_init(&cSlice_tn9b0BoJ, 1, -1);
  numBytes += cVar_init_f(&cVar_pgyG0VK5, 0.5f);
  numBytes += cVar_init_f(&cVar_UMU3sCiN, 0.0f);
  numBytes += cVar_init_f(&cVar_lBKXZ75t, 0.0f);
  numBytes += cIf_init(&cIf_RdXKuAzy, false);
  numBytes += cIf_init(&cIf_oghBdMve, false);
  numBytes += cDelay_init(this, &cDelay_GTWFj4jf, 10.0f);
  numBytes += cIf_init(&cIf_4kL2D7Qo, false);
  numBytes += cIf_init(&cIf_WI7a4DA0, false);
  numBytes += cDelay_init(this, &cDelay_9NluoTwF, 10.0f);
  numBytes += cIf_init(&cIf_P26bWWzo, false);
  numBytes += cIf_init(&cIf_Tt1oyKmL, false);
  numBytes += cDelay_init(this, &cDelay_GM16FB0d, 10.0f);
  numBytes += cIf_init(&cIf_9dIFBemD, false);
  numBytes += cIf_init(&cIf_Vyer7YwV, false);
  numBytes += cDelay_init(this, &cDelay_DFN92fIE, 10.0f);
  numBytes += cIf_init(&cIf_Vk4N2S6G, false);
  numBytes += cIf_init(&cIf_govx89rS, false);
  numBytes += cDelay_init(this, &cDelay_Jw56uDUi, 10.0f);
  numBytes += cIf_init(&cIf_cbWWcFa3, false);
  numBytes += cIf_init(&cIf_wG4OU7hq, false);
  numBytes += cDelay_init(this, &cDelay_tnRwlkCM, 10.0f);
  numBytes += cIf_init(&cIf_Hrinbj23, false);
  numBytes += cIf_init(&cIf_h2Iiv1Fy, false);
  numBytes += cDelay_init(this, &cDelay_l3nwmEjm, 10.0f);
  numBytes += cIf_init(&cIf_xpcdgjLs, false);
  numBytes += cIf_init(&cIf_M4iMYA0u, false);
  numBytes += cDelay_init(this, &cDelay_UkMy8WAU, 10.0f);
  numBytes += cIf_init(&cIf_i5cQ2q9Q, false);
  numBytes += cIf_init(&cIf_WA5RhEwj, false);
  numBytes += cDelay_init(this, &cDelay_M4xOhuiJ, 10.0f);
  numBytes += cIf_init(&cIf_HDaxwOi3, false);
  numBytes += cIf_init(&cIf_b0aNaJWx, false);
  numBytes += cDelay_init(this, &cDelay_vMrsck9C, 10.0f);
  numBytes += cIf_init(&cIf_yhM5JkZx, false);
  numBytes += cIf_init(&cIf_QEhXeFfA, false);
  numBytes += cDelay_init(this, &cDelay_uP5vLkMO, 10.0f);
  numBytes += cIf_init(&cIf_SF992i4Y, false);
  numBytes += cIf_init(&cIf_OKvJgem4, false);
  numBytes += cDelay_init(this, &cDelay_dJWnLN2U, 10.0f);
  numBytes += sVarf_init(&sVarf_6CInDqmu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XrwftxOg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TNDkmLdY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_F2TP7sQm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UK5cgn3C, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fPVSRYMd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FJNwaIlH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CJbyQkfU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_8Tp3yE4S, 0.0f);
  numBytes += cSlice_init(&cSlice_3pIpBKx9, 1, -1);
  numBytes += cVar_init_f(&cVar_pkFhSf1r, 1.0f);
  numBytes += cSlice_init(&cSlice_MsnvBYsB, 1, -1);
  numBytes += cVar_init_f(&cVar_Cagbe23F, 0.0f);
  numBytes += cSlice_init(&cSlice_35GwUwN5, 1, -1);
  numBytes += cVar_init_f(&cVar_kEHNOngX, 512.0f);
  numBytes += cSlice_init(&cSlice_EY1iiLI5, 1, -1);
  numBytes += cVar_init_f(&cVar_TpDcaxyS, 1.0f);
  numBytes += cSlice_init(&cSlice_jhTZNAh5, 1, -1);
  numBytes += cVar_init_f(&cVar_cev3HfJi, 1.0f);
  numBytes += cDelay_init(this, &cDelay_XO0Ovqaf, 20.0f);
  numBytes += cVar_init_f(&cVar_eW4nrtGS, 0.0f);
  numBytes += cIf_init(&cIf_qdUQRCnT, false);
  numBytes += cIf_init(&cIf_QhYt9mVD, false);
  numBytes += cBinop_init(&cBinop_EvmGWzDW, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_NGq8OPad, 1, -1);
  numBytes += cVar_init_f(&cVar_Fp9R7bO2, 0.0f);
  numBytes += sVarf_init(&sVarf_BlyKLHm4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_V0704S3t, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Y5ij4clr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VzcRshwe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AEOpEGN7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oCGP6bzP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_qbovnTiJ, 0.0f);
  numBytes += cVar_init_f(&cVar_JgGyZc2n, 0.0f);
  numBytes += cIf_init(&cIf_oXj3SwvT, false);
  numBytes += cIf_init(&cIf_X8yZmSfa, false);
  numBytes += cDelay_init(this, &cDelay_tlvEikpV, 10.0f);
  numBytes += cIf_init(&cIf_ZIQste7s, false);
  numBytes += cIf_init(&cIf_rcTKKjRZ, false);
  numBytes += cDelay_init(this, &cDelay_i5ihj6Li, 10.0f);
  numBytes += cIf_init(&cIf_RxDZHgv2, false);
  numBytes += cIf_init(&cIf_hRDYAXrN, false);
  numBytes += cDelay_init(this, &cDelay_c6Yv8pxE, 10.0f);
  numBytes += cIf_init(&cIf_e3FxSkdl, false);
  numBytes += cIf_init(&cIf_3QddqQ0b, false);
  numBytes += cDelay_init(this, &cDelay_xPSmZ4f2, 10.0f);
  numBytes += cIf_init(&cIf_uRfsvmDU, false);
  numBytes += cIf_init(&cIf_MJ90j9O8, false);
  numBytes += cDelay_init(this, &cDelay_xcY3VFZW, 10.0f);
  numBytes += cIf_init(&cIf_J2sxOIZO, false);
  numBytes += cIf_init(&cIf_Vxbf4rQO, false);
  numBytes += cDelay_init(this, &cDelay_ptFXNHdr, 10.0f);
  numBytes += cIf_init(&cIf_nTQxWc7O, false);
  numBytes += cIf_init(&cIf_yDwwT0Tm, false);
  numBytes += cDelay_init(this, &cDelay_N8fzR2Tp, 10.0f);
  numBytes += cIf_init(&cIf_dWayJKd6, false);
  numBytes += cIf_init(&cIf_x9ZWrpqs, false);
  numBytes += cDelay_init(this, &cDelay_7IfGM0I0, 10.0f);
  numBytes += cIf_init(&cIf_ywQ6M0mK, false);
  numBytes += cIf_init(&cIf_NDIJc2QQ, false);
  numBytes += cDelay_init(this, &cDelay_djGN7llJ, 10.0f);
  numBytes += cIf_init(&cIf_HeDFMjKl, false);
  numBytes += cIf_init(&cIf_ZIDzXzp3, false);
  numBytes += cDelay_init(this, &cDelay_N59lag4j, 10.0f);
  numBytes += cIf_init(&cIf_sqU1Y1LB, false);
  numBytes += cIf_init(&cIf_7zMW8oaR, false);
  numBytes += cDelay_init(this, &cDelay_2Yj16Pjk, 10.0f);
  numBytes += cIf_init(&cIf_gAmYY0rI, false);
  numBytes += cIf_init(&cIf_x2J0sPbb, false);
  numBytes += cDelay_init(this, &cDelay_mEbk6MBb, 10.0f);
  numBytes += sVarf_init(&sVarf_cUgsSNMC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Orr2tpxr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gxgERvT3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vrCTCmyK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Z1f9iYFz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hurWNrcc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4LEY4DRz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oBDKSGeA, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_8LK30UQq, 0.0f);
  numBytes += cSlice_init(&cSlice_1ucYgSo4, 1, -1);
  numBytes += cVar_init_f(&cVar_LsN48ec8, 1.0f);
  numBytes += cSlice_init(&cSlice_ROnvxtEn, 1, -1);
  numBytes += cVar_init_f(&cVar_BV7I4EEP, 0.0f);
  numBytes += cSlice_init(&cSlice_LhubyV3X, 1, -1);
  numBytes += cVar_init_f(&cVar_nKhQ2v18, 512.0f);
  numBytes += cSlice_init(&cSlice_ii0E5KGu, 1, -1);
  numBytes += cVar_init_f(&cVar_u5nvMzrU, 1.0f);
  numBytes += cSlice_init(&cSlice_Y1iNpJjw, 1, -1);
  numBytes += cVar_init_f(&cVar_Sd5WgGzm, 1.0f);
  numBytes += cDelay_init(this, &cDelay_D83dUMS9, 20.0f);
  numBytes += cVar_init_f(&cVar_BLt6rdaq, 0.0f);
  numBytes += cIf_init(&cIf_O97ayKhz, false);
  numBytes += cIf_init(&cIf_oE1JeWJJ, false);
  numBytes += cBinop_init(&cBinop_zUC0S1zq, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_vHYJKgRh, 1, -1);
  numBytes += cVar_init_f(&cVar_ZRza9F2L, 0.0f);
  numBytes += sVarf_init(&sVarf_RpXyBXWq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_suBpVERB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9A1YnBhO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xmo06AML, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AduQ9RLr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5TXSs0le, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zOKO7k0F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4XeWox0C, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qjhPc02U, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fpd4CCAW, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_slfhGg1e, 0.0f);
  numBytes += cVar_init_f(&cVar_3XVczCOe, 0.0f);
  numBytes += cVar_init_f(&cVar_WzrmwYXZ, 0.0f);
  numBytes += sVarf_init(&sVarf_FzLPdMtY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_92cDzYwh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XHUyoXEp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2sMAjr91, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5Oc5IzF4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VnpAVqX2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fIlcVJcp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DRklZUuq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IJ5m1DSZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OZPJBJSC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uBhGseTu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TWCCR38k, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_qAkugdHd);
  sEnv_free(&sEnv_MreXH6Qx);
  sEnv_free(&sEnv_hmUkP2Ur);
  sEnv_free(&sEnv_ebKDkGXi);
  sEnv_free(&sEnv_OTMCXNQM);
  sEnv_free(&sEnv_BmPKLLVZ);
  sEnv_free(&sEnv_VyAHaKV5);
  sEnv_free(&sEnv_IlczPjBn);
  sEnv_free(&sEnv_ZgvJogK3);
  sEnv_free(&sEnv_x9aluynh);
  sEnv_free(&sEnv_UX5G5BFA);
  sEnv_free(&sEnv_vfABTrp5);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vARJj4ns_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rjxJDGOF_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T7GkZfrC_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oiWKqCiq_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e9m7MtFz_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lktBFuCW_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qsqyEd5l_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yfWZHl0i_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C8ngMg1o_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UafQ7EKq_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nQcU1mwy_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TrcIqy7M_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YARDqO2b_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TIjGh2hK_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_I0RvVZUs_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sIpumxv3_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GmpLKULZ_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tCcrvcSv_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JtnMPp7N_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jfiCBMeU_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WhA6sN6M_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MSzGTN5G_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YWNBMRwl_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FwrvZhKh_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zATcIB86_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mhQWJKXj_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uav92x5n_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GqUlgWOg_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_12geb3UR_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ELdx7P1c_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Uxqn4Mii_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YIHVjL8i_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fSKD6hNc_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uVJjW78e_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eaPgcqqn_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cRcDTkWZ_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6r724Fsi_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lGCOj1YP_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IVQOQPvk_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O9pRNF3b_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pWEyAyVL_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9EHlnb9w_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4mYYK568_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RjGZ5CsA_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v01obU4b_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_V7J69L7x_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UbxD4jvs_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ncbONSAe_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sVe9XILR_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WkK8tGeo_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vW5F8ifZ_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1ArAlLhd_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zhwLQS04_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YzKGp62y_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZNWPdZzq_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_buKmobAq_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r62zN5ho_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lXi7S3nW_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NQAMC6HN_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YSEeMLRd_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WgUFlBb4_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OTH86ad0_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CLUbQ7tI_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jpewozst_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CbuxReZm_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jxQ3tW8q_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_abNkLBHX_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ac3M86HE_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ht2qOWzs_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OqY0K06b_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HiSp90r3_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Aw6vyy1o_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TaGKatIA_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uozmYR9r_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hK0yT19k_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RGZpXeyJ_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Rzq5GVyY_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W67qJV25_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n4czyUOM_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7lY9z3a6_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SDRUjHns_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U20Owp7l_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tK70P3nL_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wBRok7PY_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Bz2emIAV_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l6jFMwyc_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4ZlNkMM9_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RmJ0khM8_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rmKSDlfS_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QBBXj5fc_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r7D5obv7_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1V1InTTU_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eDT8HuYe_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_NBL0wTD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c0idNmr1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_yaq8gVuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4oQSdxci_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_SFIUM7DZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WIz2XAiU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_EMR5tyYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dLCjmEIs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_hAxngoLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BdZzSbVI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Jojdf8Gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BMlUjoMB_sendMessage);
  cMsg_efNFIn1n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_BMlUjoMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jojdf8Gp, 1, m, &cVar_Jojdf8Gp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mfgUks1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H9nX1mT5_sendMessage(_c, 0, m);
  cMsg_TmXiSvQp_sendMessage(_c, 0, m);
  cMsg_WAKAU05g_sendMessage(_c, 0, m);
  cMsg_6lSFWh83_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_HSvxFpEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PJCqIPrB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_C967YwGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ufk4nNtA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_6QiQU5O5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b4NBPylR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_iHJKKhFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X68svkLG_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jSq5yhpp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iipztjDI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LV4kOkil_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CfcI9tve_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_oNM3437J, 0, m, &cSlice_oNM3437J_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IGyQsC8X_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_oNM3437J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DEwWP2xH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DEwWP2xH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_fj835w0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DEwWP2xH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_DEwWP2xH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GqUlgWOg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_wCKo499u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1pyd59JM_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_l26NqGOl, 0, m, &cIf_l26NqGOl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_l26NqGOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yxIhlwyT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_EJfHG435_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_bz30PCWy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_VaQiRIbP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_jIFJCKTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZPyo5Dx4, HV_BINOP_POW, 0, m, &cBinop_ZPyo5Dx4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZPyo5Dx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iIeKPAiw, 0, m, &cIf_iIeKPAiw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wnmGIFUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vNnJbKu0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gVCwgNFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EJfHG435, 0, m, &cIf_EJfHG435_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y2HPDZvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_umfsY6lS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_umfsY6lS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EJfHG435, 1, m, &cIf_EJfHG435_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VaQiRIbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_wnmGIFUZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bz30PCWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_iIeKPAiw, 0, m, &cIf_iIeKPAiw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vNnJbKu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZPyo5Dx4, HV_BINOP_POW, 1, m, &cBinop_ZPyo5Dx4_sendMessage);
  cMsg_jIFJCKTr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_iIeKPAiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O00TF35i_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_1pyd59JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l26NqGOl, 1, m, &cIf_l26NqGOl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yxIhlwyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kYSD2ZWy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IplLVs0c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KZzwG4DR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y2HPDZvg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gVCwgNFa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ByL76171_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iIeKPAiw, 1, m, &cIf_iIeKPAiw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZfnIiQ6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Onsj71VA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Onsj71VA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_O00TF35i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6NWsAKJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_KZzwG4DR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IplLVs0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ByL76171, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ByL76171_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kYSD2ZWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZfnIiQ6n, HV_BINOP_EQ, 1, m, &cBinop_ZfnIiQ6n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Yn51Pawu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wCKo499u, 0, m, &cVar_wCKo499u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D5RNeqPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6NWsAKJw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_jJ3JJW3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ByL76171, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ByL76171_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5agQq0o9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZfnIiQ6n, HV_BINOP_EQ, 0, m, &cBinop_ZfnIiQ6n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_5LFywbLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_N0IzuCLl_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_QRUan1hi, 0, m, &cIf_QRUan1hi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_QRUan1hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DzjRbZ8n_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wY40lhK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_cc5sXASs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_0ln8Fnpk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_XooqYYLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BfqFDPzM, HV_BINOP_POW, 0, m, &cBinop_BfqFDPzM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BfqFDPzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2nj73TpD, 0, m, &cIf_2nj73TpD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uhcFKckg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_re5ecWiJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bMixYuTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ERRxsH7k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EWCZmB6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wY40lhK5, 0, m, &cIf_wY40lhK5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ERRxsH7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wY40lhK5, 1, m, &cIf_wY40lhK5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0ln8Fnpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_uhcFKckg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cc5sXASs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_2nj73TpD, 0, m, &cIf_2nj73TpD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_re5ecWiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BfqFDPzM, HV_BINOP_POW, 1, m, &cBinop_BfqFDPzM_sendMessage);
  cMsg_XooqYYLL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_2nj73TpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h8fAYU94_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NkHn883r_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_N0IzuCLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QRUan1hi, 1, m, &cIf_QRUan1hi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DzjRbZ8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MNDGLGA3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z71UNgKe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MSEyByTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bMixYuTt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EWCZmB6A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WUctPY74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2nj73TpD, 1, m, &cIf_2nj73TpD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FtUxUKIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1smxUbiu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1smxUbiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h8fAYU94_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NkHn883r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m7FgmTXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_MSEyByTq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z71UNgKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WUctPY74, HV_BINOP_GREATER_THAN, 1, m, &cBinop_WUctPY74_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MNDGLGA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FtUxUKIN, HV_BINOP_EQ, 1, m, &cBinop_FtUxUKIN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dAwFR7rW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m7FgmTXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_XprWH4Ol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FtUxUKIN, HV_BINOP_EQ, 0, m, &cBinop_FtUxUKIN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZNDPvFLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WUctPY74, HV_BINOP_GREATER_THAN, 0, m, &cBinop_WUctPY74_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ihlbJLzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5LFywbLo, 0, m, &cVar_5LFywbLo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_MlY43meW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BPq5ji4R_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_rvOZzLfn, 0, m, &cIf_rvOZzLfn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_rvOZzLfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xBB1WzHR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_18PlZHS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_w1P6qiHp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_1ohDzXTF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_PkN9doCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CnTOcscx, HV_BINOP_POW, 0, m, &cBinop_CnTOcscx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CnTOcscx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WDgqMylz, 0, m, &cIf_WDgqMylz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IVsE4e1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_11ZnU0Mj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KGNyG1zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nSDXHOPH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M3iV9nVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_18PlZHS0, 0, m, &cIf_18PlZHS0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nSDXHOPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_18PlZHS0, 1, m, &cIf_18PlZHS0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1ohDzXTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_IVsE4e1T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w1P6qiHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_WDgqMylz, 0, m, &cIf_WDgqMylz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_11ZnU0Mj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CnTOcscx, HV_BINOP_POW, 1, m, &cBinop_CnTOcscx_sendMessage);
  cMsg_PkN9doCg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_WDgqMylz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MZonmr3A_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_BPq5ji4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rvOZzLfn, 1, m, &cIf_rvOZzLfn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xBB1WzHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sfTXYzmO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xF8vt3dp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0S7UNqyp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KGNyG1zp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M3iV9nVG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5adtbHJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WDgqMylz, 1, m, &cIf_WDgqMylz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QGJ9H8Cc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NYzcIpUX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NYzcIpUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_MZonmr3A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YcP8F6al_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_0S7UNqyp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sfTXYzmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QGJ9H8Cc, HV_BINOP_EQ, 1, m, &cBinop_QGJ9H8Cc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xF8vt3dp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5adtbHJa, HV_BINOP_GREATER_THAN, 1, m, &cBinop_5adtbHJa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6z8pl9vk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QGJ9H8Cc, HV_BINOP_EQ, 0, m, &cBinop_QGJ9H8Cc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9huO1oNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MlY43meW, 0, m, &cVar_MlY43meW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DPILcGdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5adtbHJa, HV_BINOP_GREATER_THAN, 0, m, &cBinop_5adtbHJa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TsTvlMwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YcP8F6al_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_XsntgRBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Hzwgxkxg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4e938pHd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_F6tHLAEz, 0, m, &cSlice_F6tHLAEz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9MCEMxCi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_F6tHLAEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9mtcyUCx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9mtcyUCx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_murOTVKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9mtcyUCx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_9mtcyUCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mhQWJKXj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9MCEMxCi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kTfClmoQ, 0, m, &cSlice_kTfClmoQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CfcI9tve_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_kTfClmoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TZXd3j8M_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TZXd3j8M_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_tU1aajCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TZXd3j8M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_TZXd3j8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ELdx7P1c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IGyQsC8X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VqgNG41o, 0, m, &cSlice_VqgNG41o_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NNnRl99v_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_VqgNG41o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xNm8YqSt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xNm8YqSt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_yjss5ajb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xNm8YqSt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xNm8YqSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uav92x5n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NNnRl99v_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_L8v6221Z, 0, m, &cSlice_L8v6221Z_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_L8v6221Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DFMwQbiE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DFMwQbiE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_0wC3iGqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DFMwQbiE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_DFMwQbiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_12geb3UR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_myFExtGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_atfLjTEz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tEGOnznY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a4GrECuc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_llKNgege_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jKOKVm6p, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gbzoD68o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eRNMLLt2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gklOduTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YOL6lrdL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_W0PLBZLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_h6giBaY7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_h6giBaY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UIDWGvdv, HV_BINOP_DIVIDE, 1, m, &cBinop_UIDWGvdv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3sXYHxHJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_ilQkaQhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_TfLla1fj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sMrApZjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ilQkaQhy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TfLla1fj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UIDWGvdv, HV_BINOP_DIVIDE, 0, m, &cBinop_UIDWGvdv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3sXYHxHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sMrApZjL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_UIDWGvdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O5TGZ5PH, HV_BINOP_MULTIPLY, 1, m, &cBinop_O5TGZ5PH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O5TGZ5PH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PBwC9PZm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mvctWloL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_yVOAuv0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3qF5ohvx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_jU4bx5wE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8FkqU8ns_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_L7BQXkiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_6nIZkItq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6nIZkItq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O5TGZ5PH, HV_BINOP_MULTIPLY, 0, m, &cBinop_O5TGZ5PH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d7nSK3Pq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_TMYgTYan_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TMYgTYan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cDZmvu7R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_I37O5t4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x8Ywc3pz, 1, m, &cVar_x8Ywc3pz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_x8Ywc3pz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_frd8WBuI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_1PEjvs9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q6h5cpJJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Q6h5cpJJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gwWKdM35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1PEjvs9d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sbTg8AIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vKvX6XtR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vKvX6XtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sMtiYd0c, HV_BINOP_MULTIPLY, 1, m, &cBinop_sMtiYd0c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zMEY67Kh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Y375VJ0, HV_BINOP_MULTIPLY, 1, m, &cBinop_9Y375VJ0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_l8TqQBzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zMEY67Kh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nEuzuMnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3VcMn9KU, HV_BINOP_MULTIPLY, 1, m, &cBinop_3VcMn9KU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3abmM7Z8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0meWTsZf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0meWTsZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PXRWTWqI, HV_BINOP_MULTIPLY, 1, m, &cBinop_PXRWTWqI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_AgOd8T4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_On1isPLm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_L7BQXkiY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XI79MGYU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_c2FbZyZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_d7nSK3Pq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mvctWloL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_jU4bx5wE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PBwC9PZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_yVOAuv0a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_3qF5ohvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fSKD6hNc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_8FkqU8ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YIHVjL8i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_9kQV4EyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Uxqn4Mii_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cDZmvu7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IraudAHP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IraudAHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eSvC03Pv, HV_BINOP_MULTIPLY, 1, m, &cBinop_eSvC03Pv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eSvC03Pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vNBMZFav_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vNBMZFav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9kQV4EyL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_frd8WBuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_R1yyWNkf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R1yyWNkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f9EirZFH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3jxmxwgi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q6pafLn7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_16E7O8bm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IbSR26A4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BOiGmENi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Q6h5cpJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_myFExtGb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_sMtiYd0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tEGOnznY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_9Y375VJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_llKNgege_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_3VcMn9KU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gbzoD68o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_PXRWTWqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gklOduTy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_SEomEFhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c2FbZyZl, 1, m, &cVar_c2FbZyZl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G1lqcPOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AgOd8T4s, 0, m, &cVar_AgOd8T4s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3jxmxwgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PXRWTWqI, HV_BINOP_MULTIPLY, 0, m, &cBinop_PXRWTWqI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q6pafLn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3VcMn9KU, HV_BINOP_MULTIPLY, 0, m, &cBinop_3VcMn9KU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IbSR26A4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sMtiYd0c, HV_BINOP_MULTIPLY, 0, m, &cBinop_sMtiYd0c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f9EirZFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_16E7O8bm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Y375VJ0, HV_BINOP_MULTIPLY, 0, m, &cBinop_9Y375VJ0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BOiGmENi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q6h5cpJJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q6h5cpJJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XI79MGYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x8Ywc3pz, 0, m, &cVar_x8Ywc3pz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_On1isPLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c2FbZyZl, 0, m, &cVar_c2FbZyZl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MkyV7SWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r432XzYz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Y7L7ac2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gFlaEb8o, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qElG3PkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KlgFMa8U, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uicXK9g5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8yAC7FUa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fe759hdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gDQbFTXM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_gDQbFTXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_niAXjvP4, HV_BINOP_DIVIDE, 1, m, &cBinop_niAXjvP4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mTXYlIPU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_WjPiPWLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_0ETa8InZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E468aKfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_WjPiPWLg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0ETa8InZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_niAXjvP4, HV_BINOP_DIVIDE, 0, m, &cBinop_niAXjvP4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mTXYlIPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E468aKfF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_niAXjvP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_29W2Z15L, HV_BINOP_MULTIPLY, 1, m, &cBinop_29W2Z15L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_29W2Z15L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5GolRbmU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8WZi6qcp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_8wWmcsDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dOglPl0h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_BiWEDU8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GWy02U6v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_1H4AmVdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_KRHs9zPg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KRHs9zPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_29W2Z15L, HV_BINOP_MULTIPLY, 0, m, &cBinop_29W2Z15L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vgn2u6pc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dXzfr5os_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dXzfr5os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wUkc0Zd3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_q510oTR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KFtlgVCE, HV_BINOP_MULTIPLY, 1, m, &cBinop_KFtlgVCE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fzgr3JVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S7VYzoDB, 1, m, &cVar_S7VYzoDB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ydZktZhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i9ZNauvi, HV_BINOP_MULTIPLY, 1, m, &cBinop_i9ZNauvi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PMqVF3LO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jzlctfp5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jzlctfp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZncBMDmH, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZncBMDmH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_S7VYzoDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zLivloBq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_QIuzuwBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Oegqj4tU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_1H4AmVdF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oxMUyMvD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_i6W77F8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_vgn2u6pc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5GolRbmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_8wWmcsDC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8WZi6qcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_BiWEDU8J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_dOglPl0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cRcDTkWZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GWy02U6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eaPgcqqn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_56EG10s4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uVJjW78e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wUkc0Zd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_aVGnC4kk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aVGnC4kk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AtFveDkN, HV_BINOP_MULTIPLY, 1, m, &cBinop_AtFveDkN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AtFveDkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_c0XIQXuy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c0XIQXuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_56EG10s4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zLivloBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_forqwbIh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_forqwbIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ttDqr6yb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xY5Oxoxj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jb0NSM6X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gwhGlSa0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2R1zEnPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MkyV7SWR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_KFtlgVCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y7L7ac2l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_i9ZNauvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qElG3PkN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ZncBMDmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uicXK9g5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VHCU8x42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QIuzuwBT, 0, m, &cVar_QIuzuwBT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JGkl1DNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i6W77F8P, 1, m, &cVar_i6W77F8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Oegqj4tU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i6W77F8P, 0, m, &cVar_i6W77F8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oxMUyMvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S7VYzoDB, 0, m, &cVar_S7VYzoDB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Jb0NSM6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KFtlgVCE, HV_BINOP_MULTIPLY, 0, m, &cBinop_KFtlgVCE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gwhGlSa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2R1zEnPr, HV_BINOP_MULTIPLY, 0, m, &cBinop_2R1zEnPr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xY5Oxoxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i9ZNauvi, HV_BINOP_MULTIPLY, 0, m, &cBinop_i9ZNauvi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ttDqr6yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZncBMDmH, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZncBMDmH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Sz1vcGnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TWgIeY2e, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AkUfVYnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PC5R0gti, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8cyCeUjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PpTPfLtO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NrKIp8aZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RLqZiWme, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hezvKhqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fuXSSIIO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nlkC37xS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_w4OudOJo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_w4OudOJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dhPqTmUD, HV_BINOP_DIVIDE, 1, m, &cBinop_dhPqTmUD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2Rb8Tztt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_F43bsNi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ct9qX1xQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_x14Uge7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_F43bsNi1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ct9qX1xQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dhPqTmUD, HV_BINOP_DIVIDE, 0, m, &cBinop_dhPqTmUD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2Rb8Tztt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x14Uge7x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dhPqTmUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R7BJbCkg, HV_BINOP_MULTIPLY, 1, m, &cBinop_R7BJbCkg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R7BJbCkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4zf9ye15_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3bEfzzVG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_hPEdtTKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fDsGtOwR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_LJimXyvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CzdfK8QT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Eo1cexul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_InHEKpMf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_InHEKpMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R7BJbCkg, HV_BINOP_MULTIPLY, 0, m, &cBinop_R7BJbCkg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_F4k1IGbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_aQUt1RjB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aQUt1RjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vJ5igx9I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_aKdFuK8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6WhWmpJo, HV_BINOP_MULTIPLY, 1, m, &cBinop_6WhWmpJo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mX1yI21F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BogTixXm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BogTixXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_aKdFuK8i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_poYsVqmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xOYkeMqf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xOYkeMqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TQiTSlIR, HV_BINOP_MULTIPLY, 1, m, &cBinop_TQiTSlIR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cW59rOui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4fvhtONJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_4fvhtONJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_29DwXao6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BNzjzLws_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BNzjzLws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cW59rOui_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yYvEI2ED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GAID0QyQ, 1, m, &cVar_GAID0QyQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3lOpRJBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jNEOxO68, HV_BINOP_MULTIPLY, 1, m, &cBinop_jNEOxO68_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7i8AcFZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hNIWGn3m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hNIWGn3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dwx4LLoH, HV_BINOP_MULTIPLY, 1, m, &cBinop_dwx4LLoH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_GAID0QyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CZS3u8JN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_hOlf1kCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xavv2LCH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Eo1cexul_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JjWuvkAG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_1RtUnE0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_F4k1IGbP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3bEfzzVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_LJimXyvD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4zf9ye15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_hPEdtTKl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_fDsGtOwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IVQOQPvk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_CzdfK8QT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lGCOj1YP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yFFms5IG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6r724Fsi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vJ5igx9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xAG9h3QV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xAG9h3QV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6RWCRu5g, HV_BINOP_MULTIPLY, 1, m, &cBinop_6RWCRu5g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6RWCRu5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xInNNqnJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xInNNqnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yFFms5IG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CZS3u8JN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Sxdjqtgm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Sxdjqtgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dU14EFTe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrVd1mQs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gkAVRTL0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eFLPMfGf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iEyMh8s9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kM8UyAqE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6WhWmpJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Sz1vcGnz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_TQiTSlIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AkUfVYnC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_4fvhtONJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8cyCeUjP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_jNEOxO68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NrKIp8aZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dwx4LLoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hezvKhqa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_YEt6bPk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hOlf1kCr, 0, m, &cVar_hOlf1kCr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z9KQ03W7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1RtUnE0S, 1, m, &cVar_1RtUnE0S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lrVd1mQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dwx4LLoH, HV_BINOP_MULTIPLY, 0, m, &cBinop_dwx4LLoH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iEyMh8s9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TQiTSlIR, HV_BINOP_MULTIPLY, 0, m, &cBinop_TQiTSlIR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kM8UyAqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6WhWmpJo, HV_BINOP_MULTIPLY, 0, m, &cBinop_6WhWmpJo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dU14EFTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_gkAVRTL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jNEOxO68, HV_BINOP_MULTIPLY, 0, m, &cBinop_jNEOxO68_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eFLPMfGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4fvhtONJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_4fvhtONJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JjWuvkAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GAID0QyQ, 0, m, &cVar_GAID0QyQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xavv2LCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1RtUnE0S, 0, m, &cVar_1RtUnE0S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CG1BPD3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XsntgRBT, 1, m, &cIf_XsntgRBT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vbdFEJ1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_Hzwgxkxg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_HuNoYnmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vbdFEJ1A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ulaiz9Gq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XsntgRBT, 0, m, &cIf_XsntgRBT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_O00TF35i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c4LPsshB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Hzwgxkxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e5eLVyJ4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MZonmr3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E3JC5uHA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NkHn883r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_ulaiz9Gq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h8fAYU94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CG1BPD3L_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HuNoYnmF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9p2gCQ9t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Xfkh3J4c, 0, m, &cSlice_Xfkh3J4c_sendMessage);
      break;
    }
    default: {
      cSwitchcase_AlQVCN4I_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Xfkh3J4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EMMw2ZUR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EMMw2ZUR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_NoSts5OO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EMMw2ZUR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_EMMw2ZUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9EHlnb9w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_cuS5V7H8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MbvHlDJh_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ONWeGQf2, 0, m, &cIf_ONWeGQf2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_ONWeGQf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CYEQJ6wB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_91Ix5aXQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_X7IWYErq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_hyIkGZQo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_CyKIrBAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ZDN2lxo, HV_BINOP_POW, 0, m, &cBinop_7ZDN2lxo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7ZDN2lxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uW5ix3sX, 0, m, &cIf_uW5ix3sX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6Q7w9zvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_j7uxtQTg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_64hMRz31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_91Ix5aXQ, 0, m, &cIf_91Ix5aXQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_czSxuxAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hhNffOdZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hhNffOdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_91Ix5aXQ, 1, m, &cIf_91Ix5aXQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hyIkGZQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_6Q7w9zvz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_X7IWYErq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_uW5ix3sX, 0, m, &cIf_uW5ix3sX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j7uxtQTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ZDN2lxo, HV_BINOP_POW, 1, m, &cBinop_7ZDN2lxo_sendMessage);
  cMsg_CyKIrBAd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_uW5ix3sX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nRX8AKnJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_MbvHlDJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ONWeGQf2, 1, m, &cIf_ONWeGQf2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CYEQJ6wB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ID1albtv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nM270ZrM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NBz6eZ0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czSxuxAp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_64hMRz31_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BuYSLz7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uW5ix3sX, 1, m, &cIf_uW5ix3sX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nABltCWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OnfnqiX6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OnfnqiX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_nRX8AKnJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bnFOaVMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_NBz6eZ0G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nM270ZrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BuYSLz7Q, HV_BINOP_GREATER_THAN, 1, m, &cBinop_BuYSLz7Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ID1albtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nABltCWE, HV_BINOP_EQ, 1, m, &cBinop_nABltCWE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ebKDrTTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BuYSLz7Q, HV_BINOP_GREATER_THAN, 0, m, &cBinop_BuYSLz7Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LQs8jKKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cuS5V7H8, 0, m, &cVar_cuS5V7H8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vUBShK1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bnFOaVMj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_gcEmhrml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nABltCWE, HV_BINOP_EQ, 0, m, &cBinop_nABltCWE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_PgW2djf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ejulePnV_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_zCg71IjA, 0, m, &cIf_zCg71IjA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_zCg71IjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_69fzO0Dt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AAxw2NOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_lqaYK07p_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_yt3APSKK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_cYz5hG73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vxBlW3ou, HV_BINOP_POW, 0, m, &cBinop_vxBlW3ou_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vxBlW3ou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HY45b0cn, 0, m, &cIf_HY45b0cn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_92r2vDkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_xHYSDB65_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YRAplOjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AAxw2NOV, 0, m, &cIf_AAxw2NOV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OEHuOZiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_s2OOwtdK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s2OOwtdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AAxw2NOV, 1, m, &cIf_AAxw2NOV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yt3APSKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_92r2vDkr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lqaYK07p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_HY45b0cn, 0, m, &cIf_HY45b0cn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xHYSDB65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vxBlW3ou, HV_BINOP_POW, 1, m, &cBinop_vxBlW3ou_sendMessage);
  cMsg_cYz5hG73_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_HY45b0cn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BCQ54c9U_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D9BGCjlz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_ejulePnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zCg71IjA, 1, m, &cIf_zCg71IjA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_69fzO0Dt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R1wPoOca_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EpUGsOkV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_en4tc5Up_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OEHuOZiI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YRAplOjN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LbIMdZuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HY45b0cn, 1, m, &cIf_HY45b0cn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_J8ncw1F1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OlRUmMuX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OlRUmMuX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BCQ54c9U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D9BGCjlz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hEUC89py_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_en4tc5Up_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EpUGsOkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LbIMdZuF, HV_BINOP_GREATER_THAN, 1, m, &cBinop_LbIMdZuF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R1wPoOca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J8ncw1F1, HV_BINOP_EQ, 1, m, &cBinop_J8ncw1F1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ePF6Re1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hEUC89py_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Da9Wxxto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J8ncw1F1, HV_BINOP_EQ, 0, m, &cBinop_J8ncw1F1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FU8cOMnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PgW2djf6, 0, m, &cVar_PgW2djf6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eU6iKgP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LbIMdZuF, HV_BINOP_GREATER_THAN, 0, m, &cBinop_LbIMdZuF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_7ePGEta4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WiVaN043_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_QdaBy2Qv, 0, m, &cIf_QdaBy2Qv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_QdaBy2Qv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GpWNBX2t_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_PvaBXsym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_zN5D1Jp8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_B1n0fLb2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_22ZXF0Np_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CtELIvHL, HV_BINOP_POW, 0, m, &cBinop_CtELIvHL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CtELIvHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FmzlexD3, 0, m, &cIf_FmzlexD3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YxCGre3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_NF1IhDiN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZJkSqgjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PvaBXsym, 0, m, &cIf_PvaBXsym_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XBJ5gCpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zTnrE2q6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zTnrE2q6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PvaBXsym, 1, m, &cIf_PvaBXsym_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B1n0fLb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_YxCGre3J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zN5D1Jp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_FmzlexD3, 0, m, &cIf_FmzlexD3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NF1IhDiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CtELIvHL, HV_BINOP_POW, 1, m, &cBinop_CtELIvHL_sendMessage);
  cMsg_22ZXF0Np_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_FmzlexD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZKFxCLXc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_WiVaN043_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QdaBy2Qv, 1, m, &cIf_QdaBy2Qv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GpWNBX2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f1SMX47H_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ba3dmjPD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0H45LGAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XBJ5gCpq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZJkSqgjV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i651B9Xq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FmzlexD3, 1, m, &cIf_FmzlexD3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DivsllR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_emCbLFgP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_emCbLFgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_ZKFxCLXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XmAPTYl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_0H45LGAN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ba3dmjPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i651B9Xq, HV_BINOP_GREATER_THAN, 1, m, &cBinop_i651B9Xq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f1SMX47H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DivsllR5, HV_BINOP_EQ, 1, m, &cBinop_DivsllR5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QHHqwAQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DivsllR5, HV_BINOP_EQ, 0, m, &cBinop_DivsllR5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KK5JchZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XmAPTYl8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_xcj7iimG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i651B9Xq, HV_BINOP_GREATER_THAN, 0, m, &cBinop_i651B9Xq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jPIhVhHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7ePGEta4, 0, m, &cVar_7ePGEta4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_WWXniq7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AaH6qSI8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yxdvmeLW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FGkMw4G5, 0, m, &cSlice_FGkMw4G5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cj11eTWV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_FGkMw4G5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Px1yQ0hq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Px1yQ0hq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_AZSe2VpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Px1yQ0hq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Px1yQ0hq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_O9pRNF3b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cj11eTWV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Uv8iP8oY, 0, m, &cSlice_Uv8iP8oY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9p2gCQ9t_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Uv8iP8oY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6Df9lEzO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6Df9lEzO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_MHRsDKlH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6Df9lEzO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_6Df9lEzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RjGZ5CsA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AlQVCN4I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pBjPJHbA, 0, m, &cSlice_pBjPJHbA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sNckMWWS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_pBjPJHbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hi89aI4m_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hi89aI4m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_0m135q8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hi89aI4m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hi89aI4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pWEyAyVL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_sNckMWWS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TUrA4rTY, 0, m, &cSlice_TUrA4rTY_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_TUrA4rTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hpNyGxrl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hpNyGxrl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_aqaWlUV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hpNyGxrl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hpNyGxrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4mYYK568_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VXmtRUDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cevx1G6j, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sqliX9BO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xEuczQB8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3pVNrjd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DgBIOjQQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kmrqauDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_feNBolwe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aCZsFSyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zRyDQqXG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YsazlDiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_W8P6s6bw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_W8P6s6bw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tZcTVBxH, HV_BINOP_DIVIDE, 1, m, &cBinop_tZcTVBxH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rFV7cwdE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_RRxSHCsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_p0SyH7bi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jDf6Qlv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_RRxSHCsy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_p0SyH7bi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tZcTVBxH, HV_BINOP_DIVIDE, 0, m, &cBinop_tZcTVBxH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rFV7cwdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jDf6Qlv8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_tZcTVBxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pu3quGnv, HV_BINOP_MULTIPLY, 1, m, &cBinop_Pu3quGnv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Pu3quGnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sm6SYgcD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r9UiLSQ6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_wL43rdDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vvUxuq8H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_fClIQCbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aeAkaoQ1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_06yOtGFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_fh9zj1z6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fh9zj1z6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pu3quGnv, HV_BINOP_MULTIPLY, 0, m, &cBinop_Pu3quGnv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8r9ukVcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_bzLGUgx9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bzLGUgx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TA0AjB4d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_2OyD3ZPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vaIPy35O, 1, m, &cVar_vaIPy35O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_vaIPy35O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JnFWClsb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Pq5LTpqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JOI57xWE, HV_BINOP_MULTIPLY, 1, m, &cBinop_JOI57xWE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lS5trfIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Pq5LTpqW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JBMUCLkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_PxpS1iId_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PxpS1iId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xe9CZqnr, HV_BINOP_MULTIPLY, 1, m, &cBinop_xe9CZqnr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Nu1TE4mN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_epjmiVDk, HV_BINOP_MULTIPLY, 1, m, &cBinop_epjmiVDk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zlFvwl7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Nu1TE4mN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u2b09BVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xI6emhWg, HV_BINOP_MULTIPLY, 1, m, &cBinop_xI6emhWg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b9bg9Jog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_E1R7TQQG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E1R7TQQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_95TpRB5T, HV_BINOP_MULTIPLY, 1, m, &cBinop_95TpRB5T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_04JfFAnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_riZZeW39_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_06yOtGFL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3g8AEbcl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_IuCCBceG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8r9ukVcX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r9UiLSQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_fClIQCbj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Sm6SYgcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_wL43rdDi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_vvUxuq8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UbxD4jvs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_aeAkaoQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_V7J69L7x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_nKTG5UoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_v01obU4b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TA0AjB4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OIZjKr2G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OIZjKr2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tvx84nsb, HV_BINOP_MULTIPLY, 1, m, &cBinop_tvx84nsb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tvx84nsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_f5yRQzDN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f5yRQzDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nKTG5UoK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JnFWClsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8zhzxIfC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8zhzxIfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NG76oZ2v_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DUYAGhP2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t1pam2Cg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dpRpWQDo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TqfaMfkJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6gNVrBi2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JOI57xWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VXmtRUDb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xe9CZqnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sqliX9BO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_epjmiVDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3pVNrjd7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xI6emhWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kmrqauDY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_95TpRB5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aCZsFSyn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_5LRBsbpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_04JfFAnb, 0, m, &cVar_04JfFAnb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kM7j1A8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IuCCBceG, 1, m, &cVar_IuCCBceG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NG76oZ2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_6gNVrBi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JOI57xWE, HV_BINOP_MULTIPLY, 0, m, &cBinop_JOI57xWE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dpRpWQDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_epjmiVDk, HV_BINOP_MULTIPLY, 0, m, &cBinop_epjmiVDk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t1pam2Cg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xI6emhWg, HV_BINOP_MULTIPLY, 0, m, &cBinop_xI6emhWg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TqfaMfkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xe9CZqnr, HV_BINOP_MULTIPLY, 0, m, &cBinop_xe9CZqnr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DUYAGhP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_95TpRB5T, HV_BINOP_MULTIPLY, 0, m, &cBinop_95TpRB5T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3g8AEbcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vaIPy35O, 0, m, &cVar_vaIPy35O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_riZZeW39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IuCCBceG, 0, m, &cVar_IuCCBceG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Om1tKgYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LHGAyNVU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2E54TrPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WpFSzaGO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JVxTg4kT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZTooHvlT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Tm6rZbQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oDPEuAAS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0FSPkRcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kkAPtKC5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_kkAPtKC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BDVwtSCv, HV_BINOP_DIVIDE, 1, m, &cBinop_BDVwtSCv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IAZ30AO5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_yo1esM2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_RV2XU3oP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2t8CTcQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_yo1esM2H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RV2XU3oP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BDVwtSCv, HV_BINOP_DIVIDE, 0, m, &cBinop_BDVwtSCv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IAZ30AO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2t8CTcQZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_BDVwtSCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OPnOWbl6, HV_BINOP_MULTIPLY, 1, m, &cBinop_OPnOWbl6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OPnOWbl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ky65YgYl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oIioB2ff_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_DcEQxRmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gpvDrb0V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_4BTQWV7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WU9FsttG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Q6zlXYTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_fHt0ln8m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fHt0ln8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OPnOWbl6, HV_BINOP_MULTIPLY, 0, m, &cBinop_OPnOWbl6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Uv1b8FJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_UdY3ChZl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UdY3ChZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HwJ1GmNj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_OKfDiJx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kgNnrQkZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_kgNnrQkZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xht3b9cg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QTwqiETl, 1, m, &cVar_QTwqiETl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_t7Kr5hIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cjBtwNj7, HV_BINOP_MULTIPLY, 1, m, &cBinop_cjBtwNj7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tIbg3zpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3uf64dd0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3uf64dd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TlkrWMKS, HV_BINOP_MULTIPLY, 1, m, &cBinop_TlkrWMKS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_QTwqiETl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xg8kTxMD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Y7aj91xp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ee9mSvPs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Q6zlXYTK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dQjlOvOg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_W6fX8dnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Uv1b8FJS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ky65YgYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_DcEQxRmW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oIioB2ff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_4BTQWV7p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_gpvDrb0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WkK8tGeo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_WU9FsttG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sVe9XILR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_AJrZ7Bn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ncbONSAe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HwJ1GmNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2VQVGE9K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2VQVGE9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yo1cZhJ2, HV_BINOP_MULTIPLY, 1, m, &cBinop_yo1cZhJ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yo1cZhJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5agNnHKT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5agNnHKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AJrZ7Bn9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xg8kTxMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LbAhkdny_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LbAhkdny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vfEDYa7l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_udh4J3UC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7ntKwZd5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bl9FW7Js_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0CtEuqpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Om1tKgYq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_kgNnrQkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2E54TrPS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cjBtwNj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JVxTg4kT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_TlkrWMKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tm6rZbQX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_URjQiD7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y7aj91xp, 0, m, &cVar_Y7aj91xp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TfG3nGf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W6fX8dnx, 1, m, &cVar_W6fX8dnx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dQjlOvOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QTwqiETl, 0, m, &cVar_QTwqiETl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ee9mSvPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W6fX8dnx, 0, m, &cVar_W6fX8dnx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vfEDYa7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TlkrWMKS, HV_BINOP_MULTIPLY, 0, m, &cBinop_TlkrWMKS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bl9FW7Js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0CtEuqpu, HV_BINOP_MULTIPLY, 0, m, &cBinop_0CtEuqpu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_udh4J3UC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cjBtwNj7, HV_BINOP_MULTIPLY, 0, m, &cBinop_cjBtwNj7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7ntKwZd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kgNnrQkZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_kgNnrQkZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EDGRfJda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DciNfvqI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Vx1j7p9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8xTFfLgD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_StpJikER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KBCJXlmZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0aPvU2lE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_83H0DuGT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qYTa6Ehz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IFkDMTWz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MHSQHJJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eOVyciZY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_eOVyciZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RTAwFlfH, HV_BINOP_DIVIDE, 1, m, &cBinop_RTAwFlfH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4TsvppV4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_rV7v8JM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_9XclNnir_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P1avJ0Le_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_rV7v8JM7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9XclNnir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RTAwFlfH, HV_BINOP_DIVIDE, 0, m, &cBinop_RTAwFlfH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4TsvppV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P1avJ0Le_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_RTAwFlfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CWPjXq08, HV_BINOP_MULTIPLY, 1, m, &cBinop_CWPjXq08_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CWPjXq08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vVd3uYdY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BpzjBu5T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_aD80rlaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pe1EgKIj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_292yBF1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hLOaEvLA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_boUDwi3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_pNfKKXa0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pNfKKXa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CWPjXq08, HV_BINOP_MULTIPLY, 0, m, &cBinop_CWPjXq08_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_96fWys3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_0kkVhcFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0kkVhcFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oKLjVjQR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vUAyjQho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_duMTztaa, HV_BINOP_MULTIPLY, 1, m, &cBinop_duMTztaa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BnLh6Tyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RXAuvAcC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RXAuvAcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vUAyjQho_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_93TK7wWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8JnyMvop_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8JnyMvop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fbQmaXwT, HV_BINOP_MULTIPLY, 1, m, &cBinop_fbQmaXwT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VamsrjCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZFKTXeE8, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZFKTXeE8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8M7aquoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8RipRBsc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8RipRBsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VamsrjCC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NYnK37NV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i9Ew9SZM, 1, m, &cVar_i9Ew9SZM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cd0h2zxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vyYCmmGz, HV_BINOP_MULTIPLY, 1, m, &cBinop_vyYCmmGz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sMeuuiU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ul3ILHWn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ul3ILHWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a1vAgsmL, HV_BINOP_MULTIPLY, 1, m, &cBinop_a1vAgsmL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_i9Ew9SZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PcAmtGvb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_XfVVHT9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kKBFLGtH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_boUDwi3P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mSkUfa7I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_0ztUDKBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_96fWys3o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BpzjBu5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_292yBF1z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vVd3uYdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_aD80rlaC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_pe1EgKIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zhwLQS04_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hLOaEvLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1ArAlLhd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ufLFr9QF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vW5F8ifZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_oKLjVjQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZGgGE379_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZGgGE379_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mF2fK7s1, HV_BINOP_MULTIPLY, 1, m, &cBinop_mF2fK7s1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mF2fK7s1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CdUKsD3r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CdUKsD3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ufLFr9QF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PcAmtGvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bMIVlmtp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bMIVlmtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IzEQ7tcH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uLJyXMGU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BC4Q375V_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CinjUzXI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X8TiUhnD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o6jT9pkA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_duMTztaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EDGRfJda_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_fbQmaXwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vx1j7p9Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ZFKTXeE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_StpJikER_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vyYCmmGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0aPvU2lE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_a1vAgsmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qYTa6Ehz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_nLZHs5O7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XfVVHT9U, 0, m, &cVar_XfVVHT9U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SFaqSnCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0ztUDKBA, 1, m, &cVar_0ztUDKBA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uLJyXMGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a1vAgsmL, HV_BINOP_MULTIPLY, 0, m, &cBinop_a1vAgsmL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_o6jT9pkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_duMTztaa, HV_BINOP_MULTIPLY, 0, m, &cBinop_duMTztaa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X8TiUhnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fbQmaXwT, HV_BINOP_MULTIPLY, 0, m, &cBinop_fbQmaXwT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IzEQ7tcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_BC4Q375V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vyYCmmGz, HV_BINOP_MULTIPLY, 0, m, &cBinop_vyYCmmGz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CinjUzXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZFKTXeE8, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZFKTXeE8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mSkUfa7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i9Ew9SZM, 0, m, &cVar_i9Ew9SZM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kKBFLGtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0ztUDKBA, 0, m, &cVar_0ztUDKBA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lrI9lHrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WWXniq7G, 1, m, &cIf_WWXniq7G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R567oPtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_AaH6qSI8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_fWlmVRRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R567oPtb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_D6ffCo83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WWXniq7G, 0, m, &cIf_WWXniq7G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nRX8AKnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cfUKzoDG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AaH6qSI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0egeMdVB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZKFxCLXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2IEhbMdG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_D9BGCjlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_D6ffCo83_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BCQ54c9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lrI9lHrh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fWlmVRRd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_zFOTq4TX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YlGU5BH9, HV_BINOP_DIVIDE, 0, m, &cBinop_YlGU5BH9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_UYaBWsKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c9NgCUcn, HV_BINOP_DIVIDE, 1, m, &cBinop_c9NgCUcn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YlGU5BH9, HV_BINOP_DIVIDE, 1, m, &cBinop_YlGU5BH9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_m2UQxdjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q4nSipg1, HV_BINOP_DIVIDE, 0, m, &cBinop_q4nSipg1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_JuPKukq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q4nSipg1, HV_BINOP_DIVIDE, 1, m, &cBinop_q4nSipg1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jSq5yhpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UYaBWsKw, 0, m, &cVar_UYaBWsKw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LV4kOkil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c9NgCUcn, HV_BINOP_DIVIDE, 0, m, &cBinop_c9NgCUcn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iipztjDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zFOTq4TX, 0, m, &cVar_zFOTq4TX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c9NgCUcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_m2UQxdjP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YlGU5BH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_JuPKukq0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_q4nSipg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_KhJTmUdm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_FhzEITXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_T5mzuj0b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jqZhCaX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_6nmSVKho_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KhJTmUdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jqZhCaX3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6nmSVKho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_FhzEITXL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T5mzuj0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0FUcrlgw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8sPRx3kb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ycvBFdyq, 0, m, &cSlice_ycvBFdyq_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ycvBFdyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YNPsTNoW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YNPsTNoW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_kozznx6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YNPsTNoW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_YNPsTNoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YzKGp62y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_5RlhBMdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7yPMhWXw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7yPMhWXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_RaChbt1y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RaChbt1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hBGU4eJK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hBGU4eJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LTCLQacZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_73X5DifP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LTCLQacZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Cn1Ddg4y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_73X5DifP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LyRv3fcS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Cn1Ddg4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ewbldwP1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LyRv3fcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MTL5W6yg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MTL5W6yg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EDbfXjmi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ewbldwP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JemJtV2B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EDbfXjmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iO8JkSRn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JemJtV2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NSnnysyI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iO8JkSRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HHZWbOB0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_n5gUdYcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rSsr0ISz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_INk5qCLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NbHFKcK0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iQvbITD1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BvstQZ2y_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CaZ0V1l8_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hp4Dg2L0_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pePfBeoj_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GdYGJKow_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yb61CtHA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_BvstQZ2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oA8lNfYi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_CaZ0V1l8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kUvU5Ply_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Hp4Dg2L0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TA8J9Q2r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_pePfBeoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m3oUJgAT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_GdYGJKow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nuXV0fUu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Yb61CtHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y59KIjx9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_7qEfQx3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ksrAgbC6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JviPrU1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Kue45kVI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oYLBAQ65_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PZFoJN9u_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PZFoJN9u_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fX4T5Rjt, 1, m, &cDelay_fX4T5Rjt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rkb8CMh7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fX4T5Rjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fX4T5Rjt, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7qEfQx3x, 0, m, &cIf_7qEfQx3x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PZFoJN9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fX4T5Rjt, 0, m, &cDelay_fX4T5Rjt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rkb8CMh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fX4T5Rjt, 0, m, &cDelay_fX4T5Rjt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R2MPl8iP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SOUBrzAO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0JCDM5dL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_brbJfXkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d1h4kmXY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T30M1Ebv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d1h4kmXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7qEfQx3x, 1, m, &cIf_7qEfQx3x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T30M1Ebv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oYLBAQ65_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SOUBrzAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JviPrU1N, 1, m, &cIf_JviPrU1N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0JCDM5dL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JviPrU1N, 0, m, &cIf_JviPrU1N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Kue45kVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Xqz4jj3O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ksrAgbC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Xqz4jj3O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_yFUMl2E7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_62KM46yK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qW3iWPFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hoWceu6K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_05htH3bL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EFQHtN0G_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EFQHtN0G_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qsRzY1uZ, 1, m, &cDelay_qsRzY1uZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZqM2AbQG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_qsRzY1uZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qsRzY1uZ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_yFUMl2E7, 0, m, &cIf_yFUMl2E7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EFQHtN0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qsRzY1uZ, 0, m, &cDelay_qsRzY1uZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZqM2AbQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qsRzY1uZ, 0, m, &cDelay_qsRzY1uZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MGsX40RQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t4WLUXFr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YM4s7GRx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D0JDvlEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i0awY66W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bMlnvISn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bMlnvISn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_05htH3bL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_i0awY66W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yFUMl2E7, 1, m, &cIf_yFUMl2E7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t4WLUXFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qW3iWPFd, 1, m, &cIf_qW3iWPFd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YM4s7GRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qW3iWPFd, 0, m, &cIf_qW3iWPFd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hoWceu6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jpaPodTZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_62KM46yK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jpaPodTZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_LCNcakKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yDw5DtqR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_09pMgT2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kCmkvep0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vk6Xk94A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LVULtzb5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LVULtzb5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GsmvEsl1, 1, m, &cDelay_GsmvEsl1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6XxQcbGv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_GsmvEsl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GsmvEsl1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LCNcakKB, 0, m, &cIf_LCNcakKB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LVULtzb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GsmvEsl1, 0, m, &cDelay_GsmvEsl1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6XxQcbGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GsmvEsl1, 0, m, &cDelay_GsmvEsl1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xz6sKkbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L5ZGkMme_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8Un5xJ1p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4KlbmsjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wKqYfR8K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ggjdwWez_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ggjdwWez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vk6Xk94A_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_wKqYfR8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LCNcakKB, 1, m, &cIf_LCNcakKB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L5ZGkMme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_09pMgT2o, 1, m, &cIf_09pMgT2o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8Un5xJ1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_09pMgT2o, 0, m, &cIf_09pMgT2o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kCmkvep0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HYAwkrQi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yDw5DtqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HYAwkrQi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jjnSHhUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DDnsMbLL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7ikTowvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KZJyQuYr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GynWwYoG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ywAv0YMs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ywAv0YMs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XWgaeqKN, 1, m, &cDelay_XWgaeqKN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m0kxoVQn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_XWgaeqKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XWgaeqKN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jjnSHhUG, 0, m, &cIf_jjnSHhUG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ywAv0YMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XWgaeqKN, 0, m, &cDelay_XWgaeqKN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_m0kxoVQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XWgaeqKN, 0, m, &cDelay_XWgaeqKN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Tqqw2Ihe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z88QuAE6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3mSCyG38_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_srIhp1SP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y22yDgdQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GiEcXF2C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GiEcXF2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GynWwYoG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Y22yDgdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jjnSHhUG, 1, m, &cIf_jjnSHhUG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3mSCyG38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7ikTowvd, 0, m, &cIf_7ikTowvd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z88QuAE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7ikTowvd, 1, m, &cIf_7ikTowvd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KZJyQuYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eg9ml84Z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DDnsMbLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eg9ml84Z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4zCniBvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tEP6HBVz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4FOXnvTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_p5CmMEZK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jd1iouTX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FqhBgNCy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FqhBgNCy_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7eJLedvE, 1, m, &cDelay_7eJLedvE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KSrzcWMa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7eJLedvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7eJLedvE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4zCniBvb, 0, m, &cIf_4zCniBvb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FqhBgNCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7eJLedvE, 0, m, &cDelay_7eJLedvE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KSrzcWMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7eJLedvE, 0, m, &cDelay_7eJLedvE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y1T7DonS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RIjH03XW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DpxNAMR4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hRowYnwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fNQseJ4f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZRTlTJsf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZRTlTJsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jd1iouTX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fNQseJ4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4zCniBvb, 1, m, &cIf_4zCniBvb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RIjH03XW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4FOXnvTt, 1, m, &cIf_4FOXnvTt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DpxNAMR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4FOXnvTt, 0, m, &cIf_4FOXnvTt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_p5CmMEZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Lx5rEpPq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tEP6HBVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Lx5rEpPq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_d1mcje4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GUUuc6V5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_i1Slbckd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_i6UKO7rC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9cpPqWX9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QGN0If30_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QGN0If30_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oTAwINpm, 1, m, &cDelay_oTAwINpm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dhDnycMa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_oTAwINpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oTAwINpm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_d1mcje4v, 0, m, &cIf_d1mcje4v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QGN0If30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oTAwINpm, 0, m, &cDelay_oTAwINpm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dhDnycMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oTAwINpm, 0, m, &cDelay_oTAwINpm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KC9UlgwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P1W6QhnB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5KNB8wpG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WCZm7aEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gjoRnFtm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PEE6bRfq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gjoRnFtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d1mcje4v, 1, m, &cIf_d1mcje4v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PEE6bRfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9cpPqWX9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5KNB8wpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i1Slbckd, 0, m, &cIf_i1Slbckd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_P1W6QhnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i1Slbckd, 1, m, &cIf_i1Slbckd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i6UKO7rC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p0gq1VcF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GUUuc6V5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p0gq1VcF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_bE1BKGm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2d3jMWUN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_37yxr9R3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gLyH4ccX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ykL0WPC8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_d1bqH3Cn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_d1bqH3Cn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_URKW4bH5, 1, m, &cDelay_URKW4bH5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_st3G2EML_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_URKW4bH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_URKW4bH5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bE1BKGm7, 0, m, &cIf_bE1BKGm7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d1bqH3Cn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_URKW4bH5, 0, m, &cDelay_URKW4bH5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_st3G2EML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_URKW4bH5, 0, m, &cDelay_URKW4bH5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hnugq8iQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c4Svj9KL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2EM6rjDy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TnNsoU3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Fu2nIi0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xw57vRUJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xw57vRUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ykL0WPC8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9Fu2nIi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bE1BKGm7, 1, m, &cIf_bE1BKGm7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2EM6rjDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_37yxr9R3, 0, m, &cIf_37yxr9R3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c4Svj9KL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_37yxr9R3, 1, m, &cIf_37yxr9R3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gLyH4ccX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tqTWgHyN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2d3jMWUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tqTWgHyN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_YPAp5kfb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5UeVYxw6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DER6xM4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_chB2PW19_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DnsODld8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Wci6nFGg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Wci6nFGg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mPDwK6qa, 1, m, &cDelay_mPDwK6qa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tptPe1N8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mPDwK6qa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mPDwK6qa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YPAp5kfb, 0, m, &cIf_YPAp5kfb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wci6nFGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mPDwK6qa, 0, m, &cDelay_mPDwK6qa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tptPe1N8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mPDwK6qa, 0, m, &cDelay_mPDwK6qa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GL67ewH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PZ8qnSFc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b9TGJUh1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Gjeu0mJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6yxM2Sp7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4VPnIlMs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4VPnIlMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DnsODld8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6yxM2Sp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YPAp5kfb, 1, m, &cIf_YPAp5kfb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PZ8qnSFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DER6xM4T, 1, m, &cIf_DER6xM4T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_b9TGJUh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DER6xM4T, 0, m, &cIf_DER6xM4T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_chB2PW19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PeZ68nL0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5UeVYxw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PeZ68nL0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_QsJADSUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zTlxaWEI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_e0yf6qdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_97u0rt1Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fuAMQHSs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FNTIJHPV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FNTIJHPV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9A0y5OM9, 1, m, &cDelay_9A0y5OM9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lCaqFcB9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9A0y5OM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9A0y5OM9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QsJADSUR, 0, m, &cIf_QsJADSUR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FNTIJHPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9A0y5OM9, 0, m, &cDelay_9A0y5OM9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lCaqFcB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9A0y5OM9, 0, m, &cDelay_9A0y5OM9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_r0BwKYHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CYJi82QA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tw8yQyNv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SbDAeUiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0KxmVlPk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z4H6scZd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z4H6scZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fuAMQHSs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0KxmVlPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QsJADSUR, 1, m, &cIf_QsJADSUR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Tw8yQyNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e0yf6qdK, 0, m, &cIf_e0yf6qdK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CYJi82QA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e0yf6qdK, 1, m, &cIf_e0yf6qdK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_97u0rt1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kpWWgThS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zTlxaWEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kpWWgThS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_BU0K9uPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xU5IocaY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_71aky8xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mnjpDL58_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_w4Zb3YSN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UGA1FzTu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UGA1FzTu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cszGMehW, 1, m, &cDelay_cszGMehW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BBuE0aYl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cszGMehW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cszGMehW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BU0K9uPG, 0, m, &cIf_BU0K9uPG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UGA1FzTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cszGMehW, 0, m, &cDelay_cszGMehW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BBuE0aYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cszGMehW, 0, m, &cDelay_cszGMehW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WYNCkV0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EPKWsu7s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LDwHA1cO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dOphPw4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yG5pCw7F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4ynJWAhw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4ynJWAhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_w4Zb3YSN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yG5pCw7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BU0K9uPG, 1, m, &cIf_BU0K9uPG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EPKWsu7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_71aky8xr, 1, m, &cIf_71aky8xr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LDwHA1cO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_71aky8xr, 0, m, &cIf_71aky8xr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mnjpDL58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Kq8SVdah, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xU5IocaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Kq8SVdah, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_nvvVMjOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_paCjIYjx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_GmRSVEKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z6CTa62J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eagECv3I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_pNNoq2bB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_pNNoq2bB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5qxtXYEh, 1, m, &cDelay_5qxtXYEh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jpX5TEC1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5qxtXYEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5qxtXYEh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_nvvVMjOL, 0, m, &cIf_nvvVMjOL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pNNoq2bB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5qxtXYEh, 0, m, &cDelay_5qxtXYEh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jpX5TEC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5qxtXYEh, 0, m, &cDelay_5qxtXYEh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pXZAgYn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aOMIeTSM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F9b916ba_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_l0CLmQD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hBBGCrwc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NPrMB8HL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hBBGCrwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nvvVMjOL, 1, m, &cIf_nvvVMjOL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NPrMB8HL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eagECv3I_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_aOMIeTSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GmRSVEKU, 1, m, &cIf_GmRSVEKU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F9b916ba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GmRSVEKU, 0, m, &cIf_GmRSVEKU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z6CTa62J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oEJdvk0D, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_paCjIYjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oEJdvk0D, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_hTDLCVTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PvvdLQto_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_D9fVLEH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eCUIFwU5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_a1PYq0bP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AEhrbmVR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AEhrbmVR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZoLsSey8, 1, m, &cDelay_ZoLsSey8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yWrJlpxs_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZoLsSey8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZoLsSey8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_hTDLCVTZ, 0, m, &cIf_hTDLCVTZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AEhrbmVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZoLsSey8, 0, m, &cDelay_ZoLsSey8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yWrJlpxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZoLsSey8, 0, m, &cDelay_ZoLsSey8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SfiSplH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kPIMpllY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C5K85dei_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5ktiUAK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kRWNtpo7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nzhltEyV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kRWNtpo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hTDLCVTZ, 1, m, &cIf_hTDLCVTZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nzhltEyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_a1PYq0bP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_C5K85dei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D9fVLEH2, 0, m, &cIf_D9fVLEH2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kPIMpllY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D9fVLEH2, 1, m, &cIf_D9fVLEH2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eCUIFwU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DCFer1Zt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PvvdLQto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DCFer1Zt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_oA8lNfYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_KrHVobN8_sendMessage(_c, 0, m);
  cMsg_UYFIvuso_sendMessage(_c, 0, m);
  cMsg_P2hg8VHq_sendMessage(_c, 0, m);
  cMsg_lWElmY4L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kUvU5Ply_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_KrHVobN8_sendMessage(_c, 0, m);
  cMsg_v3qqTdWe_sendMessage(_c, 0, m);
  cMsg_GIZRwSrP_sendMessage(_c, 0, m);
  cMsg_uvMfKMQS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TA8J9Q2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_y3XFBN2Q_sendMessage(_c, 0, m);
  cMsg_v3qqTdWe_sendMessage(_c, 0, m);
  cMsg_lWElmY4L_sendMessage(_c, 0, m);
  cMsg_TzSgfIph_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_m3oUJgAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_y3XFBN2Q_sendMessage(_c, 0, m);
  cMsg_JlILyCUC_sendMessage(_c, 0, m);
  cMsg_P2hg8VHq_sendMessage(_c, 0, m);
  cMsg_CbimCb7v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nuXV0fUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_YByja1Zl_sendMessage(_c, 0, m);
  cMsg_uvMfKMQS_sendMessage(_c, 0, m);
  cMsg_kMT0uksK_sendMessage(_c, 0, m);
  cMsg_P2hg8VHq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Y59KIjx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_YByja1Zl_sendMessage(_c, 0, m);
  cMsg_CbimCb7v_sendMessage(_c, 0, m);
  cMsg_v3qqTdWe_sendMessage(_c, 0, m);
  cMsg_PCxcHZQv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_g9nJCBZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_brbJfXkP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R2MPl8iP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LfCSnF6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_brbJfXkP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R2MPl8iP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NFqRNWAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_D0JDvlEd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MGsX40RQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_G44gDkU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_D0JDvlEd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MGsX40RQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_brLMqvUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4KlbmsjK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xz6sKkbf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qe0n5DSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4KlbmsjK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xz6sKkbf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KrHVobN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_g9nJCBZt_sendMessage(_c, 0, m);
  cMsg_G44gDkU5_sendMessage(_c, 0, m);
  cMsg_qe0n5DSC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_y3XFBN2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_LfCSnF6G_sendMessage(_c, 0, m);
  cMsg_NFqRNWAK_sendMessage(_c, 0, m);
  cMsg_qe0n5DSC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YByja1Zl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_LfCSnF6G_sendMessage(_c, 0, m);
  cMsg_G44gDkU5_sendMessage(_c, 0, m);
  cMsg_brLMqvUs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Oi1cV6cU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_srIhp1SP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Tqqw2Ihe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0HLwzPQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_srIhp1SP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Tqqw2Ihe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Zpb3xrR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hRowYnwK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_y1T7DonS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pomaVpdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hRowYnwK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_y1T7DonS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CZLI6tyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WCZm7aEw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KC9UlgwA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xRmrvKdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WCZm7aEw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KC9UlgwA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_v3qqTdWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_0HLwzPQ9_sendMessage(_c, 0, m);
  cMsg_pomaVpdZ_sendMessage(_c, 0, m);
  cMsg_xRmrvKdB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UYFIvuso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_0HLwzPQ9_sendMessage(_c, 0, m);
  cMsg_Zpb3xrR6_sendMessage(_c, 0, m);
  cMsg_CZLI6tyn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JlILyCUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Oi1cV6cU_sendMessage(_c, 0, m);
  cMsg_pomaVpdZ_sendMessage(_c, 0, m);
  cMsg_CZLI6tyn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v9DV6orC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dOphPw4b_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WYNCkV0S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Pby9mKcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dOphPw4b_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WYNCkV0S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a22U1X5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_l0CLmQD7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pXZAgYn7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5SgeVJhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_l0CLmQD7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pXZAgYn7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3x9EOgVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5ktiUAK4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SfiSplH7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2zud9xJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5ktiUAK4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SfiSplH7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CbimCb7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_v9DV6orC_sendMessage(_c, 0, m);
  cMsg_5SgeVJhy_sendMessage(_c, 0, m);
  cMsg_2zud9xJw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uvMfKMQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Pby9mKcb_sendMessage(_c, 0, m);
  cMsg_a22U1X5c_sendMessage(_c, 0, m);
  cMsg_2zud9xJw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lWElmY4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Pby9mKcb_sendMessage(_c, 0, m);
  cMsg_5SgeVJhy_sendMessage(_c, 0, m);
  cMsg_3x9EOgVt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DrrHPfCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TnNsoU3q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hnugq8iQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uzuK7AaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TnNsoU3q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hnugq8iQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bHJF7xcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Gjeu0mJA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GL67ewH6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_reLL50FW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Gjeu0mJA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GL67ewH6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_my9jDrqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SbDAeUiG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_r0BwKYHB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rU9QZZsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SbDAeUiG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_r0BwKYHB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P2hg8VHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_uzuK7AaB_sendMessage(_c, 0, m);
  cMsg_reLL50FW_sendMessage(_c, 0, m);
  cMsg_rU9QZZsU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GIZRwSrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_uzuK7AaB_sendMessage(_c, 0, m);
  cMsg_bHJF7xcL_sendMessage(_c, 0, m);
  cMsg_my9jDrqN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PCxcHZQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_DrrHPfCe_sendMessage(_c, 0, m);
  cMsg_bHJF7xcL_sendMessage(_c, 0, m);
  cMsg_rU9QZZsU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kMT0uksK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Oi1cV6cU_sendMessage(_c, 0, m);
  cMsg_Zpb3xrR6_sendMessage(_c, 0, m);
  cMsg_xRmrvKdB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TzSgfIph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_DrrHPfCe_sendMessage(_c, 0, m);
  cMsg_reLL50FW_sendMessage(_c, 0, m);
  cMsg_my9jDrqN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_FgTZUTEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NyM8um6B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DSbKg81A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9ho5q8Os, 0, m, &cSlice_9ho5q8Os_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tglLeOIk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_9ho5q8Os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NWXg2xmk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NWXg2xmk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ldE3Q1Zn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NWXg2xmk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_NWXg2xmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_buKmobAq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VF5Bv13g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ThpYd2p9, 0, m, &cSlice_ThpYd2p9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QgoIW4n0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ThpYd2p9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JezCQs7E_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JezCQs7E_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_g3AOIQIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JezCQs7E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_JezCQs7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YSEeMLRd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QgoIW4n0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ygn9EupI, 0, m, &cSlice_Ygn9EupI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DSbKg81A_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Ygn9EupI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZGBL4Ma3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZGBL4Ma3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_dnoq2Mxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZGBL4Ma3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ZGBL4Ma3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZNWPdZzq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tglLeOIk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_j7YgrDlm, 0, m, &cSlice_j7YgrDlm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KMuMBp9g_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_j7YgrDlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LPiiM2v4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LPiiM2v4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_2O6aAxGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LPiiM2v4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_LPiiM2v4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NQAMC6HN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KMuMBp9g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xzn1TyT4, 0, m, &cSlice_xzn1TyT4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OrlWiXI7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_xzn1TyT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Uwi5nN7e_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Uwi5nN7e_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_dK3cdWzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Uwi5nN7e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Uwi5nN7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lXi7S3nW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QghxSnnE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SCQaZQKr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SCQaZQKr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JsohWWzs, 1, m, &cDelay_JsohWWzs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ozaqm1OR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JsohWWzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JsohWWzs, m);
  cMsg_8uqZBwzM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SCQaZQKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JsohWWzs, 0, m, &cDelay_JsohWWzs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ozaqm1OR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JsohWWzs, 0, m, &cDelay_JsohWWzs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_0wywwvxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uOi9ZIMs, HV_BINOP_SUBTRACT, 0, m, &cBinop_uOi9ZIMs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_fKoyWmvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oUiOnZnh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6icOhj9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oUiOnZnh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_qAkugdHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0wywwvxr, 0, m, &cVar_0wywwvxr_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_MreXH6Qx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jokeTNxk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rPdFfMco_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JyHiraDW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uOi9ZIMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RP4MIqMX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RP4MIqMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_W5dgCXsO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_W5dgCXsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Dqp1GYf5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BRvIDmru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JiJ43YMv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3atpjXCl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3atpjXCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Sg4F9JPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JiJ43YMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fKoyWmvr, 1, m, &cIf_fKoyWmvr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_q3gNy4O0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6icOhj9u, 1, m, &cIf_6icOhj9u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Sg4F9JPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_fKoyWmvr, 0, m, &cIf_fKoyWmvr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Dqp1GYf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6icOhj9u, 0, m, &cIf_6icOhj9u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JyHiraDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0wywwvxr, 0, m, &cVar_0wywwvxr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jokeTNxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_rPdFfMco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uOi9ZIMs, HV_BINOP_SUBTRACT, 1, m, &cBinop_uOi9ZIMs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oUiOnZnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8lY7pmEO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OrlWiXI7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lo2G1fsS, 0, m, &cSlice_lo2G1fsS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_lo2G1fsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VUfYROHD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VUfYROHD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_FV04Yu3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VUfYROHD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_VUfYROHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_r62zN5ho_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rSsr0ISz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5smm3uys, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NbHFKcK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mgNQz2wB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_GQ5sItRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_INk5qCLj, 0, m, &cVar_INk5qCLj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NyM8um6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KGoc2gO8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_beI8Z9Hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QghxSnnE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RUxxJ8sJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mXHp1JVA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8uqZBwzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i4hPeZLV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mXHp1JVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i4hPeZLV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9DlkFBpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_ICBzdOUy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ICBzdOUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JkwjoKeO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JkwjoKeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oLC9ICoz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_x6CHYP3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JJHKT0iC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_N4PXmiJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fKvHumLD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pEbZh8fY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HBT4lVMK_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Sjl1jDnA_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nexLlF9u_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XKDl4IsW_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dL9K6mLy_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8GJ3HuAq_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_HBT4lVMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aWcZwvuU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Sjl1jDnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_83Qous15_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_nexLlF9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KTdwRBmc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_XKDl4IsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xzhm6bJ1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_dL9K6mLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VdvFHqlI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8GJ3HuAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nyvGsVl3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_lbQ0FUc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_h1HDVv68_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UhQM3MMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Lm8Q0e3D_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_77DNDjyk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_96oniJ3N_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_96oniJ3N_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_23854Z6I, 1, m, &cDelay_23854Z6I_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j094QhFW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_23854Z6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_23854Z6I, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lbQ0FUc8, 0, m, &cIf_lbQ0FUc8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_96oniJ3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_23854Z6I, 0, m, &cDelay_23854Z6I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j094QhFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_23854Z6I, 0, m, &cDelay_23854Z6I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ejd5hbwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bxDGLhyI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kroxe6uY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Lri225ZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GWoHTkzH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ySJHWHz8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ySJHWHz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_77DNDjyk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GWoHTkzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lbQ0FUc8, 1, m, &cIf_lbQ0FUc8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bxDGLhyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UhQM3MMz, 1, m, &cIf_UhQM3MMz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Kroxe6uY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UhQM3MMz, 0, m, &cIf_UhQM3MMz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Lm8Q0e3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XH0IeQDf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_h1HDVv68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XH0IeQDf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Lq9XtWdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SnnEXHmD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_OPWS1TaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TxwStQRL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8BWziDiN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wMO16XE7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wMO16XE7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_um5nrtk2, 1, m, &cDelay_um5nrtk2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7jFnac3e_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_um5nrtk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_um5nrtk2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Lq9XtWdV, 0, m, &cIf_Lq9XtWdV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wMO16XE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_um5nrtk2, 0, m, &cDelay_um5nrtk2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7jFnac3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_um5nrtk2, 0, m, &cDelay_um5nrtk2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2QRfHse5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W73DfQgD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xc5vBfXZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gK4YYx5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ekFJYEjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wRtVJGkN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wRtVJGkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8BWziDiN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ekFJYEjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Lq9XtWdV, 1, m, &cIf_Lq9XtWdV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xc5vBfXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OPWS1TaZ, 0, m, &cIf_OPWS1TaZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W73DfQgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OPWS1TaZ, 1, m, &cIf_OPWS1TaZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TxwStQRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Yi1vWqsP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SnnEXHmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Yi1vWqsP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_h3Pi8nmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FRpPjm5k_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_6NaHuRRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DziODJzO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rTD1F4Bj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4mZilFeM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4mZilFeM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_G8PJHFoF, 1, m, &cDelay_G8PJHFoF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AuntpXBe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_G8PJHFoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_G8PJHFoF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_h3Pi8nmP, 0, m, &cIf_h3Pi8nmP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4mZilFeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_G8PJHFoF, 0, m, &cDelay_G8PJHFoF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AuntpXBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_G8PJHFoF, 0, m, &cDelay_G8PJHFoF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i2gOrs3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u63PZ5xg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eMM5JJv3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_W1tl6o7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GvroK9pw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v0nR4avU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GvroK9pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h3Pi8nmP, 1, m, &cIf_h3Pi8nmP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v0nR4avU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rTD1F4Bj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_u63PZ5xg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6NaHuRRU, 1, m, &cIf_6NaHuRRU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eMM5JJv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6NaHuRRU, 0, m, &cIf_6NaHuRRU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DziODJzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a1nJuZC0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FRpPjm5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a1nJuZC0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gmNl9GBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CRGGePcC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3Ysq66gQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z9eyYKgb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oct3oN5v_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bFXFNCJT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bFXFNCJT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YFvEkRlx, 1, m, &cDelay_YFvEkRlx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A9jjJMLk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_YFvEkRlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YFvEkRlx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gmNl9GBg, 0, m, &cIf_gmNl9GBg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bFXFNCJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YFvEkRlx, 0, m, &cDelay_YFvEkRlx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A9jjJMLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YFvEkRlx, 0, m, &cDelay_YFvEkRlx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1jNZj37d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sLgjmJkT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y5lB6eCC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U5y9y6Zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yIjWTFMn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n5P6Cq2L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n5P6Cq2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oct3oN5v_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yIjWTFMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gmNl9GBg, 1, m, &cIf_gmNl9GBg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y5lB6eCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3Ysq66gQ, 0, m, &cIf_3Ysq66gQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sLgjmJkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3Ysq66gQ, 1, m, &cIf_3Ysq66gQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z9eyYKgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fN9h9Lx5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CRGGePcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fN9h9Lx5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_C4mP7cj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tgnRZkS7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_OAcSMEhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NV46paxx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_b2sELwFj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yhUTNLVL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yhUTNLVL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9Pzf5TSK, 1, m, &cDelay_9Pzf5TSK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_48AIuImk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9Pzf5TSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9Pzf5TSK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_C4mP7cj3, 0, m, &cIf_C4mP7cj3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yhUTNLVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9Pzf5TSK, 0, m, &cDelay_9Pzf5TSK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_48AIuImk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9Pzf5TSK, 0, m, &cDelay_9Pzf5TSK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_be0Bc8d3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8tuiTkAI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mUWbCCxF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eZLxeNel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pgF6y0PK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7TzkIntM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7TzkIntM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_b2sELwFj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_pgF6y0PK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_C4mP7cj3, 1, m, &cIf_C4mP7cj3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mUWbCCxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OAcSMEhg, 0, m, &cIf_OAcSMEhg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8tuiTkAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OAcSMEhg, 1, m, &cIf_OAcSMEhg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NV46paxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wP6x3Sra, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tgnRZkS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wP6x3Sra, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aWWDveOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JgIt1i4G_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_U8mJiZAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fvqqFhrY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XqHNISU8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FRJYwII2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FRJYwII2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6av11oF2, 1, m, &cDelay_6av11oF2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rWzFLWxW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6av11oF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6av11oF2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aWWDveOz, 0, m, &cIf_aWWDveOz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FRJYwII2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6av11oF2, 0, m, &cDelay_6av11oF2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rWzFLWxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6av11oF2, 0, m, &cDelay_6av11oF2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uUhyCgth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cK5KTpzL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tigx8bss_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UOy8cAPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NJMzCHZT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nq3xiUfM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nq3xiUfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XqHNISU8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NJMzCHZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aWWDveOz, 1, m, &cIf_aWWDveOz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cK5KTpzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U8mJiZAf, 1, m, &cIf_U8mJiZAf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tigx8bss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U8mJiZAf, 0, m, &cIf_U8mJiZAf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fvqqFhrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XcxZUoBe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JgIt1i4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XcxZUoBe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7OPl6aOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_q1CqKpXD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_U5Lfx6Cz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_npvRtTle_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6b9tTSpm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wXdo0CKa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wXdo0CKa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JRxPvkCz, 1, m, &cDelay_JRxPvkCz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z1iN4WGs_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JRxPvkCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JRxPvkCz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7OPl6aOJ, 0, m, &cIf_7OPl6aOJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wXdo0CKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JRxPvkCz, 0, m, &cDelay_JRxPvkCz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z1iN4WGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JRxPvkCz, 0, m, &cDelay_JRxPvkCz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_brihBwd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JDPExkpi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jWXj91Ch_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YPprDdkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AAPClWmR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y8nrsqys_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y8nrsqys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6b9tTSpm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_AAPClWmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7OPl6aOJ, 1, m, &cIf_7OPl6aOJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JDPExkpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U5Lfx6Cz, 1, m, &cIf_U5Lfx6Cz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jWXj91Ch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U5Lfx6Cz, 0, m, &cIf_U5Lfx6Cz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_npvRtTle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FULWliam, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_q1CqKpXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FULWliam, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_KvdBKvjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TeZzfOxv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2eSpv0TO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rFHCWNq0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mf6jkHz5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yEojNG6s_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yEojNG6s_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_k9Ix5TtP, 1, m, &cDelay_k9Ix5TtP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IYmhofFX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_k9Ix5TtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_k9Ix5TtP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KvdBKvjg, 0, m, &cIf_KvdBKvjg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yEojNG6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_k9Ix5TtP, 0, m, &cDelay_k9Ix5TtP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IYmhofFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_k9Ix5TtP, 0, m, &cDelay_k9Ix5TtP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sikHtKOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rLgD5IUe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EE8ql1N7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_t8aFKw9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nrM7lpZr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KBuBF6fP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KBuBF6fP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mf6jkHz5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nrM7lpZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KvdBKvjg, 1, m, &cIf_KvdBKvjg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EE8ql1N7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2eSpv0TO, 0, m, &cIf_2eSpv0TO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rLgD5IUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2eSpv0TO, 1, m, &cIf_2eSpv0TO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rFHCWNq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JWvkgLMc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TeZzfOxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JWvkgLMc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9tOl4wMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qVyfrTww_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JS8jNpJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g6Wnf7pp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JPsDJhdi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_e3JJ4mCb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_e3JJ4mCb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Co9qbbRm, 1, m, &cDelay_Co9qbbRm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TWc0VVsl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Co9qbbRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Co9qbbRm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9tOl4wMV, 0, m, &cIf_9tOl4wMV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e3JJ4mCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Co9qbbRm, 0, m, &cDelay_Co9qbbRm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TWc0VVsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Co9qbbRm, 0, m, &cDelay_Co9qbbRm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Qin6TRDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RiRFhhst_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ir8vtZwF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZBIAnowE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HndICwIN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V69VguI5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V69VguI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JPsDJhdi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HndICwIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9tOl4wMV, 1, m, &cIf_9tOl4wMV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ir8vtZwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JS8jNpJS, 0, m, &cIf_JS8jNpJS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RiRFhhst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JS8jNpJS, 1, m, &cIf_JS8jNpJS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g6Wnf7pp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q8T1drzt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qVyfrTww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q8T1drzt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_wtvv98xt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9J4WIP8Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kEvCFjUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YY5CqCKC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mKar1xJ0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_m7kItQl5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_m7kItQl5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZG3a0Exm, 1, m, &cDelay_ZG3a0Exm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TF4KWL0W_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZG3a0Exm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZG3a0Exm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wtvv98xt, 0, m, &cIf_wtvv98xt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m7kItQl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZG3a0Exm, 0, m, &cDelay_ZG3a0Exm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TF4KWL0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZG3a0Exm, 0, m, &cDelay_ZG3a0Exm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XPmNHDnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XqYUwKAT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S6rw0V4u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n89BRETZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_421RGKPd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m0lQnDdo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_m0lQnDdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mKar1xJ0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_421RGKPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wtvv98xt, 1, m, &cIf_wtvv98xt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S6rw0V4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kEvCFjUH, 0, m, &cIf_kEvCFjUH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XqYUwKAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kEvCFjUH, 1, m, &cIf_kEvCFjUH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YY5CqCKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PF2SkrMm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9J4WIP8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PF2SkrMm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NiJryKaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2FdUL1n0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1F9BGED5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XXVI8CmX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GmmD7TW5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YpkMLJSJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YpkMLJSJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_py0gL3Rx, 1, m, &cDelay_py0gL3Rx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q9857R6p_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_py0gL3Rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_py0gL3Rx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NiJryKaN, 0, m, &cIf_NiJryKaN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YpkMLJSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_py0gL3Rx, 0, m, &cDelay_py0gL3Rx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q9857R6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_py0gL3Rx, 0, m, &cDelay_py0gL3Rx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Amjqurlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zGUvd8ot_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2MCb6RlY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lFwJtZgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u2iWIksG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FcZqvrhW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FcZqvrhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GmmD7TW5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_u2iWIksG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NiJryKaN, 1, m, &cIf_NiJryKaN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2MCb6RlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1F9BGED5, 0, m, &cIf_1F9BGED5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zGUvd8ot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1F9BGED5, 1, m, &cIf_1F9BGED5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XXVI8CmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PT2VAXku, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2FdUL1n0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PT2VAXku, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_n5pt10K4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DxdlDh14_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KhE6shqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2RxdsonR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_d0zXlVxm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4ieltWUu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4ieltWUu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_f1RPImUs, 1, m, &cDelay_f1RPImUs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3ulF62Az_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_f1RPImUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_f1RPImUs, m);
  cIf_onMessage(_c, &Context(_c)->cIf_n5pt10K4, 0, m, &cIf_n5pt10K4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4ieltWUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_f1RPImUs, 0, m, &cDelay_f1RPImUs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3ulF62Az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_f1RPImUs, 0, m, &cDelay_f1RPImUs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HBgomiss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0EA4xf8T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eQayII0Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kZS44RyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yutjXjn0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_INCes8up_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_INCes8up_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_d0zXlVxm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yutjXjn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n5pt10K4, 1, m, &cIf_n5pt10K4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0EA4xf8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KhE6shqq, 1, m, &cIf_KhE6shqq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eQayII0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KhE6shqq, 0, m, &cIf_KhE6shqq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2RxdsonR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TelBcEjD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DxdlDh14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TelBcEjD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aWcZwvuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_YdUHBylO_sendMessage(_c, 0, m);
  cMsg_p2Lx9DTJ_sendMessage(_c, 0, m);
  cMsg_lhxHqrjZ_sendMessage(_c, 0, m);
  cMsg_kxtt9j8V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_83Qous15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_YdUHBylO_sendMessage(_c, 0, m);
  cMsg_ekONnDQ7_sendMessage(_c, 0, m);
  cMsg_qJzRyZAC_sendMessage(_c, 0, m);
  cMsg_AdCe2zoO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KTdwRBmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_Xf8iv0v2_sendMessage(_c, 0, m);
  cMsg_ekONnDQ7_sendMessage(_c, 0, m);
  cMsg_kxtt9j8V_sendMessage(_c, 0, m);
  cMsg_eO8CeHAX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Xzhm6bJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_Xf8iv0v2_sendMessage(_c, 0, m);
  cMsg_W2lIVvQ9_sendMessage(_c, 0, m);
  cMsg_lhxHqrjZ_sendMessage(_c, 0, m);
  cMsg_qfkbzB99_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VdvFHqlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_ovNizDrE_sendMessage(_c, 0, m);
  cMsg_AdCe2zoO_sendMessage(_c, 0, m);
  cMsg_8BgpOYzE_sendMessage(_c, 0, m);
  cMsg_lhxHqrjZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nyvGsVl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_ovNizDrE_sendMessage(_c, 0, m);
  cMsg_qfkbzB99_sendMessage(_c, 0, m);
  cMsg_ekONnDQ7_sendMessage(_c, 0, m);
  cMsg_nku2c83q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_y5aZjJ7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Lri225ZV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ejd5hbwo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QqBhVKMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Lri225ZV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ejd5hbwo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vs6g5rpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gK4YYx5g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2QRfHse5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3IZgiNfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gK4YYx5g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2QRfHse5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M9QzkpSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W1tl6o7W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_i2gOrs3a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aypPUoh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W1tl6o7W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_i2gOrs3a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YdUHBylO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_y5aZjJ7F_sendMessage(_c, 0, m);
  cMsg_3IZgiNfk_sendMessage(_c, 0, m);
  cMsg_aypPUoh8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Xf8iv0v2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_QqBhVKMm_sendMessage(_c, 0, m);
  cMsg_vs6g5rpT_sendMessage(_c, 0, m);
  cMsg_aypPUoh8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ovNizDrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_QqBhVKMm_sendMessage(_c, 0, m);
  cMsg_3IZgiNfk_sendMessage(_c, 0, m);
  cMsg_M9QzkpSF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ROTGVguZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U5y9y6Zf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1jNZj37d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pS3jZgb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U5y9y6Zf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1jNZj37d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gk1iR7Zn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eZLxeNel_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_be0Bc8d3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rWRzeW6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eZLxeNel_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_be0Bc8d3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_y6Qz2kmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UOy8cAPg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uUhyCgth_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cujQHASm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UOy8cAPg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uUhyCgth_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ekONnDQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_pS3jZgb8_sendMessage(_c, 0, m);
  cMsg_rWRzeW6a_sendMessage(_c, 0, m);
  cMsg_cujQHASm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_p2Lx9DTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_pS3jZgb8_sendMessage(_c, 0, m);
  cMsg_gk1iR7Zn_sendMessage(_c, 0, m);
  cMsg_y6Qz2kmN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_W2lIVvQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_ROTGVguZ_sendMessage(_c, 0, m);
  cMsg_rWRzeW6a_sendMessage(_c, 0, m);
  cMsg_y6Qz2kmN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UXSFaPKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n89BRETZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XPmNHDnI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yz48MuLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_n89BRETZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XPmNHDnI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sioHb4Iy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lFwJtZgn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Amjqurlf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nfqM0g8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lFwJtZgn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Amjqurlf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZIqjOlr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kZS44RyH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HBgomiss_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lVUS0M85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kZS44RyH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HBgomiss_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qfkbzB99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_UXSFaPKy_sendMessage(_c, 0, m);
  cMsg_nfqM0g8i_sendMessage(_c, 0, m);
  cMsg_lVUS0M85_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AdCe2zoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_yz48MuLs_sendMessage(_c, 0, m);
  cMsg_sioHb4Iy_sendMessage(_c, 0, m);
  cMsg_lVUS0M85_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kxtt9j8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_yz48MuLs_sendMessage(_c, 0, m);
  cMsg_nfqM0g8i_sendMessage(_c, 0, m);
  cMsg_ZIqjOlr0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_L00S0sAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YPprDdkd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_brihBwd1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Srgy2u9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YPprDdkd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_brihBwd1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XXnHSgsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t8aFKw9A_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sikHtKOs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CQQ0j7Lq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t8aFKw9A_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sikHtKOs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XymL1j2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZBIAnowE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Qin6TRDb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b7yFjYWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZBIAnowE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Qin6TRDb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lhxHqrjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_Srgy2u9N_sendMessage(_c, 0, m);
  cMsg_CQQ0j7Lq_sendMessage(_c, 0, m);
  cMsg_b7yFjYWC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qJzRyZAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_Srgy2u9N_sendMessage(_c, 0, m);
  cMsg_XXnHSgsg_sendMessage(_c, 0, m);
  cMsg_XymL1j2M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nku2c83q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_L00S0sAU_sendMessage(_c, 0, m);
  cMsg_XXnHSgsg_sendMessage(_c, 0, m);
  cMsg_b7yFjYWC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8BgpOYzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_ROTGVguZ_sendMessage(_c, 0, m);
  cMsg_gk1iR7Zn_sendMessage(_c, 0, m);
  cMsg_cujQHASm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eO8CeHAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_L00S0sAU_sendMessage(_c, 0, m);
  cMsg_CQQ0j7Lq_sendMessage(_c, 0, m);
  cMsg_XymL1j2M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_xSoLrUUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f07ZGTtz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_sO7NV2k0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NhpWiwTB, 0, m, &cSlice_NhpWiwTB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_W7BxSCrw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_NhpWiwTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qnaDHQI0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qnaDHQI0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_fIaf4rbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qnaDHQI0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_qnaDHQI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OTH86ad0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XdoXq2yW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_B4fW84TQ, 0, m, &cSlice_B4fW84TQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MrFzRs9t_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_B4fW84TQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3BCcI0i6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3BCcI0i6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_UXaRNwA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3BCcI0i6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_3BCcI0i6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jxQ3tW8q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MrFzRs9t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_npu5di1v, 0, m, &cSlice_npu5di1v_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sO7NV2k0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_npu5di1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tLgRtFVA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tLgRtFVA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_CumDOwN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tLgRtFVA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_tLgRtFVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WgUFlBb4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_W7BxSCrw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5FQDAHGo, 0, m, &cSlice_5FQDAHGo_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vQ3nKTDe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_5FQDAHGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TyIaHzU1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TyIaHzU1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_W9eu0r0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TyIaHzU1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_TyIaHzU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CbuxReZm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vQ3nKTDe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UchwlgD6, 0, m, &cSlice_UchwlgD6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QYbKgkzq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_UchwlgD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_z4QLCEnU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_z4QLCEnU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_7UMeH7XZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z4QLCEnU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_z4QLCEnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jpewozst_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Wg3NHTtn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CfSRXiWi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CfSRXiWi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mAvvNq1F, 1, m, &cDelay_mAvvNq1F_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iNfd5lLR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mAvvNq1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mAvvNq1F, m);
  cMsg_0fdepxnp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CfSRXiWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mAvvNq1F, 0, m, &cDelay_mAvvNq1F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iNfd5lLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mAvvNq1F, 0, m, &cDelay_mAvvNq1F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_pTtnjxvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JquAuloa, HV_BINOP_SUBTRACT, 0, m, &cBinop_JquAuloa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_3pKBn5Tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TQflJLwN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_EXyBVVsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TQflJLwN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_hmUkP2Ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pTtnjxvY, 0, m, &cVar_pTtnjxvY_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_ebKDkGXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zddye2yG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4cJRBlmF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lcMJpbsc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JquAuloa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m9oAwakl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_m9oAwakl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_of0la03y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_of0la03y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_PVSZPucc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sOf7BLbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PmyaEyZK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oDtUM5Pw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oDtUM5Pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0XGcmKle_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_PmyaEyZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3pKBn5Tg, 1, m, &cIf_3pKBn5Tg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Bfoj3Y2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EXyBVVsY, 1, m, &cIf_EXyBVVsY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0XGcmKle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_3pKBn5Tg, 0, m, &cIf_3pKBn5Tg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PVSZPucc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EXyBVVsY, 0, m, &cIf_EXyBVVsY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lcMJpbsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pTtnjxvY, 0, m, &cVar_pTtnjxvY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4cJRBlmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JquAuloa, HV_BINOP_SUBTRACT, 1, m, &cBinop_JquAuloa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Zddye2yG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_TQflJLwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BRne8ebW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QYbKgkzq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_juFA9c5d, 0, m, &cSlice_juFA9c5d_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_juFA9c5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OWyd0NgL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OWyd0NgL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_JHS3EFcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OWyd0NgL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_OWyd0NgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CLUbQ7tI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JJHKT0iC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0nzR12Ez, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fKvHumLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VFyCHDbY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_pJGYsJDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N4PXmiJ4, 0, m, &cVar_N4PXmiJ4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_f07ZGTtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e8vwUzJi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_lxIqT538_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Wg3NHTtn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_D76GdFHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DMu9c9AF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0fdepxnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1QPlyaGk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DMu9c9AF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1QPlyaGk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GPEBTwf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_0XHWaeqv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0XHWaeqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e9rToRI4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_e9rToRI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eby9Jmzw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_fslb5WnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lEDMPxe7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_FvuSbhK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Iyeh0vcO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ono9UQZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6J3I4rQW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_q8LN79Z0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NBY3uasp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_PJTtsY4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_np3JJ9JN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ee91MX7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u7gMfr23_sendMessage);
  cMsg_KeO97LBD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_u7gMfr23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ee91MX7t, 1, m, &cVar_ee91MX7t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E1wnfJiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tJ4i5liv_sendMessage(_c, 0, m);
  cMsg_dggzknMJ_sendMessage(_c, 0, m);
  cMsg_7Z7CSnP8_sendMessage(_c, 0, m);
  cMsg_2Wye3nxK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tiNoSK0l_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RzkyzxxI, 0, m, &cSlice_RzkyzxxI_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_RzkyzxxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5lCGJ37K_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5lCGJ37K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_YS1EdWcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5lCGJ37K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5lCGJ37K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_abNkLBHX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ZgRgYsMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_sWLhMt4q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sWLhMt4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_K9rWGRCG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_K9rWGRCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_OIiKBXha_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OIiKBXha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KP308sxI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WWKi3xQ4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WWKi3xQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lMaaRrOa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_KP308sxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pC79goX9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pC79goX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0DnFkq3D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lMaaRrOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kIUe8Jnu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kIUe8Jnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LXd3KIau_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0DnFkq3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SuxZp3h7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_LXd3KIau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m7LehvPV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SuxZp3h7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qmr728aw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_m7LehvPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OsuoYFFi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_uypG5CEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7OlGZCno_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_D2FYpSAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k93cvNoy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Mfn2Lvjg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GW2HsbcS_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zyIauLbM_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8qbgHbeK_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zQk84Arb_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fORPakxQ_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FpVRAvwP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_GW2HsbcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FU1i0CQx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_zyIauLbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5GT5Xp0t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8qbgHbeK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dmWR34E8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_zQk84Arb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_86VUhQwa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_fORPakxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aObciJJ2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_FpVRAvwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SHwvg4Ct_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_g1fQQDc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_feUIs7W6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FeWE6chi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6o7UHfIp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kfKaNPTC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GgQfNIVm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GgQfNIVm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vUGNhu3q, 1, m, &cDelay_vUGNhu3q_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_76sVgOom_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vUGNhu3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vUGNhu3q, m);
  cIf_onMessage(_c, &Context(_c)->cIf_g1fQQDc5, 0, m, &cIf_g1fQQDc5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GgQfNIVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vUGNhu3q, 0, m, &cDelay_vUGNhu3q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_76sVgOom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vUGNhu3q, 0, m, &cDelay_vUGNhu3q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d7JKnUmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nuDuNljn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_evWHLlPi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4mHo8tdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Iz4qgOMH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HqFylshZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Iz4qgOMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g1fQQDc5, 1, m, &cIf_g1fQQDc5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HqFylshZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kfKaNPTC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_evWHLlPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FeWE6chi, 0, m, &cIf_FeWE6chi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nuDuNljn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FeWE6chi, 1, m, &cIf_FeWE6chi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6o7UHfIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7bHIEkfL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_feUIs7W6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7bHIEkfL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_bpo8iXtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NTJikdzc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IpNgLBAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FfxdXkJS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TVHCTrHX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xqSPFIXf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xqSPFIXf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UsWYwufa, 1, m, &cDelay_UsWYwufa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0J2j101Q_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UsWYwufa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UsWYwufa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bpo8iXtN, 0, m, &cIf_bpo8iXtN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xqSPFIXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UsWYwufa, 0, m, &cDelay_UsWYwufa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0J2j101Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UsWYwufa, 0, m, &cDelay_UsWYwufa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UYw4vq2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XaBlmBSm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zzdNdN3S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hJ17aYOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z5tl1Ida_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7t0LQLQa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7t0LQLQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TVHCTrHX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Z5tl1Ida_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bpo8iXtN, 1, m, &cIf_bpo8iXtN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zzdNdN3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IpNgLBAT, 0, m, &cIf_IpNgLBAT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XaBlmBSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IpNgLBAT, 1, m, &cIf_IpNgLBAT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FfxdXkJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VJuCMeM8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NTJikdzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VJuCMeM8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_TuDZ45Ab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cegh4H8U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_sronBJ6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eGnXCnLL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1ZIbQhfb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xjVYLHFQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xjVYLHFQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tSqUAew2, 1, m, &cDelay_tSqUAew2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w41wZL3a_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tSqUAew2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tSqUAew2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_TuDZ45Ab, 0, m, &cIf_TuDZ45Ab_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xjVYLHFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tSqUAew2, 0, m, &cDelay_tSqUAew2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w41wZL3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tSqUAew2, 0, m, &cDelay_tSqUAew2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wC8LA1FB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H0wV7bAM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YrZ2joKG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qesIMhnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vq1b5HRN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_chDerASq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_chDerASq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1ZIbQhfb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vq1b5HRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TuDZ45Ab, 1, m, &cIf_TuDZ45Ab_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H0wV7bAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sronBJ6N, 1, m, &cIf_sronBJ6N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YrZ2joKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sronBJ6N, 0, m, &cIf_sronBJ6N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eGnXCnLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tP959rhQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cegh4H8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tP959rhQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_eiF9JguD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EkLNmtHe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DCnJ5z4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qlfZZsyC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3mRhDAGO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Kr0mNXcI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Kr0mNXcI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pv0750ge, 1, m, &cDelay_pv0750ge_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lwWknln7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_pv0750ge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pv0750ge, m);
  cIf_onMessage(_c, &Context(_c)->cIf_eiF9JguD, 0, m, &cIf_eiF9JguD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Kr0mNXcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pv0750ge, 0, m, &cDelay_pv0750ge_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lwWknln7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pv0750ge, 0, m, &cDelay_pv0750ge_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_82dOfb1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_50FJ4QfD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T2SvVxRk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yLIVA6YW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1NpQ0yRN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T6HbJ8Lj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T6HbJ8Lj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3mRhDAGO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1NpQ0yRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eiF9JguD, 1, m, &cIf_eiF9JguD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_50FJ4QfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DCnJ5z4W, 1, m, &cIf_DCnJ5z4W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T2SvVxRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DCnJ5z4W, 0, m, &cIf_DCnJ5z4W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qlfZZsyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JIawtIJ9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EkLNmtHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JIawtIJ9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ywMRzEwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OHTcZIaa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_H0wMU26S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_timAxTXN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_INaCL3RI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6ItfFv7c_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6ItfFv7c_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GElfUAxj, 1, m, &cDelay_GElfUAxj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IhduCPqw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_GElfUAxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GElfUAxj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ywMRzEwa, 0, m, &cIf_ywMRzEwa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6ItfFv7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GElfUAxj, 0, m, &cDelay_GElfUAxj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IhduCPqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GElfUAxj, 0, m, &cDelay_GElfUAxj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EN1knrR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zYPNpj89_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SI2i7HBk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rXQacK9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xuqtehUI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5jAhoN9O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xuqtehUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ywMRzEwa, 1, m, &cIf_ywMRzEwa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5jAhoN9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_INaCL3RI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SI2i7HBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H0wMU26S, 0, m, &cIf_H0wMU26S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zYPNpj89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H0wMU26S, 1, m, &cIf_H0wMU26S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_timAxTXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SfHBkP6r, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OHTcZIaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SfHBkP6r, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_fHZHyWtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TdkUkfEK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_K2HBqsKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W4PeZcMX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GRWVpdwd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jcenwWNK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jcenwWNK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wxH040F8, 1, m, &cDelay_wxH040F8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_phzWj0uK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_wxH040F8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wxH040F8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fHZHyWtc, 0, m, &cIf_fHZHyWtc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jcenwWNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wxH040F8, 0, m, &cDelay_wxH040F8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_phzWj0uK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wxH040F8, 0, m, &cDelay_wxH040F8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KTIz2Irk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fBQt1V6Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BmTRvPVc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BcTDVeii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4Kr8oh6q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xONyaZOj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xONyaZOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GRWVpdwd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4Kr8oh6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fHZHyWtc, 1, m, &cIf_fHZHyWtc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fBQt1V6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K2HBqsKx, 1, m, &cIf_K2HBqsKx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BmTRvPVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K2HBqsKx, 0, m, &cIf_K2HBqsKx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W4PeZcMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YmM7x51x, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TdkUkfEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YmM7x51x, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_iOG2FP6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z5icEUvB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ORCIqbdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eRJu5zpr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VC9A4iZG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_siCEuWpi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_siCEuWpi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dTrtZIys, 1, m, &cDelay_dTrtZIys_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fHc5Q2G_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_dTrtZIys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dTrtZIys, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iOG2FP6z, 0, m, &cIf_iOG2FP6z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_siCEuWpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dTrtZIys, 0, m, &cDelay_dTrtZIys_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8fHc5Q2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dTrtZIys, 0, m, &cDelay_dTrtZIys_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ETvV5cP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GkfPe6P7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9NrCf1iu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V3FLDFnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lwGQf6Oy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HdprOJU9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HdprOJU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VC9A4iZG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_lwGQf6Oy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iOG2FP6z, 1, m, &cIf_iOG2FP6z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9NrCf1iu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ORCIqbdW, 0, m, &cIf_ORCIqbdW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GkfPe6P7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ORCIqbdW, 1, m, &cIf_ORCIqbdW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eRJu5zpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zdtXr6HK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Z5icEUvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zdtXr6HK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aDU7IhkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jw5noxTM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_SL72uSSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_R1VPgHmm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_axwec2bI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KsZXtd1C_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KsZXtd1C_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FEQ2gfo5, 1, m, &cDelay_FEQ2gfo5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JdIdrleg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_FEQ2gfo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FEQ2gfo5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aDU7IhkA, 0, m, &cIf_aDU7IhkA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KsZXtd1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FEQ2gfo5, 0, m, &cDelay_FEQ2gfo5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JdIdrleg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FEQ2gfo5, 0, m, &cDelay_FEQ2gfo5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fVZ3IhFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Py5r5G7B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TR8OykFf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zNPYPbgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0GJ8bMWG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xIDcCCxV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0GJ8bMWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aDU7IhkA, 1, m, &cIf_aDU7IhkA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xIDcCCxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_axwec2bI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Py5r5G7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SL72uSSr, 1, m, &cIf_SL72uSSr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TR8OykFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SL72uSSr, 0, m, &cIf_SL72uSSr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R1VPgHmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_77Pfx9Ru, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jw5noxTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_77Pfx9Ru, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_snDeV78M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0NYTSmzC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_nVerfcqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KmFoDTPi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XvfZmGz5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qNBInjQV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qNBInjQV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xGpJA8EH, 1, m, &cDelay_xGpJA8EH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qTHkGOVe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xGpJA8EH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xGpJA8EH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_snDeV78M, 0, m, &cIf_snDeV78M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qNBInjQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xGpJA8EH, 0, m, &cDelay_xGpJA8EH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qTHkGOVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xGpJA8EH, 0, m, &cDelay_xGpJA8EH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mQG5LxUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8Dnril39_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M7XIUo0T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VR2649bd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3hzUa6Gd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W1XD36ls_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W1XD36ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XvfZmGz5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3hzUa6Gd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_snDeV78M, 1, m, &cIf_snDeV78M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M7XIUo0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nVerfcqj, 0, m, &cIf_nVerfcqj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8Dnril39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nVerfcqj, 1, m, &cIf_nVerfcqj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KmFoDTPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rNnLTlBK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0NYTSmzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rNnLTlBK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_fL5pm1ge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g4USEEbZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qzQRtgzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6oxYTwVJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2on4KZkk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5k5NnsBs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5k5NnsBs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YOEBMcav, 1, m, &cDelay_YOEBMcav_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_euWXPERs_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_YOEBMcav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YOEBMcav, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fL5pm1ge, 0, m, &cIf_fL5pm1ge_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5k5NnsBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YOEBMcav, 0, m, &cDelay_YOEBMcav_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_euWXPERs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YOEBMcav, 0, m, &cDelay_YOEBMcav_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Hdo2PJx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f9don49v_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6z3A2U75_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ARADQITp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oz1XUljH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D4tVvrb8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oz1XUljH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fL5pm1ge, 1, m, &cIf_fL5pm1ge_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D4tVvrb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2on4KZkk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6z3A2U75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qzQRtgzk, 0, m, &cIf_qzQRtgzk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f9don49v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qzQRtgzk, 1, m, &cIf_qzQRtgzk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6oxYTwVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c83sF4gI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_g4USEEbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c83sF4gI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_oRozDaOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XfflgpaT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_McDXRIzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KEHqxtXe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZwcSqvhl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0AMM2tcY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0AMM2tcY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Dg2Ct1t3, 1, m, &cDelay_Dg2Ct1t3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HXTIw9uC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Dg2Ct1t3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Dg2Ct1t3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oRozDaOe, 0, m, &cIf_oRozDaOe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0AMM2tcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Dg2Ct1t3, 0, m, &cDelay_Dg2Ct1t3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HXTIw9uC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Dg2Ct1t3, 0, m, &cDelay_Dg2Ct1t3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wlPbrIEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X4FMsUcO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cX0hzkp5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_36lKnOmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JNO3liS4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ee8SPnl4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ee8SPnl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZwcSqvhl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JNO3liS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oRozDaOe, 1, m, &cIf_oRozDaOe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cX0hzkp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_McDXRIzr, 0, m, &cIf_McDXRIzr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X4FMsUcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_McDXRIzr, 1, m, &cIf_McDXRIzr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KEHqxtXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LF6U4hlY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XfflgpaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LF6U4hlY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_IejBBXwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5B8t2Xpc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MbBRdao9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KS5PdoG8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DGeT91fQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BesYCZfX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BesYCZfX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4anWcnNC, 1, m, &cDelay_4anWcnNC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EbdFkdxW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4anWcnNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4anWcnNC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_IejBBXwh, 0, m, &cIf_IejBBXwh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BesYCZfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4anWcnNC, 0, m, &cDelay_4anWcnNC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EbdFkdxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4anWcnNC, 0, m, &cDelay_4anWcnNC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7aqVe79B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UHJzHPx9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fg0qWzWC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JysH55G9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mYF1odRL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WjdK1yFv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WjdK1yFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DGeT91fQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mYF1odRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IejBBXwh, 1, m, &cIf_IejBBXwh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fg0qWzWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MbBRdao9, 0, m, &cIf_MbBRdao9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UHJzHPx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MbBRdao9, 1, m, &cIf_MbBRdao9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KS5PdoG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vVVzVcNV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5B8t2Xpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vVVzVcNV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FU1i0CQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_wwvq3v6k_sendMessage(_c, 0, m);
  cMsg_ZPcKhxq9_sendMessage(_c, 0, m);
  cMsg_MqyBMWZo_sendMessage(_c, 0, m);
  cMsg_YSrdRhpV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5GT5Xp0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_wwvq3v6k_sendMessage(_c, 0, m);
  cMsg_AYy9wlGQ_sendMessage(_c, 0, m);
  cMsg_lQNvr3zN_sendMessage(_c, 0, m);
  cMsg_9KIfvnEu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dmWR34E8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_qxzCeB8H_sendMessage(_c, 0, m);
  cMsg_AYy9wlGQ_sendMessage(_c, 0, m);
  cMsg_YSrdRhpV_sendMessage(_c, 0, m);
  cMsg_pW3kAAk4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_86VUhQwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_qxzCeB8H_sendMessage(_c, 0, m);
  cMsg_A0bEHeVt_sendMessage(_c, 0, m);
  cMsg_MqyBMWZo_sendMessage(_c, 0, m);
  cMsg_DyBdya9C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aObciJJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_mm8WwrqO_sendMessage(_c, 0, m);
  cMsg_9KIfvnEu_sendMessage(_c, 0, m);
  cMsg_CJswvDm2_sendMessage(_c, 0, m);
  cMsg_MqyBMWZo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SHwvg4Ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_mm8WwrqO_sendMessage(_c, 0, m);
  cMsg_DyBdya9C_sendMessage(_c, 0, m);
  cMsg_AYy9wlGQ_sendMessage(_c, 0, m);
  cMsg_I2XUMhSE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aOooG5IZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4mHo8tdE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d7JKnUmi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KRg6Q9lo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4mHo8tdE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d7JKnUmi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6YrfM806_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hJ17aYOX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UYw4vq2j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BdLEzH5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hJ17aYOX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UYw4vq2j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ASEyH6JZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qesIMhnA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wC8LA1FB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d200DoSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qesIMhnA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wC8LA1FB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wwvq3v6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_aOooG5IZ_sendMessage(_c, 0, m);
  cMsg_BdLEzH5g_sendMessage(_c, 0, m);
  cMsg_d200DoSS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qxzCeB8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_KRg6Q9lo_sendMessage(_c, 0, m);
  cMsg_6YrfM806_sendMessage(_c, 0, m);
  cMsg_d200DoSS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mm8WwrqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_KRg6Q9lo_sendMessage(_c, 0, m);
  cMsg_BdLEzH5g_sendMessage(_c, 0, m);
  cMsg_ASEyH6JZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yjQeTdki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yLIVA6YW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_82dOfb1C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_D4stzhVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yLIVA6YW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_82dOfb1C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n5tRiEEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rXQacK9I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EN1knrR5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hB3ctgG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rXQacK9I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EN1knrR5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Jx7OwC8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BcTDVeii_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KTIz2Irk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Qdh8QQPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BcTDVeii_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KTIz2Irk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AYy9wlGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_D4stzhVE_sendMessage(_c, 0, m);
  cMsg_hB3ctgG0_sendMessage(_c, 0, m);
  cMsg_Qdh8QQPl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZPcKhxq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_D4stzhVE_sendMessage(_c, 0, m);
  cMsg_n5tRiEEo_sendMessage(_c, 0, m);
  cMsg_Jx7OwC8M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_A0bEHeVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_yjQeTdki_sendMessage(_c, 0, m);
  cMsg_hB3ctgG0_sendMessage(_c, 0, m);
  cMsg_Jx7OwC8M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EuXuJp09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ARADQITp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Hdo2PJx5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UBG4c1NW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ARADQITp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Hdo2PJx5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R5jBXjWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_36lKnOmx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wlPbrIEV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YkZo48gz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_36lKnOmx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wlPbrIEV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pN2Hzuqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JysH55G9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7aqVe79B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rdLqOpYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JysH55G9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7aqVe79B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DyBdya9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_EuXuJp09_sendMessage(_c, 0, m);
  cMsg_YkZo48gz_sendMessage(_c, 0, m);
  cMsg_rdLqOpYL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9KIfvnEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_UBG4c1NW_sendMessage(_c, 0, m);
  cMsg_R5jBXjWS_sendMessage(_c, 0, m);
  cMsg_rdLqOpYL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YSrdRhpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_UBG4c1NW_sendMessage(_c, 0, m);
  cMsg_YkZo48gz_sendMessage(_c, 0, m);
  cMsg_pN2Hzuqt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pYKdVqTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_V3FLDFnJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ETvV5cP4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_f0hXvTEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_V3FLDFnJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ETvV5cP4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YC8xp55B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zNPYPbgu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fVZ3IhFq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ftiOI58C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zNPYPbgu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fVZ3IhFq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ge0QCK1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VR2649bd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mQG5LxUR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_A4X8OZbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VR2649bd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mQG5LxUR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MqyBMWZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_f0hXvTEL_sendMessage(_c, 0, m);
  cMsg_ftiOI58C_sendMessage(_c, 0, m);
  cMsg_A4X8OZbg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lQNvr3zN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_f0hXvTEL_sendMessage(_c, 0, m);
  cMsg_YC8xp55B_sendMessage(_c, 0, m);
  cMsg_Ge0QCK1f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_I2XUMhSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_pYKdVqTu_sendMessage(_c, 0, m);
  cMsg_YC8xp55B_sendMessage(_c, 0, m);
  cMsg_A4X8OZbg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CJswvDm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_yjQeTdki_sendMessage(_c, 0, m);
  cMsg_n5tRiEEo_sendMessage(_c, 0, m);
  cMsg_Qdh8QQPl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pW3kAAk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_pYKdVqTu_sendMessage(_c, 0, m);
  cMsg_ftiOI58C_sendMessage(_c, 0, m);
  cMsg_Ge0QCK1f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_J3z5lKsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CKtlpTn3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bVjALC8t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eTZUplu6, 0, m, &cSlice_eTZUplu6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Ix7c63kn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_eTZUplu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Hv5r5Fen_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Hv5r5Fen_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_x8BfBaJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Hv5r5Fen_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Hv5r5Fen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ht2qOWzs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_F2hYXSZG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yH15wPIN, 0, m, &cSlice_yH15wPIN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BjSgSMgS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_yH15wPIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_B9PFWT5j_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_B9PFWT5j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GkziVjRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_B9PFWT5j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_B9PFWT5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TaGKatIA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BjSgSMgS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4sUWPmLx, 0, m, &cSlice_4sUWPmLx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bVjALC8t_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_4sUWPmLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BJnDaXKg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BJnDaXKg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ijS8UDbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BJnDaXKg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_BJnDaXKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ac3M86HE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Ix7c63kn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Q0lRxPCb, 0, m, &cSlice_Q0lRxPCb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7NrOrW2B_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Q0lRxPCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pcBiJgNq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pcBiJgNq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_7mEj1rIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pcBiJgNq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_pcBiJgNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Aw6vyy1o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7NrOrW2B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LlsJ9rGj, 0, m, &cSlice_LlsJ9rGj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6vB5hDYe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_LlsJ9rGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2lrcrn7x_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2lrcrn7x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3sVZtc4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2lrcrn7x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_2lrcrn7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HiSp90r3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6wdvaGJY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SUtg53uP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SUtg53uP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VLMJn5EY, 1, m, &cDelay_VLMJn5EY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Uu2zUULL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_VLMJn5EY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VLMJn5EY, m);
  cMsg_2Y0CmXUF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SUtg53uP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VLMJn5EY, 0, m, &cDelay_VLMJn5EY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Uu2zUULL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VLMJn5EY, 0, m, &cDelay_VLMJn5EY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_KamBT18P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2hbUVlBb, HV_BINOP_SUBTRACT, 0, m, &cBinop_2hbUVlBb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_k9yn7jQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nTOsWJvN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bflHIF06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nTOsWJvN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_OTMCXNQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KamBT18P, 0, m, &cVar_KamBT18P_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_BmPKLLVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1LoOfVHC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jSyYJb2e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EDLxtLhe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2hbUVlBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MYq1jB6A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MYq1jB6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_aixKL8va_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aixKL8va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_EBglvB1f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_o8ZWHCwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0zq9vdYz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cVQ1sFYt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0zq9vdYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k9yn7jQm, 1, m, &cIf_k9yn7jQm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cVQ1sFYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GKYQUxps_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wkRJy2jq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bflHIF06, 1, m, &cIf_bflHIF06_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GKYQUxps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_k9yn7jQm, 0, m, &cIf_k9yn7jQm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EBglvB1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bflHIF06, 0, m, &cIf_bflHIF06_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1LoOfVHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_jSyYJb2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2hbUVlBb, HV_BINOP_SUBTRACT, 1, m, &cBinop_2hbUVlBb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EDLxtLhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KamBT18P, 0, m, &cVar_KamBT18P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nTOsWJvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_91hWqGia, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6vB5hDYe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WRdCbCsV, 0, m, &cSlice_WRdCbCsV_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_WRdCbCsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RIZJpLJt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RIZJpLJt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_RwGvkjNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RIZJpLJt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_RIZJpLJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OqY0K06b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7OlGZCno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Tugqri45, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_k93cvNoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XP4paGqh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_tQG56T2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D2FYpSAf, 0, m, &cVar_D2FYpSAf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CKtlpTn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JcnM9Km4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_41BFKgbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VFbTLZYk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_2CfMePuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6wdvaGJY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2Y0CmXUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vo1zPwuv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VFbTLZYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vo1zPwuv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cJuirSEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_3cjIUsNx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3cjIUsNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w4XKn8hJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_w4XKn8hJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ceK2FSHa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_5Nk9jrUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2r5yfNbv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_MKjShBxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eJDrgxdZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WIELuJyT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gpTCMkJD_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lr3zlaRP_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3IGGPsz2_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aMJnvca9_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lBw7f41A_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zbz8gYZO_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_gpTCMkJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ECwacIfw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Lr3zlaRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7jBRn3UT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_3IGGPsz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Va0A5aoq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_aMJnvca9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mHhYvoCE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_lBw7f41A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zcKp5rmh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Zbz8gYZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wdxSNJH1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_TmI4K3Uc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ea1I3Xjh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dpXoP2aX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BHuuM4p5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8zibg0DB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bpxTwecp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bpxTwecp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RqTnMp5b, 1, m, &cDelay_RqTnMp5b_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ha6hS1Bg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RqTnMp5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RqTnMp5b, m);
  cIf_onMessage(_c, &Context(_c)->cIf_TmI4K3Uc, 0, m, &cIf_TmI4K3Uc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bpxTwecp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RqTnMp5b, 0, m, &cDelay_RqTnMp5b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ha6hS1Bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RqTnMp5b, 0, m, &cDelay_RqTnMp5b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R2LbClr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aI3gUB7t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kDuGbbLO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eMuCVkRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T6o8SAsU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ppfkAuat_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T6o8SAsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TmI4K3Uc, 1, m, &cIf_TmI4K3Uc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ppfkAuat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8zibg0DB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kDuGbbLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dpXoP2aX, 0, m, &cIf_dpXoP2aX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aI3gUB7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dpXoP2aX, 1, m, &cIf_dpXoP2aX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BHuuM4p5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bzMf1MDG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ea1I3Xjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bzMf1MDG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_KPEe5KOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kd9kDWN7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NzCGSavo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pi3dnbpp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_L11sYJLw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6PObIVAs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6PObIVAs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_DmTxzFHp, 1, m, &cDelay_DmTxzFHp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rB7wVqIe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_DmTxzFHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DmTxzFHp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KPEe5KOW, 0, m, &cIf_KPEe5KOW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6PObIVAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DmTxzFHp, 0, m, &cDelay_DmTxzFHp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rB7wVqIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DmTxzFHp, 0, m, &cDelay_DmTxzFHp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_syKKNFVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1fVEY66E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UOznyq3w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GpqYyiBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T201J8WZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SlUBbuvv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SlUBbuvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_L11sYJLw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_T201J8WZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KPEe5KOW, 1, m, &cIf_KPEe5KOW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UOznyq3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NzCGSavo, 0, m, &cIf_NzCGSavo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1fVEY66E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NzCGSavo, 1, m, &cIf_NzCGSavo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pi3dnbpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VHFVZeRu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kd9kDWN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VHFVZeRu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_V0Ia5HXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_coqqug8s_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zHzSdsAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bKoqEWmm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qVZV7ytn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Z1i2IXQp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Z1i2IXQp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EXI6IskP, 1, m, &cDelay_EXI6IskP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2yLt6Pkf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EXI6IskP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EXI6IskP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_V0Ia5HXS, 0, m, &cIf_V0Ia5HXS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z1i2IXQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EXI6IskP, 0, m, &cDelay_EXI6IskP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2yLt6Pkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EXI6IskP, 0, m, &cDelay_EXI6IskP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TPooEzvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VOjbzjby_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N89WTgYJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_b7RFPOLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kDkFGP9E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JUKqhs3K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JUKqhs3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qVZV7ytn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kDkFGP9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V0Ia5HXS, 1, m, &cIf_V0Ia5HXS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VOjbzjby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zHzSdsAp, 1, m, &cIf_zHzSdsAp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N89WTgYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zHzSdsAp, 0, m, &cIf_zHzSdsAp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bKoqEWmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5Yku40Ce, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_coqqug8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5Yku40Ce, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_OSRWVfE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_s3FJmcHs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UjWRS20f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mFnKO681_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IWZB4mHQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Katcw4Gs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Katcw4Gs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jFNdmUdh, 1, m, &cDelay_jFNdmUdh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_duPfaIWV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jFNdmUdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jFNdmUdh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OSRWVfE8, 0, m, &cIf_OSRWVfE8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Katcw4Gs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jFNdmUdh, 0, m, &cDelay_jFNdmUdh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_duPfaIWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jFNdmUdh, 0, m, &cDelay_jFNdmUdh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O52hQYve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6m6HHgpH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PR6qGOC2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_N2ErdWZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CXQFNbgr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o4b0h8Pg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_o4b0h8Pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IWZB4mHQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_CXQFNbgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OSRWVfE8, 1, m, &cIf_OSRWVfE8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PR6qGOC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UjWRS20f, 0, m, &cIf_UjWRS20f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6m6HHgpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UjWRS20f, 1, m, &cIf_UjWRS20f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mFnKO681_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9fYolomI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_s3FJmcHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9fYolomI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NZ6mL67N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_M6ThZ9Tp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rAVDq1PI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_coxHRRPg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_F1GAJ9Gp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_R7y3cFHg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_R7y3cFHg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yJdHCVcu, 1, m, &cDelay_yJdHCVcu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MfvVmb2U_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yJdHCVcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yJdHCVcu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NZ6mL67N, 0, m, &cIf_NZ6mL67N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R7y3cFHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yJdHCVcu, 0, m, &cDelay_yJdHCVcu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MfvVmb2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yJdHCVcu, 0, m, &cDelay_yJdHCVcu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ccPqUjAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aSqgm2Di_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqqlIHpQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rQLzJBed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ufK54x4b_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fPhrNptj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fPhrNptj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_F1GAJ9Gp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ufK54x4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NZ6mL67N, 1, m, &cIf_NZ6mL67N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FqqlIHpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rAVDq1PI, 0, m, &cIf_rAVDq1PI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aSqgm2Di_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rAVDq1PI, 1, m, &cIf_rAVDq1PI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_coxHRRPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UPkACdnJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_M6ThZ9Tp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UPkACdnJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ha05uvjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JPbprX9B_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7TFJvTTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_poYElxgG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_URcygmk3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_n94L4tSQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_n94L4tSQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_D2AZIQNH, 1, m, &cDelay_D2AZIQNH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9rFFL9X2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_D2AZIQNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D2AZIQNH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ha05uvjY, 0, m, &cIf_ha05uvjY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n94L4tSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_D2AZIQNH, 0, m, &cDelay_D2AZIQNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9rFFL9X2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D2AZIQNH, 0, m, &cDelay_D2AZIQNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TOPlgIYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pUL6lBR3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B7reSHtV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wdF7VPaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L42iKMSn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fKfhK7Ea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fKfhK7Ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_URcygmk3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_L42iKMSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ha05uvjY, 1, m, &cIf_ha05uvjY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pUL6lBR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7TFJvTTC, 1, m, &cIf_7TFJvTTC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B7reSHtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7TFJvTTC, 0, m, &cIf_7TFJvTTC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_poYElxgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5ck0hCrS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JPbprX9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5ck0hCrS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_f4Y4AQuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_92qakEwF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qpyqc6zz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gB2X7rkp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UyZYpFWP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FVpDbTNd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FVpDbTNd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jMPUveha, 1, m, &cDelay_jMPUveha_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_97a36CMh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jMPUveha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jMPUveha, m);
  cIf_onMessage(_c, &Context(_c)->cIf_f4Y4AQuZ, 0, m, &cIf_f4Y4AQuZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FVpDbTNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jMPUveha, 0, m, &cDelay_jMPUveha_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_97a36CMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jMPUveha, 0, m, &cDelay_jMPUveha_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6MEK39KV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bdXnY1nM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L4kBi41n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_w7Pdnbeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hjsl9aCF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h1FRVB9B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h1FRVB9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UyZYpFWP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hjsl9aCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f4Y4AQuZ, 1, m, &cIf_f4Y4AQuZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L4kBi41n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qpyqc6zz, 0, m, &cIf_qpyqc6zz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bdXnY1nM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qpyqc6zz, 1, m, &cIf_qpyqc6zz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gB2X7rkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8wb7aPu1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_92qakEwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8wb7aPu1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lJEzHOjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4vWq2tms_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3FdK0SNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_93LHCVhQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Ob9cvdfd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_RVU3ds2o_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_RVU3ds2o_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BM03WGIa, 1, m, &cDelay_BM03WGIa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CPP87rzR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BM03WGIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BM03WGIa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lJEzHOjD, 0, m, &cIf_lJEzHOjD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RVU3ds2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BM03WGIa, 0, m, &cDelay_BM03WGIa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CPP87rzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BM03WGIa, 0, m, &cDelay_BM03WGIa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O4JKjbjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ehOhHtTr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qPFDMTRc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sroVrJex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_skYrfkya_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3pgchyA3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_skYrfkya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lJEzHOjD, 1, m, &cIf_lJEzHOjD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3pgchyA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Ob9cvdfd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ehOhHtTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3FdK0SNK, 1, m, &cIf_3FdK0SNK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qPFDMTRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3FdK0SNK, 0, m, &cIf_3FdK0SNK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_93LHCVhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N88PzxSv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4vWq2tms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N88PzxSv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_DG5enoWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LKLDdsZb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wcXUmFKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_p92QjGyX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PtGJCd2b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1j1HS7W2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1j1HS7W2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Lj9yirod, 1, m, &cDelay_Lj9yirod_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ecRZtW0g_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Lj9yirod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Lj9yirod, m);
  cIf_onMessage(_c, &Context(_c)->cIf_DG5enoWU, 0, m, &cIf_DG5enoWU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1j1HS7W2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Lj9yirod, 0, m, &cDelay_Lj9yirod_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ecRZtW0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Lj9yirod, 0, m, &cDelay_Lj9yirod_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xFU3FXUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sSJgWCrf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wJmb8ox3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6VwykD3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gjfS163j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4XuCGkl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v4XuCGkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PtGJCd2b_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_gjfS163j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DG5enoWU, 1, m, &cIf_DG5enoWU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sSJgWCrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wcXUmFKA, 1, m, &cIf_wcXUmFKA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wJmb8ox3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wcXUmFKA, 0, m, &cIf_wcXUmFKA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_p92QjGyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZfbI4SCK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LKLDdsZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZfbI4SCK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3xEqSNV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9BGVILE0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3L3gDdZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5GRMRDIQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0BLy8kYX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fSGwjAE7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fSGwjAE7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AeEgh5vy, 1, m, &cDelay_AeEgh5vy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nOe5u3BA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AeEgh5vy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AeEgh5vy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3xEqSNV3, 0, m, &cIf_3xEqSNV3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fSGwjAE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AeEgh5vy, 0, m, &cDelay_AeEgh5vy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nOe5u3BA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AeEgh5vy, 0, m, &cDelay_AeEgh5vy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C4iAaLHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wabaDUAX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gViQUzNO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ai870mp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GTCxU0YR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iSIufft3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iSIufft3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0BLy8kYX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GTCxU0YR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3xEqSNV3, 1, m, &cIf_3xEqSNV3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gViQUzNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3L3gDdZW, 0, m, &cIf_3L3gDdZW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wabaDUAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3L3gDdZW, 1, m, &cIf_3L3gDdZW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5GRMRDIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tlpJBsnC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9BGVILE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tlpJBsnC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7RFhrdPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z4NyBWLB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RSCH1she_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iZ1sOCZ7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6qG3WQzI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YxjXN3CG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YxjXN3CG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_08cVnv08, 1, m, &cDelay_08cVnv08_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uFggcpzZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_08cVnv08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_08cVnv08, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7RFhrdPD, 0, m, &cIf_7RFhrdPD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YxjXN3CG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_08cVnv08, 0, m, &cDelay_08cVnv08_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uFggcpzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_08cVnv08, 0, m, &cDelay_08cVnv08_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ifG9ihnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kn7EXBkw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uvpn3IiA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tP9lcGyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4iYrb3Kn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HPeZhQl2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HPeZhQl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6qG3WQzI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4iYrb3Kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7RFhrdPD, 1, m, &cIf_7RFhrdPD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uvpn3IiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RSCH1she, 0, m, &cIf_RSCH1she_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Kn7EXBkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RSCH1she, 1, m, &cIf_RSCH1she_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iZ1sOCZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pq7UBq75, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Z4NyBWLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pq7UBq75, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_FiegSPOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wUNruwEv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9qazXYrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RyTQUJ6o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hC2rCqTx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_08Tj9CdL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_08Tj9CdL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7xMT262C, 1, m, &cDelay_7xMT262C_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YoN5v9IT_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7xMT262C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7xMT262C, m);
  cIf_onMessage(_c, &Context(_c)->cIf_FiegSPOd, 0, m, &cIf_FiegSPOd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_08Tj9CdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7xMT262C, 0, m, &cDelay_7xMT262C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YoN5v9IT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7xMT262C, 0, m, &cDelay_7xMT262C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FrgnBEvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HC5aIiAK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FvWEaUb3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tr2PHFWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iXyqIsDJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yJhWKxyF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iXyqIsDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FiegSPOd, 1, m, &cIf_FiegSPOd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yJhWKxyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hC2rCqTx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HC5aIiAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9qazXYrN, 1, m, &cIf_9qazXYrN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FvWEaUb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9qazXYrN, 0, m, &cIf_9qazXYrN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RyTQUJ6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FEpFA6WZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wUNruwEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FEpFA6WZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ECwacIfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_TujpNvjZ_sendMessage(_c, 0, m);
  cMsg_ClBpRzxB_sendMessage(_c, 0, m);
  cMsg_tT57HBas_sendMessage(_c, 0, m);
  cMsg_DiRdVRiM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7jBRn3UT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_TujpNvjZ_sendMessage(_c, 0, m);
  cMsg_SfQIkNvI_sendMessage(_c, 0, m);
  cMsg_e5MqynX6_sendMessage(_c, 0, m);
  cMsg_PPQipC9r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Va0A5aoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_7NtZVX8s_sendMessage(_c, 0, m);
  cMsg_SfQIkNvI_sendMessage(_c, 0, m);
  cMsg_DiRdVRiM_sendMessage(_c, 0, m);
  cMsg_H7XWxdUI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mHhYvoCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_7NtZVX8s_sendMessage(_c, 0, m);
  cMsg_BdA7wGzH_sendMessage(_c, 0, m);
  cMsg_tT57HBas_sendMessage(_c, 0, m);
  cMsg_rnmVdQXj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zcKp5rmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_atUKPcDG_sendMessage(_c, 0, m);
  cMsg_PPQipC9r_sendMessage(_c, 0, m);
  cMsg_Je7259Ce_sendMessage(_c, 0, m);
  cMsg_tT57HBas_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wdxSNJH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_atUKPcDG_sendMessage(_c, 0, m);
  cMsg_rnmVdQXj_sendMessage(_c, 0, m);
  cMsg_SfQIkNvI_sendMessage(_c, 0, m);
  cMsg_9jYhuh6O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LDPQSutN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eMuCVkRL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R2LbClr6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u2fTEb9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eMuCVkRL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R2LbClr6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ldE7xwcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GpqYyiBr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_syKKNFVi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lQixcWzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GpqYyiBr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_syKKNFVi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uTU1BYFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_b7RFPOLB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TPooEzvx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HwATXpzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_b7RFPOLB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TPooEzvx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TujpNvjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_LDPQSutN_sendMessage(_c, 0, m);
  cMsg_lQixcWzm_sendMessage(_c, 0, m);
  cMsg_HwATXpzP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7NtZVX8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_u2fTEb9Z_sendMessage(_c, 0, m);
  cMsg_ldE7xwcO_sendMessage(_c, 0, m);
  cMsg_HwATXpzP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_atUKPcDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_u2fTEb9Z_sendMessage(_c, 0, m);
  cMsg_lQixcWzm_sendMessage(_c, 0, m);
  cMsg_uTU1BYFX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OWY6iY7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_N2ErdWZW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O52hQYve_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iqk75eog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_N2ErdWZW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O52hQYve_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Kj1I1HL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rQLzJBed_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ccPqUjAP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_00zM9CbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rQLzJBed_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ccPqUjAP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0jFo8Ybs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wdF7VPaB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TOPlgIYa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jdcloELa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wdF7VPaB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TOPlgIYa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SfQIkNvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_iqk75eog_sendMessage(_c, 0, m);
  cMsg_00zM9CbR_sendMessage(_c, 0, m);
  cMsg_jdcloELa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ClBpRzxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_iqk75eog_sendMessage(_c, 0, m);
  cMsg_Kj1I1HL8_sendMessage(_c, 0, m);
  cMsg_0jFo8Ybs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BdA7wGzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_OWY6iY7n_sendMessage(_c, 0, m);
  cMsg_00zM9CbR_sendMessage(_c, 0, m);
  cMsg_0jFo8Ybs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_k4u7aYuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ai870mp6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C4iAaLHk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TOEFE1dS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ai870mp6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C4iAaLHk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7HyNeSV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tP9lcGyb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ifG9ihnH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Qk2zSkgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tP9lcGyb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ifG9ihnH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LQFIutOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tr2PHFWT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FrgnBEvt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xHwVFQxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tr2PHFWT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FrgnBEvt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rnmVdQXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_k4u7aYuB_sendMessage(_c, 0, m);
  cMsg_Qk2zSkgG_sendMessage(_c, 0, m);
  cMsg_xHwVFQxz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PPQipC9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_TOEFE1dS_sendMessage(_c, 0, m);
  cMsg_7HyNeSV2_sendMessage(_c, 0, m);
  cMsg_xHwVFQxz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DiRdVRiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_TOEFE1dS_sendMessage(_c, 0, m);
  cMsg_Qk2zSkgG_sendMessage(_c, 0, m);
  cMsg_LQFIutOd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Fwb06kTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_w7Pdnbeb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6MEK39KV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uglZKRsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_w7Pdnbeb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6MEK39KV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vCS5CnoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sroVrJex_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O4JKjbjp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_B011xkZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sroVrJex_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O4JKjbjp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3Sywrlt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6VwykD3A_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xFU3FXUD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z3ahzTpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6VwykD3A_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xFU3FXUD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tT57HBas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_uglZKRsm_sendMessage(_c, 0, m);
  cMsg_B011xkZL_sendMessage(_c, 0, m);
  cMsg_z3ahzTpS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_e5MqynX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_uglZKRsm_sendMessage(_c, 0, m);
  cMsg_vCS5CnoS_sendMessage(_c, 0, m);
  cMsg_3Sywrlt3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9jYhuh6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Fwb06kTE_sendMessage(_c, 0, m);
  cMsg_vCS5CnoS_sendMessage(_c, 0, m);
  cMsg_z3ahzTpS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Je7259Ce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_OWY6iY7n_sendMessage(_c, 0, m);
  cMsg_Kj1I1HL8_sendMessage(_c, 0, m);
  cMsg_jdcloELa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_H7XWxdUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Fwb06kTE_sendMessage(_c, 0, m);
  cMsg_B011xkZL_sendMessage(_c, 0, m);
  cMsg_3Sywrlt3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_oHQtMKo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SFJXmF2M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xm7WurSA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QFxvyadF, 0, m, &cSlice_QFxvyadF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nKzEwKp5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_QFxvyadF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ky2TfIWr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ky2TfIWr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_l1GQG2EK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ky2TfIWr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ky2TfIWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hK0yT19k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6cVY9AjX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_e6yipyFl, 0, m, &cSlice_e6yipyFl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uDiGvJKO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_e6yipyFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8WUXm4pA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8WUXm4pA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_37BbmJBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8WUXm4pA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_8WUXm4pA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_n4czyUOM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uDiGvJKO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RSwP40Yi, 0, m, &cSlice_RSwP40Yi_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xm7WurSA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_RSwP40Yi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NCQMJtzp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NCQMJtzp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_zxIoi3pJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NCQMJtzp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_NCQMJtzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uozmYR9r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nKzEwKp5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MaUUZhd8, 0, m, &cSlice_MaUUZhd8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GkrgQcNt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_MaUUZhd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gB9zbMXx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gB9zbMXx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_CahfVcAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gB9zbMXx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_gB9zbMXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_W67qJV25_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GkrgQcNt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OOlQvIOW, 0, m, &cSlice_OOlQvIOW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tKRWPghz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_OOlQvIOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Qu9anfFf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Qu9anfFf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_kM2knrj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Qu9anfFf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Qu9anfFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Rzq5GVyY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MzY8Qs9m_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_as8ckOoy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_as8ckOoy_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Rrnv6qF4, 1, m, &cDelay_Rrnv6qF4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NJKmVhzM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Rrnv6qF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Rrnv6qF4, m);
  cMsg_Rmjv0sFR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_as8ckOoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Rrnv6qF4, 0, m, &cDelay_Rrnv6qF4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NJKmVhzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Rrnv6qF4, 0, m, &cDelay_Rrnv6qF4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_7aTI19N8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cQfCDKSM, HV_BINOP_SUBTRACT, 0, m, &cBinop_cQfCDKSM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_kWPDSYBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rEjgI9gm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bXdhQcyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rEjgI9gm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_VyAHaKV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7aTI19N8, 0, m, &cVar_7aTI19N8_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_IlczPjBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XYHDd4L8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gI97fDqW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZcJmWj0H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cQfCDKSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AnqiBWgS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AnqiBWgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rvgyzjvu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rvgyzjvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_wKLdWr4W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IbUCLGcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x5bqOknk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YcZ3vKnn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YcZ3vKnn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QLUjXwK5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_x5bqOknk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kWPDSYBi, 1, m, &cIf_kWPDSYBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bQVphLyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bXdhQcyf, 1, m, &cIf_bXdhQcyf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QLUjXwK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_kWPDSYBi, 0, m, &cIf_kWPDSYBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wKLdWr4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bXdhQcyf, 0, m, &cIf_bXdhQcyf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZcJmWj0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7aTI19N8, 0, m, &cVar_7aTI19N8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gI97fDqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cQfCDKSM, HV_BINOP_SUBTRACT, 1, m, &cBinop_cQfCDKSM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XYHDd4L8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_rEjgI9gm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dfg8kW3j, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tKRWPghz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_x9sn94TN, 0, m, &cSlice_x9sn94TN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_x9sn94TN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Zt56LX18_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Zt56LX18_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_b6mUH3ND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Zt56LX18_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Zt56LX18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RGZpXeyJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2r5yfNbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sY6shsGG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eJDrgxdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wztfoUeP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_JNns8a8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MKjShBxb, 0, m, &cVar_MKjShBxb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SFJXmF2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5nEf8cMR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6lcPRSE3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MzY8Qs9m_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ksczoHg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CEwS04Ze_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Rmjv0sFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6uOITxb2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CEwS04Ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6uOITxb2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jIdCdxI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_EHPDE99p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EHPDE99p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DfNEGnHp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DfNEGnHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a2Y5bGtR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_aqiXY9V6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DWb1DtBI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_U6yKXRyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LxjWRjyf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_dnNhFBrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P76l5J4Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_R84QtEyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rgXEAEbC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_8mB5yb96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KrWIOTW1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ieRz6eEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Y3WLwFDG_sendMessage);
  cMsg_bf97Spw4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Y3WLwFDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ieRz6eEG, 1, m, &cVar_ieRz6eEG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JsNIernm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YwhjN5uU_sendMessage(_c, 0, m);
  cMsg_a7BFPgaJ_sendMessage(_c, 0, m);
  cMsg_suWnrWaH_sendMessage(_c, 0, m);
  cMsg_kdYiPoRE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_P29aHlZq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tn9b0BoJ, 0, m, &cSlice_tn9b0BoJ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_tn9b0BoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_50Yx6SRy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_50Yx6SRy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_pgyG0VK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_50Yx6SRy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_50Yx6SRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7lY9z3a6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_C0Bl4T8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_05zUK8A2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_05zUK8A2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_sqgEAlFB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sqgEAlFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_34sqifFo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_34sqifFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QAuudkca_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bGMveBDX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bGMveBDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rE09NeDd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_QAuudkca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ijqg9iMD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ijqg9iMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iky5ha4m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rE09NeDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TEiZ5FAU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TEiZ5FAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_X0SY2dcf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iky5ha4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZnnS710N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_X0SY2dcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hr3mk8c2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZnnS710N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OxMjE4AT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Hr3mk8c2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9STs1V8F, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_UMU3sCiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6kM4OxTw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_lBKXZ75t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pUXaLn2g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yYjerFZe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3hkvdyJi_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_icebmC5g_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_53h7zw8j_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Dw6EA58q_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JdWzvGZ4_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fWCXjW5t_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_3hkvdyJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GbSi7Gmm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_icebmC5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1lkVM6lT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_53h7zw8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QNnb2QBT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Dw6EA58q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mc3PeiHO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JdWzvGZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pp1nO2SX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_fWCXjW5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yo1RUjAU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_RdXKuAzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8vS2Ntt1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oghBdMve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mfTywvwG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LkPgV5Cu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NvtJvpHh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NvtJvpHh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GTWFj4jf, 1, m, &cDelay_GTWFj4jf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hlf6OwzS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_GTWFj4jf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GTWFj4jf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RdXKuAzy, 0, m, &cIf_RdXKuAzy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NvtJvpHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GTWFj4jf, 0, m, &cDelay_GTWFj4jf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hlf6OwzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GTWFj4jf, 0, m, &cDelay_GTWFj4jf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yKvwEqyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_izyoUxV2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uPiV9Z4F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2FQmOc4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uoN4OKSZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2Aq2Di9S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2Aq2Di9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LkPgV5Cu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uoN4OKSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RdXKuAzy, 1, m, &cIf_RdXKuAzy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_izyoUxV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oghBdMve, 1, m, &cIf_oghBdMve_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uPiV9Z4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oghBdMve, 0, m, &cIf_oghBdMve_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mfTywvwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YCzjWQe8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8vS2Ntt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YCzjWQe8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4kL2D7Qo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5kqPcmtC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WI7a4DA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tEuBc7O1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4ueevS2t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yltTsKqj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yltTsKqj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9NluoTwF, 1, m, &cDelay_9NluoTwF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_73YifiI9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9NluoTwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9NluoTwF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4kL2D7Qo, 0, m, &cIf_4kL2D7Qo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yltTsKqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9NluoTwF, 0, m, &cDelay_9NluoTwF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_73YifiI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9NluoTwF, 0, m, &cDelay_9NluoTwF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_29n9YYUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z0Tajjj2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YTNrIWH0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5hFPzVnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vYWdLAvZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sPX1uXlt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sPX1uXlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4ueevS2t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vYWdLAvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4kL2D7Qo, 1, m, &cIf_4kL2D7Qo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Z0Tajjj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WI7a4DA0, 1, m, &cIf_WI7a4DA0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YTNrIWH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WI7a4DA0, 0, m, &cIf_WI7a4DA0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tEuBc7O1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JGCIyOYf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5kqPcmtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JGCIyOYf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_P26bWWzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QrRxSPwO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Tt1oyKmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1X5voWt3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wwuwxKTs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xv7ojcib_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xv7ojcib_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GM16FB0d, 1, m, &cDelay_GM16FB0d_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_37FLiFpS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_GM16FB0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GM16FB0d, m);
  cIf_onMessage(_c, &Context(_c)->cIf_P26bWWzo, 0, m, &cIf_P26bWWzo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xv7ojcib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GM16FB0d, 0, m, &cDelay_GM16FB0d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_37FLiFpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GM16FB0d, 0, m, &cDelay_GM16FB0d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ADyVFo1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qf7FwHXk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OPEQbnzn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B1s260Qp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c4Ztwp9W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oZq4uL6S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oZq4uL6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wwuwxKTs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_c4Ztwp9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P26bWWzo, 1, m, &cIf_P26bWWzo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Qf7FwHXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Tt1oyKmL, 1, m, &cIf_Tt1oyKmL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OPEQbnzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Tt1oyKmL, 0, m, &cIf_Tt1oyKmL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1X5voWt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k3S9LJfx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QrRxSPwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k3S9LJfx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9dIFBemD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_k57hJLFN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Vyer7YwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iwAmhmun_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UaUSC6HE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ncOtQq0M_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ncOtQq0M_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_DFN92fIE, 1, m, &cDelay_DFN92fIE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0JZOlaM0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_DFN92fIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DFN92fIE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9dIFBemD, 0, m, &cIf_9dIFBemD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ncOtQq0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DFN92fIE, 0, m, &cDelay_DFN92fIE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0JZOlaM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DFN92fIE, 0, m, &cDelay_DFN92fIE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T5hTVbdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AT9VmEug_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2ERc9Zai_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Qy4M5qKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rb4GKMUO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lNsKjyS8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lNsKjyS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UaUSC6HE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rb4GKMUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9dIFBemD, 1, m, &cIf_9dIFBemD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AT9VmEug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Vyer7YwV, 1, m, &cIf_Vyer7YwV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2ERc9Zai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Vyer7YwV, 0, m, &cIf_Vyer7YwV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iwAmhmun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dIIC5NL5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_k57hJLFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dIIC5NL5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Vk4N2S6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_linK2Hnn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_govx89rS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EJEj0cAQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZEtJt7Gx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Mx7fprwh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Mx7fprwh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Jw56uDUi, 1, m, &cDelay_Jw56uDUi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BAP2JFlP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Jw56uDUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Jw56uDUi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Vk4N2S6G, 0, m, &cIf_Vk4N2S6G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Mx7fprwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Jw56uDUi, 0, m, &cDelay_Jw56uDUi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BAP2JFlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Jw56uDUi, 0, m, &cDelay_Jw56uDUi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4Ezw9ChJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3WovfYs5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TQTiDfBv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zO7S36XN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t3VNqkk4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F1q9gAvG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t3VNqkk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Vk4N2S6G, 1, m, &cIf_Vk4N2S6G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F1q9gAvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZEtJt7Gx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3WovfYs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_govx89rS, 1, m, &cIf_govx89rS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TQTiDfBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_govx89rS, 0, m, &cIf_govx89rS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EJEj0cAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1ErwqQFI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_linK2Hnn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1ErwqQFI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_cbWWcFa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2U4dBDtm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wG4OU7hq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_E4EFgW97_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Hh3kgjt5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_VmYMrFA9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_VmYMrFA9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tnRwlkCM, 1, m, &cDelay_tnRwlkCM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KSKIcea6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tnRwlkCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tnRwlkCM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cbWWcFa3, 0, m, &cIf_cbWWcFa3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VmYMrFA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tnRwlkCM, 0, m, &cDelay_tnRwlkCM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KSKIcea6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tnRwlkCM, 0, m, &cDelay_tnRwlkCM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QoWMfTEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fWk9ydAX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bI0I5S10_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pGX7fBgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8kJbxUHC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xZLnjRHm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xZLnjRHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Hh3kgjt5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_8kJbxUHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cbWWcFa3, 1, m, &cIf_cbWWcFa3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fWk9ydAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wG4OU7hq, 1, m, &cIf_wG4OU7hq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bI0I5S10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wG4OU7hq, 0, m, &cIf_wG4OU7hq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E4EFgW97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UiivM1vs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2U4dBDtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UiivM1vs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Hrinbj23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4Hsn0nNh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_h2Iiv1Fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8D6qraBj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OqyVaSCh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SeFnmzo0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SeFnmzo0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_l3nwmEjm, 1, m, &cDelay_l3nwmEjm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7YJ7d0HV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_l3nwmEjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_l3nwmEjm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Hrinbj23, 0, m, &cIf_Hrinbj23_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SeFnmzo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_l3nwmEjm, 0, m, &cDelay_l3nwmEjm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7YJ7d0HV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_l3nwmEjm, 0, m, &cDelay_l3nwmEjm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_adtomEqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_56g9gz5J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AshDmxvp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cngqALRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_joX4Rbcc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_24yHroSp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_24yHroSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OqyVaSCh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_joX4Rbcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hrinbj23, 1, m, &cIf_Hrinbj23_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AshDmxvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h2Iiv1Fy, 0, m, &cIf_h2Iiv1Fy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_56g9gz5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h2Iiv1Fy, 1, m, &cIf_h2Iiv1Fy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8D6qraBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CoyfKN3L, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4Hsn0nNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CoyfKN3L, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xpcdgjLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JxYrMRq3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_M4iMYA0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_b8Wbj7Uo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vOaevyk8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FHdDgnkJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FHdDgnkJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UkMy8WAU, 1, m, &cDelay_UkMy8WAU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_luJjELbG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UkMy8WAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UkMy8WAU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xpcdgjLs, 0, m, &cIf_xpcdgjLs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FHdDgnkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UkMy8WAU, 0, m, &cDelay_UkMy8WAU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_luJjELbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UkMy8WAU, 0, m, &cDelay_UkMy8WAU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lsDHG5in_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6QdcLYQS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JATZpQm7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jBVdVtpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k1PB50E3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9EBKKBzu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9EBKKBzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vOaevyk8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_k1PB50E3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xpcdgjLs, 1, m, &cIf_xpcdgjLs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JATZpQm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M4iMYA0u, 0, m, &cIf_M4iMYA0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6QdcLYQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M4iMYA0u, 1, m, &cIf_M4iMYA0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b8Wbj7Uo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WEYd1UeP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JxYrMRq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WEYd1UeP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_i5cQ2q9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4Co1rkZD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WA5RhEwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UOsERIRN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2JKmSAQD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HLgvAq9R_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HLgvAq9R_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_M4xOhuiJ, 1, m, &cDelay_M4xOhuiJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r7ZMlzBa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_M4xOhuiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M4xOhuiJ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_i5cQ2q9Q, 0, m, &cIf_i5cQ2q9Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HLgvAq9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_M4xOhuiJ, 0, m, &cDelay_M4xOhuiJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r7ZMlzBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_M4xOhuiJ, 0, m, &cDelay_M4xOhuiJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_soMtLN8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M5fGWtLw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kZO3GIii_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7jhEys2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iIbt2cTS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VXCmziyh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iIbt2cTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i5cQ2q9Q, 1, m, &cIf_i5cQ2q9Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VXCmziyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2JKmSAQD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kZO3GIii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WA5RhEwj, 0, m, &cIf_WA5RhEwj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_M5fGWtLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WA5RhEwj, 1, m, &cIf_WA5RhEwj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UOsERIRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V2TbqXw9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4Co1rkZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V2TbqXw9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_HDaxwOi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LD9wIgwY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_b0aNaJWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LnB8rllB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eu1zSJbk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_iMQMLG9n_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_iMQMLG9n_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vMrsck9C, 1, m, &cDelay_vMrsck9C_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LaoOMTzd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vMrsck9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vMrsck9C, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HDaxwOi3, 0, m, &cIf_HDaxwOi3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iMQMLG9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vMrsck9C, 0, m, &cDelay_vMrsck9C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LaoOMTzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vMrsck9C, 0, m, &cDelay_vMrsck9C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EB5zAGbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MDWs4BGk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sTyHhqiR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SbaKjbX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hPMzH73k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lbBL7XS6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lbBL7XS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eu1zSJbk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hPMzH73k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HDaxwOi3, 1, m, &cIf_HDaxwOi3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sTyHhqiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b0aNaJWx, 0, m, &cIf_b0aNaJWx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MDWs4BGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b0aNaJWx, 1, m, &cIf_b0aNaJWx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LnB8rllB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gnABSb97, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LD9wIgwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gnABSb97, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_yhM5JkZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JK2TA82H_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QEhXeFfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SR2aW5Gw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HAxXCRbw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XYV7wkZS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XYV7wkZS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uP5vLkMO, 1, m, &cDelay_uP5vLkMO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MxLKvhm3_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uP5vLkMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uP5vLkMO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_yhM5JkZx, 0, m, &cIf_yhM5JkZx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XYV7wkZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uP5vLkMO, 0, m, &cDelay_uP5vLkMO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MxLKvhm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uP5vLkMO, 0, m, &cDelay_uP5vLkMO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Al4jfvNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i3hqE9HJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N7u6ErC8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JojUPZgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z5IBATIk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OwQIIo3b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OwQIIo3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HAxXCRbw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Z5IBATIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yhM5JkZx, 1, m, &cIf_yhM5JkZx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i3hqE9HJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QEhXeFfA, 1, m, &cIf_QEhXeFfA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N7u6ErC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QEhXeFfA, 0, m, &cIf_QEhXeFfA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SR2aW5Gw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JMrvh5x0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JK2TA82H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JMrvh5x0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SF992i4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Xepb3PMW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_OKvJgem4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yKUoTEyt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1N3KR0oM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tQyzWXYz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tQyzWXYz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dJWnLN2U, 1, m, &cDelay_dJWnLN2U_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1Ns7boH4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_dJWnLN2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dJWnLN2U, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SF992i4Y, 0, m, &cIf_SF992i4Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tQyzWXYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dJWnLN2U, 0, m, &cDelay_dJWnLN2U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1Ns7boH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dJWnLN2U, 0, m, &cDelay_dJWnLN2U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2gvEwzov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WrqteJFH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CK9b5EWT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uEerJTqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QC96ZLFJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1nYk5gtQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1nYk5gtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1N3KR0oM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QC96ZLFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SF992i4Y, 1, m, &cIf_SF992i4Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CK9b5EWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OKvJgem4, 0, m, &cIf_OKvJgem4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WrqteJFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OKvJgem4, 1, m, &cIf_OKvJgem4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yKUoTEyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lymIGaZU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Xepb3PMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lymIGaZU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GbSi7Gmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_1ekZfylf_sendMessage(_c, 0, m);
  cMsg_jcwy7wB3_sendMessage(_c, 0, m);
  cMsg_E5y53W59_sendMessage(_c, 0, m);
  cMsg_15EM0OWa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1lkVM6lT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_1ekZfylf_sendMessage(_c, 0, m);
  cMsg_OZuWSuPW_sendMessage(_c, 0, m);
  cMsg_zK06R3yQ_sendMessage(_c, 0, m);
  cMsg_82a32Kfp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QNnb2QBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_ubrsG0R6_sendMessage(_c, 0, m);
  cMsg_OZuWSuPW_sendMessage(_c, 0, m);
  cMsg_15EM0OWa_sendMessage(_c, 0, m);
  cMsg_5ZYFTpo4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mc3PeiHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_ubrsG0R6_sendMessage(_c, 0, m);
  cMsg_Ih6HzoWI_sendMessage(_c, 0, m);
  cMsg_E5y53W59_sendMessage(_c, 0, m);
  cMsg_Z6m58vr8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Pp1nO2SX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_lC2NroSx_sendMessage(_c, 0, m);
  cMsg_82a32Kfp_sendMessage(_c, 0, m);
  cMsg_BwHXJw0M_sendMessage(_c, 0, m);
  cMsg_E5y53W59_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yo1RUjAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_lC2NroSx_sendMessage(_c, 0, m);
  cMsg_Z6m58vr8_sendMessage(_c, 0, m);
  cMsg_OZuWSuPW_sendMessage(_c, 0, m);
  cMsg_KB8oyQhV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Wr2lrhwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2FQmOc4L_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yKvwEqyQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6g29kXwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2FQmOc4L_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yKvwEqyQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cUlfWmjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5hFPzVnd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_29n9YYUs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9uktJ98f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5hFPzVnd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_29n9YYUs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vYXgb8Ep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_B1s260Qp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ADyVFo1x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MuPqDEKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_B1s260Qp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ADyVFo1x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1ekZfylf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_Wr2lrhwK_sendMessage(_c, 0, m);
  cMsg_9uktJ98f_sendMessage(_c, 0, m);
  cMsg_MuPqDEKh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ubrsG0R6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_6g29kXwD_sendMessage(_c, 0, m);
  cMsg_cUlfWmjL_sendMessage(_c, 0, m);
  cMsg_MuPqDEKh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lC2NroSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_6g29kXwD_sendMessage(_c, 0, m);
  cMsg_9uktJ98f_sendMessage(_c, 0, m);
  cMsg_vYXgb8Ep_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WsHbjX20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Qy4M5qKL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T5hTVbdn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qRnfyzVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Qy4M5qKL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T5hTVbdn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GMYi0AJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zO7S36XN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4Ezw9ChJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hIaZWFva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zO7S36XN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4Ezw9ChJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bortlqrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pGX7fBgI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QoWMfTEu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EQD1oQL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pGX7fBgI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QoWMfTEu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OZuWSuPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_qRnfyzVr_sendMessage(_c, 0, m);
  cMsg_hIaZWFva_sendMessage(_c, 0, m);
  cMsg_EQD1oQL8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jcwy7wB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_qRnfyzVr_sendMessage(_c, 0, m);
  cMsg_GMYi0AJ3_sendMessage(_c, 0, m);
  cMsg_bortlqrj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ih6HzoWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_WsHbjX20_sendMessage(_c, 0, m);
  cMsg_hIaZWFva_sendMessage(_c, 0, m);
  cMsg_bortlqrj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jikbH944_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SbaKjbX7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EB5zAGbw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ijHBrd1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SbaKjbX7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EB5zAGbw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ICm3vMdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JojUPZgL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Al4jfvNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KKE7g3Qa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JojUPZgL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Al4jfvNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PoahPKDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uEerJTqS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2gvEwzov_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qrUxwXbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uEerJTqS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2gvEwzov_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z6m58vr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_jikbH944_sendMessage(_c, 0, m);
  cMsg_KKE7g3Qa_sendMessage(_c, 0, m);
  cMsg_qrUxwXbX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_82a32Kfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_ijHBrd1O_sendMessage(_c, 0, m);
  cMsg_ICm3vMdD_sendMessage(_c, 0, m);
  cMsg_qrUxwXbX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_15EM0OWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_ijHBrd1O_sendMessage(_c, 0, m);
  cMsg_KKE7g3Qa_sendMessage(_c, 0, m);
  cMsg_PoahPKDT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4w73SdD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cngqALRs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_adtomEqK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mCZY8cl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cngqALRs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_adtomEqK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QbE9kGdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jBVdVtpu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lsDHG5in_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KxCh7aLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jBVdVtpu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lsDHG5in_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DUbRvJsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7jhEys2r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_soMtLN8x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rDkd3vEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7jhEys2r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_soMtLN8x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E5y53W59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_mCZY8cl0_sendMessage(_c, 0, m);
  cMsg_KxCh7aLa_sendMessage(_c, 0, m);
  cMsg_rDkd3vEu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zK06R3yQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_mCZY8cl0_sendMessage(_c, 0, m);
  cMsg_QbE9kGdc_sendMessage(_c, 0, m);
  cMsg_DUbRvJsd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KB8oyQhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_4w73SdD1_sendMessage(_c, 0, m);
  cMsg_QbE9kGdc_sendMessage(_c, 0, m);
  cMsg_rDkd3vEu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BwHXJw0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_WsHbjX20_sendMessage(_c, 0, m);
  cMsg_GMYi0AJ3_sendMessage(_c, 0, m);
  cMsg_EQD1oQL8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5ZYFTpo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_4w73SdD1_sendMessage(_c, 0, m);
  cMsg_KxCh7aLa_sendMessage(_c, 0, m);
  cMsg_DUbRvJsd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_8Tp3yE4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r1LdzzdL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SRpYD57g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3pIpBKx9, 0, m, &cSlice_3pIpBKx9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jndYIaEM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_3pIpBKx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GbQxUjfC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GbQxUjfC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_pkFhSf1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GbQxUjfC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GbQxUjfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_U20Owp7l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MAB1Cut4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MsnvBYsB, 0, m, &cSlice_MsnvBYsB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_f5fvETVs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_MsnvBYsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qZO7jkex_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qZO7jkex_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Cagbe23F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qZO7jkex_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_qZO7jkex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_l6jFMwyc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_f5fvETVs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_35GwUwN5, 0, m, &cSlice_35GwUwN5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_SRpYD57g_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_35GwUwN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_60XdHz73_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_60XdHz73_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_kEHNOngX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_60XdHz73_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_60XdHz73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SDRUjHns_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jndYIaEM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EY1iiLI5, 0, m, &cSlice_EY1iiLI5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7oKjE5OQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_EY1iiLI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BY2jdMH3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BY2jdMH3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_TpDcaxyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BY2jdMH3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_BY2jdMH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Bz2emIAV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7oKjE5OQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jhTZNAh5, 0, m, &cSlice_jhTZNAh5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UkMiPz2f_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_jhTZNAh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8HiYjday_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8HiYjday_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_cev3HfJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8HiYjday_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_8HiYjday_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wBRok7PY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WGkj4Iod_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_iYgsCchW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_iYgsCchW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XO0Ovqaf, 1, m, &cDelay_XO0Ovqaf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ic6vtOja_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_XO0Ovqaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XO0Ovqaf, m);
  cMsg_tgHth8p6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iYgsCchW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XO0Ovqaf, 0, m, &cDelay_XO0Ovqaf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ic6vtOja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XO0Ovqaf, 0, m, &cDelay_XO0Ovqaf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_eW4nrtGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EvmGWzDW, HV_BINOP_SUBTRACT, 0, m, &cBinop_EvmGWzDW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_qdUQRCnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LSxBnVwc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QhYt9mVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LSxBnVwc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_ZgvJogK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eW4nrtGS, 0, m, &cVar_eW4nrtGS_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_x9aluynh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SejNAYQr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EDombPue_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1fDrX1mk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EvmGWzDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tbv04SZP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Tbv04SZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2V0oVJT5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2V0oVJT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_msa4iwNc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_s6xxNy3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c238lNf6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mk37ZPZk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c238lNf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qdUQRCnT, 1, m, &cIf_qdUQRCnT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Mk37ZPZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T64trDPF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_PWv7FxoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QhYt9mVD, 1, m, &cIf_QhYt9mVD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T64trDPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_qdUQRCnT, 0, m, &cIf_qdUQRCnT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_msa4iwNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QhYt9mVD, 0, m, &cIf_QhYt9mVD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1fDrX1mk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eW4nrtGS, 0, m, &cVar_eW4nrtGS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EDombPue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EvmGWzDW, HV_BINOP_SUBTRACT, 1, m, &cBinop_EvmGWzDW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SejNAYQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_LSxBnVwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XhEBrAiT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UkMiPz2f_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NGq8OPad, 0, m, &cSlice_NGq8OPad_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_NGq8OPad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JIqLTg1Z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JIqLTg1Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Fp9R7bO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JIqLTg1Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_JIqLTg1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tK70P3nL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6kM4OxTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EsPFTjiL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pUXaLn2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ymyz2ncu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_q6y35g2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lBKXZ75t, 0, m, &cVar_lBKXZ75t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_r1LdzzdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y02VtuS7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JW5FVG7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UBBD40XL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_6qkXe8ht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WGkj4Iod_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tgHth8p6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_naTeCaBY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UBBD40XL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_naTeCaBY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_g0RFBEzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_NISoL6Wa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NISoL6Wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xRXYfSf5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xRXYfSf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wjjjwS6k, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_qbovnTiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4lreTCw6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_JgGyZc2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RGaOmOJ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2CUwNUL6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V6fgmwy5_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fjX8wSp1_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k5IXo1JO_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YG9EhLaZ_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b1dZoIOg_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Nm3VUc0H_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_V6fgmwy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LPUXZVOM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_fjX8wSp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B12bz3Ue_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_k5IXo1JO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W82ioO1u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_YG9EhLaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WCevvxXl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_b1dZoIOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qRy16uV2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Nm3VUc0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sxhoj7iu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_oXj3SwvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_t6gVJmOu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_X8yZmSfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MnRGZT8g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nb21fPXi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CHjxjEX0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CHjxjEX0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tlvEikpV, 1, m, &cDelay_tlvEikpV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rlHC3Ci9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tlvEikpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tlvEikpV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oXj3SwvT, 0, m, &cIf_oXj3SwvT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CHjxjEX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tlvEikpV, 0, m, &cDelay_tlvEikpV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rlHC3Ci9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tlvEikpV, 0, m, &cDelay_tlvEikpV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Q2whULbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dNG2wHuK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qgV9Dz5c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PSTeF07h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gThxue8X_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b8WdLiPp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gThxue8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oXj3SwvT, 1, m, &cIf_oXj3SwvT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_b8WdLiPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nb21fPXi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_dNG2wHuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X8yZmSfa, 1, m, &cIf_X8yZmSfa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qgV9Dz5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X8yZmSfa, 0, m, &cIf_X8yZmSfa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MnRGZT8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GctIOAtp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_t6gVJmOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GctIOAtp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZIQste7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4UYZwHUf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rcTKKjRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Dp3kh5IG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7fZmptmA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EQMAywxt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EQMAywxt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_i5ihj6Li, 1, m, &cDelay_i5ihj6Li_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PW7AdnaY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_i5ihj6Li_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_i5ihj6Li, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZIQste7s, 0, m, &cIf_ZIQste7s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EQMAywxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_i5ihj6Li, 0, m, &cDelay_i5ihj6Li_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PW7AdnaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_i5ihj6Li, 0, m, &cDelay_i5ihj6Li_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tlEHUQsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3iIvtotN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_smbub7DJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dgpOTdPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VjcJMcuv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JCp2jAt7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JCp2jAt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7fZmptmA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VjcJMcuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZIQste7s, 1, m, &cIf_ZIQste7s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3iIvtotN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rcTKKjRZ, 1, m, &cIf_rcTKKjRZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_smbub7DJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rcTKKjRZ, 0, m, &cIf_rcTKKjRZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Dp3kh5IG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NGS8bXAz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4UYZwHUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NGS8bXAz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RxDZHgv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gRmUtdlS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hRDYAXrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DbahsrLZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XCarIxoB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lmDa49lx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lmDa49lx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_c6Yv8pxE, 1, m, &cDelay_c6Yv8pxE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5ng0IwAM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_c6Yv8pxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_c6Yv8pxE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RxDZHgv2, 0, m, &cIf_RxDZHgv2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lmDa49lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_c6Yv8pxE, 0, m, &cDelay_c6Yv8pxE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5ng0IwAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_c6Yv8pxE, 0, m, &cDelay_c6Yv8pxE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6bcyQxc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2eot9N6T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dXrKBuef_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oDgtt7Jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gh83KAfp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y8mbqWnF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Gh83KAfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RxDZHgv2, 1, m, &cIf_RxDZHgv2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y8mbqWnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XCarIxoB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2eot9N6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hRDYAXrN, 1, m, &cIf_hRDYAXrN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dXrKBuef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hRDYAXrN, 0, m, &cIf_hRDYAXrN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DbahsrLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4UP39uiP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gRmUtdlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4UP39uiP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_e3FxSkdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_B2sEN5YK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3QddqQ0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NlxuiQwb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JZSsOiXz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Cce6e1wH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Cce6e1wH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xPSmZ4f2, 1, m, &cDelay_xPSmZ4f2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tCUOfKy4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xPSmZ4f2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xPSmZ4f2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_e3FxSkdl, 0, m, &cIf_e3FxSkdl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Cce6e1wH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xPSmZ4f2, 0, m, &cDelay_xPSmZ4f2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tCUOfKy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xPSmZ4f2, 0, m, &cDelay_xPSmZ4f2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kNJzDD9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sCKif3iy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AQJ6O5aW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i2RljbqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qp9YzB7T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8Q7d4POd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8Q7d4POd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JZSsOiXz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Qp9YzB7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e3FxSkdl, 1, m, &cIf_e3FxSkdl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AQJ6O5aW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3QddqQ0b, 0, m, &cIf_3QddqQ0b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sCKif3iy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3QddqQ0b, 1, m, &cIf_3QddqQ0b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NlxuiQwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2HmE1XFJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_B2sEN5YK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2HmE1XFJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_uRfsvmDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_z9f2rQI3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MJ90j9O8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rhowaUlP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IZxft8yc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DPSjQV5O_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DPSjQV5O_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xcY3VFZW, 1, m, &cDelay_xcY3VFZW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U4v9w6Jd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xcY3VFZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xcY3VFZW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uRfsvmDU, 0, m, &cIf_uRfsvmDU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DPSjQV5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xcY3VFZW, 0, m, &cDelay_xcY3VFZW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_U4v9w6Jd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xcY3VFZW, 0, m, &cDelay_xcY3VFZW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GZ5OjKFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kuNmqQdk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q1dCEOe2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GD12NKSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hafQOdwh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SEYeCPGs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SEYeCPGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IZxft8yc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hafQOdwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uRfsvmDU, 1, m, &cIf_uRfsvmDU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q1dCEOe2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MJ90j9O8, 0, m, &cIf_MJ90j9O8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kuNmqQdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MJ90j9O8, 1, m, &cIf_MJ90j9O8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rhowaUlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ThHvsdGe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_z9f2rQI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ThHvsdGe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_J2sxOIZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_z6sZjyk1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Vxbf4rQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9fEGITRc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Bw5GOnUm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0A9lHlg9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0A9lHlg9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ptFXNHdr, 1, m, &cDelay_ptFXNHdr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cqTcEM3u_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ptFXNHdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ptFXNHdr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_J2sxOIZO, 0, m, &cIf_J2sxOIZO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0A9lHlg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ptFXNHdr, 0, m, &cDelay_ptFXNHdr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cqTcEM3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ptFXNHdr, 0, m, &cDelay_ptFXNHdr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_H8Dsp4lw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VgM7KnY3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WQRgbmHF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Cwo0VQh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_On7KS7I1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_43t7FTez_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_43t7FTez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Bw5GOnUm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_On7KS7I1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J2sxOIZO, 1, m, &cIf_J2sxOIZO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WQRgbmHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Vxbf4rQO, 0, m, &cIf_Vxbf4rQO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VgM7KnY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Vxbf4rQO, 1, m, &cIf_Vxbf4rQO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9fEGITRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v3KJpkRQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_z6sZjyk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v3KJpkRQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_nTQxWc7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8jD4TLO0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yDwwT0Tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_u5J2WjS0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NFSXL42z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_z9zZ2rYa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_z9zZ2rYa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_N8fzR2Tp, 1, m, &cDelay_N8fzR2Tp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dLdF2Pvi_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_N8fzR2Tp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N8fzR2Tp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_nTQxWc7O, 0, m, &cIf_nTQxWc7O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z9zZ2rYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_N8fzR2Tp, 0, m, &cDelay_N8fzR2Tp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dLdF2Pvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_N8fzR2Tp, 0, m, &cDelay_N8fzR2Tp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CJd0dcTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pjfH4X1Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_keIC6p89_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QuzSdEJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cMD80ftY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UkOzCrWD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UkOzCrWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NFSXL42z_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cMD80ftY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nTQxWc7O, 1, m, &cIf_nTQxWc7O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pjfH4X1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yDwwT0Tm, 1, m, &cIf_yDwwT0Tm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_keIC6p89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yDwwT0Tm, 0, m, &cIf_yDwwT0Tm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u5J2WjS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qBCJVUTU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8jD4TLO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qBCJVUTU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_dWayJKd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3u6Efpfy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_x9ZWrpqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mHNpxXeb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PZ5TWTne_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lSZRJDV2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lSZRJDV2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7IfGM0I0, 1, m, &cDelay_7IfGM0I0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_csCLRRKr_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7IfGM0I0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7IfGM0I0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_dWayJKd6, 0, m, &cIf_dWayJKd6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lSZRJDV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7IfGM0I0, 0, m, &cDelay_7IfGM0I0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_csCLRRKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7IfGM0I0, 0, m, &cDelay_7IfGM0I0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_080exdd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bTdzixhf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rJmPF07Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FKRtS5UA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nqYGexWg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_62hh2YGv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_62hh2YGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PZ5TWTne_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nqYGexWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dWayJKd6, 1, m, &cIf_dWayJKd6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rJmPF07Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x9ZWrpqs, 0, m, &cIf_x9ZWrpqs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bTdzixhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x9ZWrpqs, 1, m, &cIf_x9ZWrpqs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mHNpxXeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YvFXrgU1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3u6Efpfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YvFXrgU1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ywQ6M0mK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XNABIIAs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NDIJc2QQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Bvy6GUj0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4UUfX8LK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SD6up2gr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SD6up2gr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_djGN7llJ, 1, m, &cDelay_djGN7llJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1kDsgKmd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_djGN7llJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_djGN7llJ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ywQ6M0mK, 0, m, &cIf_ywQ6M0mK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SD6up2gr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_djGN7llJ, 0, m, &cDelay_djGN7llJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1kDsgKmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_djGN7llJ, 0, m, &cDelay_djGN7llJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DjFyZswL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DU9ZjUd7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rzyWtSsj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EajOEetY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7ZCLAfUB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BizIoiMp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7ZCLAfUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ywQ6M0mK, 1, m, &cIf_ywQ6M0mK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BizIoiMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4UUfX8LK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rzyWtSsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NDIJc2QQ, 0, m, &cIf_NDIJc2QQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DU9ZjUd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NDIJc2QQ, 1, m, &cIf_NDIJc2QQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Bvy6GUj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2WNjZhoi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XNABIIAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2WNjZhoi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_HeDFMjKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_N1RiP36M_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ZIDzXzp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hTin2QzQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4AsHgQkz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tcFTq65V_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tcFTq65V_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_N59lag4j, 1, m, &cDelay_N59lag4j_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_luCJKDRR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_N59lag4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N59lag4j, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HeDFMjKl, 0, m, &cIf_HeDFMjKl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tcFTq65V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_N59lag4j, 0, m, &cDelay_N59lag4j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_luCJKDRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_N59lag4j, 0, m, &cDelay_N59lag4j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cvjEdwqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FATQCfet_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VuQiKhIK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qKgVg4cl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mirjxEAh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2bsECMiu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2bsECMiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4AsHgQkz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mirjxEAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HeDFMjKl, 1, m, &cIf_HeDFMjKl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VuQiKhIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZIDzXzp3, 0, m, &cIf_ZIDzXzp3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FATQCfet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZIDzXzp3, 1, m, &cIf_ZIDzXzp3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hTin2QzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZzRHyPad, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_N1RiP36M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZzRHyPad, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_sqU1Y1LB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_k4WEcLAL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_7zMW8oaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eB6z1WU5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0lP1I6xm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DzOiAJn2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DzOiAJn2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2Yj16Pjk, 1, m, &cDelay_2Yj16Pjk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zQRpY1lE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2Yj16Pjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2Yj16Pjk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_sqU1Y1LB, 0, m, &cIf_sqU1Y1LB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DzOiAJn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2Yj16Pjk, 0, m, &cDelay_2Yj16Pjk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zQRpY1lE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2Yj16Pjk, 0, m, &cDelay_2Yj16Pjk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MuWWQlWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7La7YgR8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7BRDIVvb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nMBjgq71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zA9mitF9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jvz5e8T0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jvz5e8T0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0lP1I6xm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_zA9mitF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sqU1Y1LB, 1, m, &cIf_sqU1Y1LB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7La7YgR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7zMW8oaR, 1, m, &cIf_7zMW8oaR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7BRDIVvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7zMW8oaR, 0, m, &cIf_7zMW8oaR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eB6z1WU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_srH0axTJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_k4WEcLAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_srH0axTJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gAmYY0rI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aFF3N3rv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_x2J0sPbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_r0V0iPdr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_x11MqcaR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9V0M69FH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9V0M69FH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mEbk6MBb, 1, m, &cDelay_mEbk6MBb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jyKLYd8I_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mEbk6MBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mEbk6MBb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gAmYY0rI, 0, m, &cIf_gAmYY0rI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9V0M69FH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mEbk6MBb, 0, m, &cDelay_mEbk6MBb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jyKLYd8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mEbk6MBb, 0, m, &cDelay_mEbk6MBb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pDqxcae3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rhqSGtLD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F0l1sSlq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4HRBz9f2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AoSt8BI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BYMOdfiA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BYMOdfiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_x11MqcaR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4AoSt8BI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gAmYY0rI, 1, m, &cIf_gAmYY0rI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F0l1sSlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x2J0sPbb, 0, m, &cIf_x2J0sPbb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rhqSGtLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x2J0sPbb, 1, m, &cIf_x2J0sPbb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_r0V0iPdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mOhfvYxf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aFF3N3rv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mOhfvYxf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LPUXZVOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_LQECUI4Z_sendMessage(_c, 0, m);
  cMsg_gLNOP0X2_sendMessage(_c, 0, m);
  cMsg_cxMJGJQi_sendMessage(_c, 0, m);
  cMsg_pKWHnAa6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_B12bz3Ue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_LQECUI4Z_sendMessage(_c, 0, m);
  cMsg_TwNSbHHs_sendMessage(_c, 0, m);
  cMsg_y2Ydj1dl_sendMessage(_c, 0, m);
  cMsg_GoejJXGL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_W82ioO1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_WZjhkcXR_sendMessage(_c, 0, m);
  cMsg_TwNSbHHs_sendMessage(_c, 0, m);
  cMsg_pKWHnAa6_sendMessage(_c, 0, m);
  cMsg_qWGTld1e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WCevvxXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_WZjhkcXR_sendMessage(_c, 0, m);
  cMsg_epnCQHzR_sendMessage(_c, 0, m);
  cMsg_cxMJGJQi_sendMessage(_c, 0, m);
  cMsg_niAc7jLZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qRy16uV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_l5at4sDO_sendMessage(_c, 0, m);
  cMsg_GoejJXGL_sendMessage(_c, 0, m);
  cMsg_rBg3SDnE_sendMessage(_c, 0, m);
  cMsg_cxMJGJQi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sxhoj7iu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_l5at4sDO_sendMessage(_c, 0, m);
  cMsg_niAc7jLZ_sendMessage(_c, 0, m);
  cMsg_TwNSbHHs_sendMessage(_c, 0, m);
  cMsg_sZx5hqGS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hIDxZUzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PSTeF07h_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Q2whULbI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qYvVh7dv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PSTeF07h_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Q2whULbI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N9YlSmgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dgpOTdPe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tlEHUQsm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FMolzKsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dgpOTdPe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tlEHUQsm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g6nacC44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oDgtt7Jo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6bcyQxc4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pmlibPLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oDgtt7Jo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6bcyQxc4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LQECUI4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_hIDxZUzY_sendMessage(_c, 0, m);
  cMsg_FMolzKsF_sendMessage(_c, 0, m);
  cMsg_pmlibPLF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WZjhkcXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_qYvVh7dv_sendMessage(_c, 0, m);
  cMsg_N9YlSmgn_sendMessage(_c, 0, m);
  cMsg_pmlibPLF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_l5at4sDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_qYvVh7dv_sendMessage(_c, 0, m);
  cMsg_FMolzKsF_sendMessage(_c, 0, m);
  cMsg_g6nacC44_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RNQUdivE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i2RljbqK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kNJzDD9r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_L5hyABYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i2RljbqK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kNJzDD9r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0MQYUvx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GD12NKSa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GZ5OjKFF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5M5RniYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GD12NKSa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GZ5OjKFF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bYRRO4Ni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Cwo0VQh7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H8Dsp4lw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_74cD3vPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Cwo0VQh7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H8Dsp4lw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TwNSbHHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_L5hyABYp_sendMessage(_c, 0, m);
  cMsg_5M5RniYM_sendMessage(_c, 0, m);
  cMsg_74cD3vPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gLNOP0X2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_L5hyABYp_sendMessage(_c, 0, m);
  cMsg_0MQYUvx5_sendMessage(_c, 0, m);
  cMsg_bYRRO4Ni_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_epnCQHzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_RNQUdivE_sendMessage(_c, 0, m);
  cMsg_5M5RniYM_sendMessage(_c, 0, m);
  cMsg_bYRRO4Ni_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uzkGs80K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qKgVg4cl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cvjEdwqP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KDJowYRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qKgVg4cl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cvjEdwqP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CLA917Cb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nMBjgq71_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MuWWQlWs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gnB57IM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nMBjgq71_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MuWWQlWs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_86H1Skin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4HRBz9f2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pDqxcae3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5E2EuEDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4HRBz9f2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pDqxcae3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_niAc7jLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_uzkGs80K_sendMessage(_c, 0, m);
  cMsg_gnB57IM5_sendMessage(_c, 0, m);
  cMsg_5E2EuEDl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GoejJXGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_KDJowYRK_sendMessage(_c, 0, m);
  cMsg_CLA917Cb_sendMessage(_c, 0, m);
  cMsg_5E2EuEDl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pKWHnAa6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_KDJowYRK_sendMessage(_c, 0, m);
  cMsg_gnB57IM5_sendMessage(_c, 0, m);
  cMsg_86H1Skin_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wYbElDfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QuzSdEJB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CJd0dcTR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EHBa8Jmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QuzSdEJB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CJd0dcTR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fsZgTthI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FKRtS5UA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_080exdd6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aooEudVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FKRtS5UA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_080exdd6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KvcPg9qV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EajOEetY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DjFyZswL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KnqDrCiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EajOEetY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DjFyZswL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cxMJGJQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_EHBa8Jmb_sendMessage(_c, 0, m);
  cMsg_aooEudVq_sendMessage(_c, 0, m);
  cMsg_KnqDrCiz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_y2Ydj1dl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_EHBa8Jmb_sendMessage(_c, 0, m);
  cMsg_fsZgTthI_sendMessage(_c, 0, m);
  cMsg_KvcPg9qV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sZx5hqGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_wYbElDfe_sendMessage(_c, 0, m);
  cMsg_fsZgTthI_sendMessage(_c, 0, m);
  cMsg_KnqDrCiz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rBg3SDnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_RNQUdivE_sendMessage(_c, 0, m);
  cMsg_0MQYUvx5_sendMessage(_c, 0, m);
  cMsg_74cD3vPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qWGTld1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_wYbElDfe_sendMessage(_c, 0, m);
  cMsg_aooEudVq_sendMessage(_c, 0, m);
  cMsg_KvcPg9qV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_8LK30UQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q5bTy3ZT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7fzJPw6I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1ucYgSo4, 0, m, &cSlice_1ucYgSo4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QIlgxP7B_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_1ucYgSo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0oKJepyr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0oKJepyr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_LsN48ec8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0oKJepyr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0oKJepyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RmJ0khM8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_khg4HWFE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ROnvxtEn, 0, m, &cSlice_ROnvxtEn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_e5X7J9pM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ROnvxtEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_idA3MMaM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_idA3MMaM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_BV7I4EEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_idA3MMaM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_idA3MMaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1V1InTTU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_e5X7J9pM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LhubyV3X, 0, m, &cSlice_LhubyV3X_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7fzJPw6I_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_LhubyV3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KFl7aY2O_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KFl7aY2O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_nKhQ2v18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KFl7aY2O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_KFl7aY2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4ZlNkMM9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QIlgxP7B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ii0E5KGu, 0, m, &cSlice_ii0E5KGu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ksUKGE3c_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ii0E5KGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QkLSh5pt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QkLSh5pt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_u5nvMzrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QkLSh5pt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_QkLSh5pt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_r7D5obv7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ksUKGE3c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Y1iNpJjw, 0, m, &cSlice_Y1iNpJjw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oNfvYJXc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Y1iNpJjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_diP9d4QL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_diP9d4QL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Sd5WgGzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_diP9d4QL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_diP9d4QL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QBBXj5fc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YUMEo0CD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tg9WmQjx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tg9WmQjx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_D83dUMS9, 1, m, &cDelay_D83dUMS9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lneuqYGS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_D83dUMS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D83dUMS9, m);
  cMsg_X4ECVkz1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tg9WmQjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_D83dUMS9, 0, m, &cDelay_D83dUMS9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lneuqYGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D83dUMS9, 0, m, &cDelay_D83dUMS9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_BLt6rdaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zUC0S1zq, HV_BINOP_SUBTRACT, 0, m, &cBinop_zUC0S1zq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_O97ayKhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bmyWH0Zr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oE1JeWJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bmyWH0Zr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_UX5G5BFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BLt6rdaq, 0, m, &cVar_BLt6rdaq_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_vfABTrp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bu52xik8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zAIKFKtT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c4XekthH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zUC0S1zq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sVTbWb5x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sVTbWb5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_n0TuvnSL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n0TuvnSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_f7ipOCH7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OcMg8JYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bFRzK6pp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9mwJ2rDH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9mwJ2rDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0kGcrT29_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_bFRzK6pp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O97ayKhz, 1, m, &cIf_O97ayKhz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WnN7XniD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oE1JeWJJ, 1, m, &cIf_oE1JeWJJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0kGcrT29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_O97ayKhz, 0, m, &cIf_O97ayKhz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f7ipOCH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oE1JeWJJ, 0, m, &cIf_oE1JeWJJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zAIKFKtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zUC0S1zq, HV_BINOP_SUBTRACT, 1, m, &cBinop_zUC0S1zq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bu52xik8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_c4XekthH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BLt6rdaq, 0, m, &cVar_BLt6rdaq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bmyWH0Zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g7jh23Fh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oNfvYJXc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vHYJKgRh, 0, m, &cSlice_vHYJKgRh_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_vHYJKgRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Xv2LN2ip_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Xv2LN2ip_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ZRza9F2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Xv2LN2ip_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Xv2LN2ip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rmKSDlfS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4lreTCw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bRwshUzZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RGaOmOJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0eJNTmFY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_lmd797pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JgGyZc2n, 0, m, &cVar_JgGyZc2n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_q5bTy3ZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Rb0bmp99, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_R2fwrSJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v73qsHin_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_q32jGM6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YUMEo0CD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_X4ECVkz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tSXOFPwQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_v73qsHin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tSXOFPwQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KcXM2WFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Duz7BMDe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Duz7BMDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9jqCzexo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9jqCzexo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jslyrezl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_slfhGg1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZoVRaqPh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_3XVczCOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zoIG69ML_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_WzrmwYXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_blUYVvmI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_c0idNmr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8sPRx3kb_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VF5Bv13g_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_XdoXq2yW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dLCjmEIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8sPRx3kb_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VF5Bv13g_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_XdoXq2yW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_QKIZQfKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yaq8gVuR, 0, m, &cVar_yaq8gVuR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WIz2XAiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8sPRx3kb_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VF5Bv13g_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_XdoXq2yW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BdZzSbVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8sPRx3kb_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VF5Bv13g_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_XdoXq2yW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_efNFIn1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8sPRx3kb_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VF5Bv13g_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_XdoXq2yW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_H9nX1mT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_EMR5tyYR, 0, m, &cVar_EMR5tyYR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TmXiSvQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_SFIUM7DZ, 0, m, &cVar_SFIUM7DZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hAxngoLw, 0, m, &cVar_hAxngoLw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Jojdf8Gp, 0, m, &cVar_Jojdf8Gp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WAKAU05g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_QKIZQfKS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PJCqIPrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4e938pHd_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yxdvmeLW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ufk4nNtA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4e938pHd_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yxdvmeLW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_b4NBPylR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4e938pHd_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yxdvmeLW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_X68svkLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4e938pHd_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yxdvmeLW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0FUcrlgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4e938pHd_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_yxdvmeLW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JL4CdvVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_iHJKKhFt, 0, m, &cVar_iHJKKhFt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J5ARAxGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_HSvxFpEE, 0, m, &cVar_HSvxFpEE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C967YwGe, 0, m, &cVar_C967YwGe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6QiQU5O5, 0, m, &cVar_6QiQU5O5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4oQSdxci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8sPRx3kb_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VF5Bv13g_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_XdoXq2yW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lEDMPxe7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_tiNoSK0l_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_F2hYXSZG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6cVY9AjX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NBY3uasp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_tiNoSK0l_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_F2hYXSZG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6cVY9AjX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_1erPI22j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FvuSbhK2, 0, m, &cVar_FvuSbhK2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6J3I4rQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_tiNoSK0l_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_F2hYXSZG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6cVY9AjX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_np3JJ9JN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_tiNoSK0l_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_F2hYXSZG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6cVY9AjX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KeO97LBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_tiNoSK0l_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_F2hYXSZG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6cVY9AjX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tJ4i5liv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_q8LN79Z0, 0, m, &cVar_q8LN79Z0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dggzknMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ono9UQZ9, 0, m, &cVar_ono9UQZ9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PJTtsY4L, 0, m, &cVar_PJTtsY4L_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ee91MX7t, 0, m, &cVar_ee91MX7t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7Z7CSnP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_1erPI22j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Iyeh0vcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_tiNoSK0l_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_F2hYXSZG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6cVY9AjX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DWb1DtBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_P29aHlZq_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MAB1Cut4_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_khg4HWFE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rgXEAEbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_P29aHlZq_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MAB1Cut4_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_khg4HWFE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_yyisdT2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U6yKXRyK, 0, m, &cVar_U6yKXRyK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P76l5J4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_P29aHlZq_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MAB1Cut4_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_khg4HWFE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KrWIOTW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_P29aHlZq_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MAB1Cut4_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_khg4HWFE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bf97Spw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_P29aHlZq_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MAB1Cut4_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_khg4HWFE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YwhjN5uU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_R84QtEyx, 0, m, &cVar_R84QtEyx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a7BFPgaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_dnNhFBrh, 0, m, &cVar_dnNhFBrh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8mB5yb96, 0, m, &cVar_8mB5yb96_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ieRz6eEG, 0, m, &cVar_ieRz6eEG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_suWnrWaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_yyisdT2z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LxjWRjyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_P29aHlZq_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MAB1Cut4_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_khg4HWFE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6lSFWh83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_slfhGg1e, 0, m, &cVar_slfhGg1e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZoVRaqPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8sPRx3kb_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VF5Bv13g_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_XdoXq2yW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2Wye3nxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_3XVczCOe, 0, m, &cVar_3XVczCOe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zoIG69ML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_tiNoSK0l_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_F2hYXSZG_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6cVY9AjX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kdYiPoRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_WzrmwYXZ, 0, m, &cVar_WzrmwYXZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_blUYVvmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_P29aHlZq_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MAB1Cut4_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_khg4HWFE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_eDT8HuYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W0PLBZLb_sendMessage(_c, 0, m);
  cMsg_fe759hdN_sendMessage(_c, 0, m);
  cMsg_nlkC37xS_sendMessage(_c, 0, m);
  cMsg_YsazlDiX_sendMessage(_c, 0, m);
  cMsg_0FSPkRcR_sendMessage(_c, 0, m);
  cMsg_MHSQHJJd_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_AgOd8T4s, 0, m, &cVar_AgOd8T4s_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QIuzuwBT, 0, m, &cVar_QIuzuwBT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hOlf1kCr, 0, m, &cVar_hOlf1kCr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_04JfFAnb, 0, m, &cVar_04JfFAnb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y7aj91xp, 0, m, &cVar_Y7aj91xp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XfVVHT9U, 0, m, &cVar_XfVVHT9U_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fj835w0X, 0, m, &cVar_fj835w0X_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wCKo499u, 0, m, &cVar_wCKo499u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5LFywbLo, 0, m, &cVar_5LFywbLo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MlY43meW, 0, m, &cVar_MlY43meW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_murOTVKr, 0, m, &cVar_murOTVKr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tU1aajCw, 0, m, &cVar_tU1aajCw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yjss5ajb, 0, m, &cVar_yjss5ajb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0wC3iGqP, 0, m, &cVar_0wC3iGqP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NoSts5OO, 0, m, &cVar_NoSts5OO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cuS5V7H8, 0, m, &cVar_cuS5V7H8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PgW2djf6, 0, m, &cVar_PgW2djf6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7ePGEta4, 0, m, &cVar_7ePGEta4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AZSe2VpB, 0, m, &cVar_AZSe2VpB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MHRsDKlH, 0, m, &cVar_MHRsDKlH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0m135q8a, 0, m, &cVar_0m135q8a_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aqaWlUV9, 0, m, &cVar_aqaWlUV9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ldE3Q1Zn, 0, m, &cVar_ldE3Q1Zn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_g3AOIQIP, 0, m, &cVar_g3AOIQIP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dnoq2Mxp, 0, m, &cVar_dnoq2Mxp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2O6aAxGM, 0, m, &cVar_2O6aAxGM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dK3cdWzB, 0, m, &cVar_dK3cdWzB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FV04Yu3Q, 0, m, &cVar_FV04Yu3Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fIaf4rbz, 0, m, &cVar_fIaf4rbz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UXaRNwA2, 0, m, &cVar_UXaRNwA2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CumDOwN3, 0, m, &cVar_CumDOwN3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_W9eu0r0R, 0, m, &cVar_W9eu0r0R_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7UMeH7XZ, 0, m, &cVar_7UMeH7XZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JHS3EFcl, 0, m, &cVar_JHS3EFcl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_x8BfBaJ6, 0, m, &cVar_x8BfBaJ6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GkziVjRb, 0, m, &cVar_GkziVjRb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ijS8UDbr, 0, m, &cVar_ijS8UDbr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7mEj1rIS, 0, m, &cVar_7mEj1rIS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3sVZtc4K, 0, m, &cVar_3sVZtc4K_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RwGvkjNn, 0, m, &cVar_RwGvkjNn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_l1GQG2EK, 0, m, &cVar_l1GQG2EK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_37BbmJBR, 0, m, &cVar_37BbmJBR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zxIoi3pJ, 0, m, &cVar_zxIoi3pJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CahfVcAn, 0, m, &cVar_CahfVcAn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kM2knrj3, 0, m, &cVar_kM2knrj3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_b6mUH3ND, 0, m, &cVar_b6mUH3ND_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pkFhSf1r, 0, m, &cVar_pkFhSf1r_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Cagbe23F, 0, m, &cVar_Cagbe23F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kEHNOngX, 0, m, &cVar_kEHNOngX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TpDcaxyS, 0, m, &cVar_TpDcaxyS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cev3HfJi, 0, m, &cVar_cev3HfJi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Fp9R7bO2, 0, m, &cVar_Fp9R7bO2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LsN48ec8, 0, m, &cVar_LsN48ec8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BV7I4EEP, 0, m, &cVar_BV7I4EEP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nKhQ2v18, 0, m, &cVar_nKhQ2v18_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_u5nvMzrU, 0, m, &cVar_u5nvMzrU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Sd5WgGzm, 0, m, &cVar_Sd5WgGzm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZRza9F2L, 0, m, &cVar_ZRza9F2L_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kozznx6t, 0, m, &cVar_kozznx6t_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YS1EdWcW, 0, m, &cVar_YS1EdWcW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pgyG0VK5, 0, m, &cVar_pgyG0VK5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mfgUks1e_sendMessage);
  cMsg_J5ARAxGO_sendMessage(_c, 0, m);
  cMsg_JL4CdvVy_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E1wnfJiS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JsNIernm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vARJj4ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HSvxFpEE, 0, m, &cVar_HSvxFpEE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GmpLKULZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C967YwGe, 0, m, &cVar_C967YwGe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_C8ngMg1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6QiQU5O5, 0, m, &cVar_6QiQU5O5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GqUlgWOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QIuzuwBT, 0, m, &cVar_QIuzuwBT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_12geb3UR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JGkl1DNY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VHCU8x42_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_mhQWJKXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yn51Pawu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5agQq0o9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jJ3JJW3D_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D5RNeqPZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_uav92x5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9huO1oNi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6z8pl9vk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DPILcGdt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TsTvlMwQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ELdx7P1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ihlbJLzr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XprWH4Ol_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZNDPvFLH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dAwFR7rW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_fSKD6hNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eSvC03Pv, HV_BINOP_MULTIPLY, 0, m, &cBinop_eSvC03Pv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YIHVjL8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gwWKdM35_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_sbTg8AIf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_l8TqQBzg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_nEuzuMnu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Uxqn4Mii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_I37O5t4U_sendMessage);
  cMsg_3abmM7Z8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_cRcDTkWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AtFveDkN, HV_BINOP_MULTIPLY, 0, m, &cBinop_AtFveDkN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eaPgcqqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ydZktZhH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_uVJjW78e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2R1zEnPr, HV_BINOP_MULTIPLY, 1, m, &cBinop_2R1zEnPr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_q510oTR7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fzgr3JVm_sendMessage);
  cMsg_PMqVF3LO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_IVQOQPvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6RWCRu5g, HV_BINOP_MULTIPLY, 0, m, &cBinop_6RWCRu5g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lGCOj1YP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mX1yI21F_sendMessage(_c, 0, m);
  cMsg_poYsVqmc_sendMessage(_c, 0, m);
  cMsg_29DwXao6_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_3lOpRJBh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6r724Fsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yYvEI2ED_sendMessage);
  cMsg_7i8AcFZe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_9EHlnb9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y7aj91xp, 0, m, &cVar_Y7aj91xp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4mYYK568_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TfG3nGf4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_URjQiD7j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_O9pRNF3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LQs8jKKN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gcEmhrml_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ebKDrTTb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vUBShK1R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pWEyAyVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jPIhVhHQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QHHqwAQL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xcj7iimG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KK5JchZE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RjGZ5CsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FU8cOMnX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Da9Wxxto_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eU6iKgP5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ePF6Re1i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UbxD4jvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tvx84nsb, HV_BINOP_MULTIPLY, 0, m, &cBinop_tvx84nsb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_V7J69L7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lS5trfIq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JBMUCLkD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zlFvwl7x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_u2b09BVX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_v01obU4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2OyD3ZPQ_sendMessage);
  cMsg_b9bg9Jog_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_WkK8tGeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yo1cZhJ2, HV_BINOP_MULTIPLY, 0, m, &cBinop_yo1cZhJ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_sVe9XILR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_t7Kr5hIc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ncbONSAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0CtEuqpu, HV_BINOP_MULTIPLY, 1, m, &cBinop_0CtEuqpu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_OKfDiJx2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xht3b9cg_sendMessage);
  cMsg_tIbg3zpx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_zhwLQS04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mF2fK7s1, HV_BINOP_MULTIPLY, 0, m, &cBinop_mF2fK7s1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1ArAlLhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BnLh6Tyz_sendMessage(_c, 0, m);
  cMsg_93TK7wWA_sendMessage(_c, 0, m);
  cMsg_8M7aquoj_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_cd0h2zxI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vW5F8ifZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NYnK37NV_sendMessage);
  cMsg_sMeuuiU2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_jfiCBMeU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iHJKKhFt, 0, m, &cVar_iHJKKhFt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yfWZHl0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NBL0wTD0, 0, m, &cVar_NBL0wTD0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rjxJDGOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EMR5tyYR, 0, m, &cVar_EMR5tyYR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_T7GkZfrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SFIUM7DZ, 0, m, &cVar_SFIUM7DZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qsqyEd5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hAxngoLw, 0, m, &cVar_hAxngoLw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_e9m7MtFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jojdf8Gp, 0, m, &cVar_Jojdf8Gp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lktBFuCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_QKIZQfKS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YzKGp62y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5RlhBMdu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_buKmobAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n5gUdYcL, 0, m, &cVar_n5gUdYcL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NQAMC6HN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FgTZUTEx, 0, m, &cVar_FgTZUTEx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZNWPdZzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_GQ5sItRJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YSEeMLRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iQvbITD1_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RUxxJ8sJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_beI8Z9Hi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lXi7S3nW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BRvIDmru_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_q3gNy4O0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_r62zN5ho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9DlkFBpl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_OTH86ad0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x6CHYP3q, 0, m, &cVar_x6CHYP3q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CbuxReZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xSoLrUUI, 0, m, &cVar_xSoLrUUI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WgUFlBb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_pJGYsJDe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_jxQ3tW8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pEbZh8fY_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D76GdFHj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lxIqT538_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_jpewozst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sOf7BLbC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Bfoj3Y2F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CLUbQ7tI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GPEBTwf8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_abNkLBHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZgRgYsMY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Ht2qOWzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uypG5CEL, 0, m, &cVar_uypG5CEL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Aw6vyy1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_J3z5lKsg, 0, m, &cVar_J3z5lKsg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Ac3M86HE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_tQG56T2v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_TaGKatIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Mfn2Lvjg_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_41BFKgbl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2CfMePuk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HiSp90r3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_o8ZWHCwu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wkRJy2jq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_OqY0K06b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cJuirSEK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_hK0yT19k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5Nk9jrUI, 0, m, &cVar_5Nk9jrUI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_W67qJV25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oHQtMKo2, 0, m, &cVar_oHQtMKo2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_uozmYR9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_JNns8a8y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_n4czyUOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WIELuJyT_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ksczoHg5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6lcPRSE3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Rzq5GVyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IbUCLGcF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bQVphLyU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RGZpXeyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jIdCdxI6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_zATcIB86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fslb5WnB, 0, m, &cVar_fslb5WnB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_tCcrvcSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_q8LN79Z0, 0, m, &cVar_q8LN79Z0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_JtnMPp7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ono9UQZ9, 0, m, &cVar_ono9UQZ9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_FwrvZhKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PJTtsY4L, 0, m, &cVar_PJTtsY4L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_MSzGTN5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ee91MX7t, 0, m, &cVar_ee91MX7t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YWNBMRwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_1erPI22j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7lY9z3a6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_C0Bl4T8G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_U20Owp7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UMU3sCiN, 0, m, &cVar_UMU3sCiN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Bz2emIAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8Tp3yE4S, 0, m, &cVar_8Tp3yE4S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_SDRUjHns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_q6y35g2S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_l6jFMwyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yYjerFZe_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JW5FVG7D_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6qkXe8ht_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_wBRok7PY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_s6xxNy3N_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PWv7FxoV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_tK70P3nL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g0RFBEzI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_RmJ0khM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qbovnTiJ, 0, m, &cVar_qbovnTiJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_r7D5obv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8LK30UQq, 0, m, &cVar_8LK30UQq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4ZlNkMM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_lmd797pk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1V1InTTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2CUwNUL6_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R2fwrSJn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q32jGM6p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QBBXj5fc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OcMg8JYp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WnN7XniD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rmKSDlfS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KcXM2WFs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_sIpumxv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aqiXY9V6, 0, m, &cVar_aqiXY9V6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UafQ7EKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R84QtEyx, 0, m, &cVar_R84QtEyx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nQcU1mwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dnNhFBrh, 0, m, &cVar_dnNhFBrh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_I0RvVZUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8mB5yb96, 0, m, &cVar_8mB5yb96_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YARDqO2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ieRz6eEG, 0, m, &cVar_ieRz6eEG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_TIjGh2hK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_yyisdT2z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_oiWKqCiq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_slfhGg1e, 0, m, &cVar_slfhGg1e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WhA6sN6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3XVczCOe, 0, m, &cVar_3XVczCOe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_TrcIqy7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WzrmwYXZ, 0, m, &cVar_WzrmwYXZ_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_atfLjTEz, VOf(Bf0));
    __hv_line_f(&sLine_a4GrECuc, VOf(Bf1));
    __hv_line_f(&sLine_jKOKVm6p, VOf(Bf2));
    __hv_line_f(&sLine_eRNMLLt2, VOf(Bf3));
    __hv_line_f(&sLine_YOL6lrdL, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_LKzSUg84, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_c4LPsshB, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_r432XzYz, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_gFlaEb8o, VOf(Bf1));
    __hv_line_f(&sLine_KlgFMa8U, VOf(Bf0));
    __hv_line_f(&sLine_8yAC7FUa, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_aAVGSfZG, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_e5eLVyJ4, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_TWgIeY2e, VOf(Bf5));
    __hv_line_f(&sLine_PC5R0gti, VOf(Bf1));
    __hv_line_f(&sLine_PpTPfLtO, VOf(Bf2));
    __hv_line_f(&sLine_RLqZiWme, VOf(Bf4));
    __hv_line_f(&sLine_fuXSSIIO, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_8LSbZFKS, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_E3JC5uHA, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_cevx1G6j, VOf(Bf6));
    __hv_line_f(&sLine_xEuczQB8, VOf(Bf2));
    __hv_line_f(&sLine_DgBIOjQQ, VOf(Bf1));
    __hv_line_f(&sLine_feNBolwe, VOf(Bf5));
    __hv_line_f(&sLine_zRyDQqXG, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_e7iMYI4j, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_cfUKzoDG, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_LHGAyNVU, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_WpFSzaGO, VOf(Bf2));
    __hv_line_f(&sLine_ZTooHvlT, VOf(Bf6));
    __hv_line_f(&sLine_oDPEuAAS, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_A0P7mKTQ, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_0egeMdVB, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_DciNfvqI, VOf(Bf8));
    __hv_line_f(&sLine_8xTFfLgD, VOf(Bf2));
    __hv_line_f(&sLine_KBCJXlmZ, VOf(Bf1));
    __hv_line_f(&sLine_83H0DuGT, VOf(Bf7));
    __hv_line_f(&sLine_IFkDMTWz, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_IzC0NTML, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_2IEhbMdG, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_FzLPdMtY, VIf(Bf0));
    __hv_varwrite_f(&sVarf_92cDzYwh, VIf(Bf6));
    __hv_varwrite_f(&sVarf_XHUyoXEp, VIf(Bf4));
    __hv_varwrite_f(&sVarf_2sMAjr91, VIf(Bf7));
    __hv_varread_f(&sVarf_uBhGseTu, VOf(Bf7));
    __hv_varread_f(&sVarf_TWCCR38k, VOf(Bf4));
    __hv_varread_f(&sVarf_NIz4yD1b, VOf(Bf6));
    __hv_varread_f(&sVarf_6oQefbA8, VOf(Bf0));
    __hv_varread_f(&sVarf_cAtEq0jY, VOf(Bf9));
    __hv_varread_f(&sVarf_B30IxKBV, VOf(Bf1));
    __hv_line_f(&sLine_HHZWbOB0, VOf(Bf2));
    __hv_line_f(&sLine_NSnnysyI, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_NIz4yD1b, VIf(Bf7));
    __hv_varwrite_f(&sVarf_cAtEq0jY, VIf(Bf4));
    __hv_varread_f(&sVarf_TKZPwyTZ, VOf(Bf2));
    __hv_varread_f(&sVarf_XJWKEgMp, VOf(Bf9));
    __hv_varread_f(&sVarf_ZGaiGZnV, VOf(Bf1));
    __hv_varread_f(&sVarf_Zp0Sshk7, VOf(Bf6));
    __hv_varread_f(&sVarf_6Ngjea96, VOf(Bf10));
    __hv_varread_f(&sVarf_mJRlDsQr, VOf(Bf11));
    __hv_varread_f(&sVarf_oKsqFyNv, VOf(Bf12));
    __hv_varwrite_f(&sVarf_QOxMw2DH, VIf(Bf7));
    __hv_varread_f(&sVarf_ftfvpA2w, VOf(Bf13));
    __hv_line_f(&sLine_Kq8SVdah, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_CZTJafai, VOf(Bf15));
    __hv_line_f(&sLine_oEJdvk0D, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_h6NDt5Gs, VOf(Bf14));
    __hv_line_f(&sLine_DCFer1Zt, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_Zp0Sshk7, VIf(Bf17));
    __hv_varread_f(&sVarf_QOxMw2DH, VOf(Bf17));
    __hv_line_f(&sLine_Xqz4jj3O, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_eg9ml84Z, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_tqTWgHyN, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_6Ngjea96, VIf(Bf16));
    __hv_line_f(&sLine_jpaPodTZ, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_Lx5rEpPq, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_PeZ68nL0, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_mJRlDsQr, VIf(Bf16));
    __hv_line_f(&sLine_HYAwkrQi, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_p0gq1VcF, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_kpWWgThS, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_oKsqFyNv, VIf(Bf16));
    __hv_varwrite_f(&sVarf_ftfvpA2w, VIf(Bf2));
    __hv_varwrite_f(&sVarf_CZTJafai, VIf(Bf9));
    __hv_varwrite_f(&sVarf_h6NDt5Gs, VIf(Bf1));
    sEnv_process(this, &sEnv_qAkugdHd, VIf(Bf6), &sEnv_qAkugdHd_sendMessage);
    sEnv_process(this, &sEnv_MreXH6Qx, VIf(Bf7), &sEnv_MreXH6Qx_sendMessage);
    __hv_line_f(&sLine_8lY7pmEO, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_i4hPeZLV, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_oLC9ICoz, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_8alScMX6, VOf(Bf6));
    __hv_line_f(&sLine_mgNQz2wB, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_TKZPwyTZ, VIf(Bf9));
    __hv_varwrite_f(&sVarf_8alScMX6, VIf(Bf10));
    __hv_varwrite_f(&sVarf_WEUe3i0P, VIf(Bf11));
    __hv_varwrite_f(&sVarf_THcvjY4g, VIf(Bf12));
    __hv_varread_f(&sVarf_THcvjY4g, VOf(Bf12));
    __hv_line_f(&sLine_KGoc2gO8, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_ZGaiGZnV, VIf(Bf10));
    __hv_varread_f(&sVarf_WEUe3i0P, VOf(Bf10));
    __hv_line_f(&sLine_5smm3uys, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_XJWKEgMp, VIf(Bf10));
    __hv_varwrite_f(&sVarf_6oQefbA8, VIf(Bf7));
    __hv_varread_f(&sVarf_ct6lJV2l, VOf(Bf7));
    __hv_varread_f(&sVarf_b9Kr1Sry, VOf(Bf10));
    __hv_varread_f(&sVarf_ZvmC07bo, VOf(Bf9));
    __hv_varread_f(&sVarf_jNrtpQbZ, VOf(Bf11));
    __hv_varread_f(&sVarf_MkG8oYAp, VOf(Bf6));
    __hv_varread_f(&sVarf_J0FI0lv4, VOf(Bf12));
    __hv_varread_f(&sVarf_PmuehAje, VOf(Bf1));
    __hv_varwrite_f(&sVarf_LQ8Ziq5l, VIf(Bf4));
    __hv_varread_f(&sVarf_beiufeOd, VOf(Bf2));
    __hv_line_f(&sLine_PF2SkrMm, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_FYHaCopZ, VOf(Bf17));
    __hv_line_f(&sLine_PT2VAXku, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_wFlz5Oud, VOf(Bf16));
    __hv_line_f(&sLine_TelBcEjD, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_jNrtpQbZ, VIf(Bf15));
    __hv_varread_f(&sVarf_LQ8Ziq5l, VOf(Bf15));
    __hv_line_f(&sLine_XH0IeQDf, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_fN9h9Lx5, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_FULWliam, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_MkG8oYAp, VIf(Bf13));
    __hv_line_f(&sLine_Yi1vWqsP, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_wP6x3Sra, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_JWvkgLMc, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_J0FI0lv4, VIf(Bf13));
    __hv_line_f(&sLine_a1nJuZC0, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_XcxZUoBe, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_q8T1drzt, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_PmuehAje, VIf(Bf13));
    __hv_varwrite_f(&sVarf_beiufeOd, VIf(Bf7));
    __hv_varwrite_f(&sVarf_FYHaCopZ, VIf(Bf10));
    __hv_varwrite_f(&sVarf_wFlz5Oud, VIf(Bf9));
    sEnv_process(this, &sEnv_hmUkP2Ur, VIf(Bf11), &sEnv_hmUkP2Ur_sendMessage);
    sEnv_process(this, &sEnv_ebKDkGXi, VIf(Bf4), &sEnv_ebKDkGXi_sendMessage);
    __hv_line_f(&sLine_BRne8ebW, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_1QPlyaGk, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_eby9Jmzw, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_HdiSuhqx, VOf(Bf11));
    __hv_line_f(&sLine_VFyCHDbY, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_ct6lJV2l, VIf(Bf10));
    __hv_varwrite_f(&sVarf_HdiSuhqx, VIf(Bf6));
    __hv_varwrite_f(&sVarf_6o79A8v8, VIf(Bf12));
    __hv_varwrite_f(&sVarf_pFy6rpPl, VIf(Bf1));
    __hv_varread_f(&sVarf_pFy6rpPl, VOf(Bf1));
    __hv_line_f(&sLine_e8vwUzJi, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_ZvmC07bo, VIf(Bf6));
    __hv_varread_f(&sVarf_6o79A8v8, VOf(Bf6));
    __hv_line_f(&sLine_0nzR12Ez, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_b9Kr1Sry, VIf(Bf6));
    __hv_varwrite_f(&sVarf_B30IxKBV, VIf(Bf4));
    __hv_varwrite_f(&sVarf_5Oc5IzF4, VIf(Bf0));
    __hv_varread_f(&sVarf_FzLPdMtY, VOf(Bf0));
    __hv_varread_f(&sVarf_92cDzYwh, VOf(Bf4));
    __hv_varread_f(&sVarf_u61Y1BzS, VOf(Bf6));
    __hv_varread_f(&sVarf_9Yk3YfYo, VOf(Bf10));
    __hv_varread_f(&sVarf_eKq59oJn, VOf(Bf12));
    __hv_varread_f(&sVarf_23DBlulU, VOf(Bf11));
    __hv_line_f(&sLine_OsuoYFFi, VOf(Bf1));
    __hv_line_f(&sLine_qmr728aw, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_u61Y1BzS, VIf(Bf0));
    __hv_varwrite_f(&sVarf_eKq59oJn, VIf(Bf4));
    __hv_varread_f(&sVarf_Bd8dCUAU, VOf(Bf1));
    __hv_varread_f(&sVarf_KLklZKBN, VOf(Bf12));
    __hv_varread_f(&sVarf_Ni5PWnYb, VOf(Bf11));
    __hv_varread_f(&sVarf_2RRfujIr, VOf(Bf6));
    __hv_varread_f(&sVarf_dN55Ij6u, VOf(Bf7));
    __hv_varread_f(&sVarf_TijLIO7E, VOf(Bf13));
    __hv_varread_f(&sVarf_m6DwWNx1, VOf(Bf15));
    __hv_varwrite_f(&sVarf_ktK4dJqs, VIf(Bf0));
    __hv_varread_f(&sVarf_jq7dNR6A, VOf(Bf2));
    __hv_line_f(&sLine_c83sF4gI, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_n6IBV3fJ, VOf(Bf18));
    __hv_line_f(&sLine_LF6U4hlY, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_BGH8sn9Q, VOf(Bf17));
    __hv_line_f(&sLine_vVVzVcNV, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_2RRfujIr, VIf(Bf14));
    __hv_varread_f(&sVarf_ktK4dJqs, VOf(Bf14));
    __hv_line_f(&sLine_7bHIEkfL, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_JIawtIJ9, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_zdtXr6HK, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_dN55Ij6u, VIf(Bf16));
    __hv_line_f(&sLine_VJuCMeM8, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_SfHBkP6r, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_77Pfx9Ru, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_TijLIO7E, VIf(Bf16));
    __hv_line_f(&sLine_tP959rhQ, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_YmM7x51x, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_rNnLTlBK, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_m6DwWNx1, VIf(Bf16));
    __hv_varwrite_f(&sVarf_jq7dNR6A, VIf(Bf1));
    __hv_varwrite_f(&sVarf_n6IBV3fJ, VIf(Bf12));
    __hv_varwrite_f(&sVarf_BGH8sn9Q, VIf(Bf11));
    sEnv_process(this, &sEnv_OTMCXNQM, VIf(Bf6), &sEnv_OTMCXNQM_sendMessage);
    sEnv_process(this, &sEnv_BmPKLLVZ, VIf(Bf0), &sEnv_BmPKLLVZ_sendMessage);
    __hv_line_f(&sLine_91hWqGia, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_Vo1zPwuv, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_ceK2FSHa, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_vSyor7si, VOf(Bf6));
    __hv_line_f(&sLine_XP4paGqh, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_Bd8dCUAU, VIf(Bf12));
    __hv_varwrite_f(&sVarf_vSyor7si, VIf(Bf7));
    __hv_varwrite_f(&sVarf_gqSO1ymZ, VIf(Bf13));
    __hv_varwrite_f(&sVarf_k6VwNPf7, VIf(Bf15));
    __hv_varread_f(&sVarf_k6VwNPf7, VOf(Bf15));
    __hv_line_f(&sLine_JcnM9Km4, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_Ni5PWnYb, VIf(Bf7));
    __hv_varread_f(&sVarf_gqSO1ymZ, VOf(Bf7));
    __hv_line_f(&sLine_Tugqri45, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_KLklZKBN, VIf(Bf7));
    __hv_varwrite_f(&sVarf_9Yk3YfYo, VIf(Bf0));
    __hv_varread_f(&sVarf_QZ2t5mx4, VOf(Bf0));
    __hv_varread_f(&sVarf_6ZgUSgrf, VOf(Bf7));
    __hv_varread_f(&sVarf_QmrWO2YG, VOf(Bf12));
    __hv_varread_f(&sVarf_9rrUQOGG, VOf(Bf13));
    __hv_varread_f(&sVarf_0xyd393O, VOf(Bf6));
    __hv_varread_f(&sVarf_VxKShsKh, VOf(Bf15));
    __hv_varread_f(&sVarf_8zz7gqxM, VOf(Bf11));
    __hv_varwrite_f(&sVarf_Sip5SJu9, VIf(Bf4));
    __hv_varread_f(&sVarf_DqnJVRxj, VOf(Bf1));
    __hv_line_f(&sLine_tlpJBsnC, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_iyBcm202, VOf(Bf14));
    __hv_line_f(&sLine_pq7UBq75, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_hVVumXoX, VOf(Bf16));
    __hv_line_f(&sLine_FEpFA6WZ, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_9rrUQOGG, VIf(Bf18));
    __hv_varread_f(&sVarf_Sip5SJu9, VOf(Bf18));
    __hv_line_f(&sLine_bzMf1MDG, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_9fYolomI, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_8wb7aPu1, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_0xyd393O, VIf(Bf2));
    __hv_line_f(&sLine_VHFVZeRu, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_UPkACdnJ, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_N88PzxSv, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_VxKShsKh, VIf(Bf2));
    __hv_line_f(&sLine_5Yku40Ce, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_5ck0hCrS, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_ZfbI4SCK, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_8zz7gqxM, VIf(Bf2));
    __hv_varwrite_f(&sVarf_DqnJVRxj, VIf(Bf0));
    __hv_varwrite_f(&sVarf_iyBcm202, VIf(Bf7));
    __hv_varwrite_f(&sVarf_hVVumXoX, VIf(Bf12));
    sEnv_process(this, &sEnv_VyAHaKV5, VIf(Bf13), &sEnv_VyAHaKV5_sendMessage);
    sEnv_process(this, &sEnv_IlczPjBn, VIf(Bf4), &sEnv_IlczPjBn_sendMessage);
    __hv_line_f(&sLine_Dfg8kW3j, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_6uOITxb2, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_a2Y5bGtR, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_SCG99p5G, VOf(Bf13));
    __hv_line_f(&sLine_wztfoUeP, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_QZ2t5mx4, VIf(Bf7));
    __hv_varwrite_f(&sVarf_SCG99p5G, VIf(Bf6));
    __hv_varwrite_f(&sVarf_w6F8JmJW, VIf(Bf15));
    __hv_varwrite_f(&sVarf_V0uC7lEJ, VIf(Bf11));
    __hv_varread_f(&sVarf_V0uC7lEJ, VOf(Bf11));
    __hv_line_f(&sLine_5nEf8cMR, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_QmrWO2YG, VIf(Bf6));
    __hv_varread_f(&sVarf_w6F8JmJW, VOf(Bf6));
    __hv_line_f(&sLine_sY6shsGG, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_6ZgUSgrf, VIf(Bf6));
    __hv_varwrite_f(&sVarf_23DBlulU, VIf(Bf4));
    __hv_varwrite_f(&sVarf_VnpAVqX2, VIf(Bf10));
    __hv_varread_f(&sVarf_XHUyoXEp, VOf(Bf10));
    __hv_varread_f(&sVarf_2sMAjr91, VOf(Bf4));
    __hv_varread_f(&sVarf_zOKO7k0F, VOf(Bf6));
    __hv_varread_f(&sVarf_qjhPc02U, VOf(Bf7));
    __hv_varread_f(&sVarf_4XeWox0C, VOf(Bf15));
    __hv_varread_f(&sVarf_fpd4CCAW, VOf(Bf13));
    __hv_line_f(&sLine_9STs1V8F, VOf(Bf11));
    __hv_line_f(&sLine_OxMjE4AT, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_zOKO7k0F, VIf(Bf10));
    __hv_varwrite_f(&sVarf_4XeWox0C, VIf(Bf4));
    __hv_varread_f(&sVarf_BlyKLHm4, VOf(Bf11));
    __hv_varread_f(&sVarf_oCGP6bzP, VOf(Bf15));
    __hv_varread_f(&sVarf_AEOpEGN7, VOf(Bf13));
    __hv_varread_f(&sVarf_XrwftxOg, VOf(Bf6));
    __hv_varread_f(&sVarf_TNDkmLdY, VOf(Bf0));
    __hv_varread_f(&sVarf_F2TP7sQm, VOf(Bf2));
    __hv_varread_f(&sVarf_UK5cgn3C, VOf(Bf18));
    __hv_varwrite_f(&sVarf_6CInDqmu, VIf(Bf10));
    __hv_varread_f(&sVarf_fPVSRYMd, VOf(Bf1));
    __hv_line_f(&sLine_gnABSb97, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_FJNwaIlH, VOf(Bf19));
    __hv_line_f(&sLine_JMrvh5x0, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_CJbyQkfU, VOf(Bf14));
    __hv_line_f(&sLine_lymIGaZU, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_XrwftxOg, VIf(Bf17));
    __hv_varread_f(&sVarf_6CInDqmu, VOf(Bf17));
    __hv_line_f(&sLine_YCzjWQe8, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_dIIC5NL5, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_CoyfKN3L, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_TNDkmLdY, VIf(Bf16));
    __hv_line_f(&sLine_JGCIyOYf, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_1ErwqQFI, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_WEYd1UeP, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_F2TP7sQm, VIf(Bf16));
    __hv_line_f(&sLine_k3S9LJfx, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_UiivM1vs, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_V2TbqXw9, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_UK5cgn3C, VIf(Bf16));
    __hv_varwrite_f(&sVarf_fPVSRYMd, VIf(Bf11));
    __hv_varwrite_f(&sVarf_FJNwaIlH, VIf(Bf15));
    __hv_varwrite_f(&sVarf_CJbyQkfU, VIf(Bf13));
    sEnv_process(this, &sEnv_ZgvJogK3, VIf(Bf6), &sEnv_ZgvJogK3_sendMessage);
    sEnv_process(this, &sEnv_x9aluynh, VIf(Bf10), &sEnv_x9aluynh_sendMessage);
    __hv_line_f(&sLine_XhEBrAiT, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_naTeCaBY, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_wjjjwS6k, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_V0704S3t, VOf(Bf6));
    __hv_line_f(&sLine_ymyz2ncu, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_BlyKLHm4, VIf(Bf15));
    __hv_varwrite_f(&sVarf_V0704S3t, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Y5ij4clr, VIf(Bf2));
    __hv_varwrite_f(&sVarf_VzcRshwe, VIf(Bf18));
    __hv_varread_f(&sVarf_VzcRshwe, VOf(Bf18));
    __hv_line_f(&sLine_y02VtuS7, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_AEOpEGN7, VIf(Bf0));
    __hv_varread_f(&sVarf_Y5ij4clr, VOf(Bf0));
    __hv_line_f(&sLine_EsPFTjiL, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_oCGP6bzP, VIf(Bf0));
    __hv_varwrite_f(&sVarf_qjhPc02U, VIf(Bf10));
    __hv_varread_f(&sVarf_RpXyBXWq, VOf(Bf10));
    __hv_varread_f(&sVarf_5TXSs0le, VOf(Bf0));
    __hv_varread_f(&sVarf_AduQ9RLr, VOf(Bf15));
    __hv_varread_f(&sVarf_Orr2tpxr, VOf(Bf2));
    __hv_varread_f(&sVarf_gxgERvT3, VOf(Bf6));
    __hv_varread_f(&sVarf_vrCTCmyK, VOf(Bf18));
    __hv_varread_f(&sVarf_Z1f9iYFz, VOf(Bf13));
    __hv_varwrite_f(&sVarf_cUgsSNMC, VIf(Bf4));
    __hv_varread_f(&sVarf_hurWNrcc, VOf(Bf11));
    __hv_line_f(&sLine_ZzRHyPad, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_4LEY4DRz, VOf(Bf17));
    __hv_line_f(&sLine_srH0axTJ, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_oBDKSGeA, VOf(Bf16));
    __hv_line_f(&sLine_mOhfvYxf, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_Orr2tpxr, VIf(Bf19));
    __hv_varread_f(&sVarf_cUgsSNMC, VOf(Bf19));
    __hv_line_f(&sLine_GctIOAtp, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_2HmE1XFJ, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_qBCJVUTU, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_gxgERvT3, VIf(Bf1));
    __hv_line_f(&sLine_NGS8bXAz, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_ThHvsdGe, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_YvFXrgU1, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_vrCTCmyK, VIf(Bf1));
    __hv_line_f(&sLine_4UP39uiP, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_v3KJpkRQ, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_2WNjZhoi, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_Z1f9iYFz, VIf(Bf1));
    __hv_varwrite_f(&sVarf_hurWNrcc, VIf(Bf10));
    __hv_varwrite_f(&sVarf_4LEY4DRz, VIf(Bf0));
    __hv_varwrite_f(&sVarf_oBDKSGeA, VIf(Bf15));
    sEnv_process(this, &sEnv_UX5G5BFA, VIf(Bf2), &sEnv_UX5G5BFA_sendMessage);
    sEnv_process(this, &sEnv_vfABTrp5, VIf(Bf4), &sEnv_vfABTrp5_sendMessage);
    __hv_line_f(&sLine_g7jh23Fh, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_tSXOFPwQ, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_jslyrezl, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_suBpVERB, VOf(Bf2));
    __hv_line_f(&sLine_0eJNTmFY, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_RpXyBXWq, VIf(Bf0));
    __hv_varwrite_f(&sVarf_suBpVERB, VIf(Bf6));
    __hv_varwrite_f(&sVarf_9A1YnBhO, VIf(Bf18));
    __hv_varwrite_f(&sVarf_xmo06AML, VIf(Bf13));
    __hv_varread_f(&sVarf_xmo06AML, VOf(Bf13));
    __hv_line_f(&sLine_Rb0bmp99, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_AduQ9RLr, VIf(Bf6));
    __hv_varread_f(&sVarf_9A1YnBhO, VOf(Bf6));
    __hv_line_f(&sLine_bRwshUzZ, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_5TXSs0le, VIf(Bf6));
    __hv_varwrite_f(&sVarf_fpd4CCAW, VIf(Bf4));
    __hv_varwrite_f(&sVarf_fIlcVJcp, VIf(Bf7));
    __hv_varwrite_f(&sVarf_DRklZUuq, VIf(Bf8));
    __hv_varwrite_f(&sVarf_IJ5m1DSZ, VIf(Bf9));
    __hv_varwrite_f(&sVarf_OZPJBJSC, VIf(Bf12));
    __hv_varwrite_f(&sVarf_uBhGseTu, VIf(Bf3));
    __hv_varwrite_f(&sVarf_TWCCR38k, VIf(Bf5));
    __hv_varread_f(&sVarf_5Oc5IzF4, VOf(Bf5));
    __hv_varread_f(&sVarf_VnpAVqX2, VOf(Bf3));
    __hv_varread_f(&sVarf_fIlcVJcp, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_DRklZUuq, VOf(Bf12));
    __hv_varread_f(&sVarf_IJ5m1DSZ, VOf(Bf5));
    __hv_varread_f(&sVarf_OZPJBJSC, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
